@@ -214,7 +214,7 @@ Type of the :data:`NotImplemented` singleton.
 '''
 
 # ....................{ TYPES ~ call                       }....................
-CallableCodeObjectType: Any = type((lambda: None).__code__)
+CallableCodeObjectType = _types.CodeType
 '''
 Type of all **code objects** (i.e., C-based objects underlying all pure-Python
 callables to which those callables are compiled for efficiency).
@@ -607,7 +607,36 @@ else:
     strings).
     '''
 
-# ....................{ TYPES ~ data                       }....................
+# ....................{ TYPES ~ kind : concrete            }....................
+# Temporary dictionary to be deleted below.
+_dict: dict = {}
+
+
+DictItemsViewType: type = type(_dict.items())
+'''
+Type of all **dictionary items views** (i.e., objects created and returned by
+the :meth:`dict.items` method).
+'''
+
+
+DictKeysViewType: type = type(_dict.keys())
+'''
+Type of all **dictionary keys views** (i.e., objects created and returned by the
+:meth:`dict.keys` method).
+'''
+
+
+DictValuesViewType: type = type(_dict.values())
+'''
+Type of all **dictionary values views** (i.e., objects created and returned by
+the :meth:`dict.values` method).
+'''
+
+
+# Delete the dictionary defined above for negligible space gains.
+del _dict
+
+# ....................{ TYPES ~ kind : abc                 }....................
 ContainerType = _Container
 '''
 Type of all **containers** (i.e., concrete instances of the abstract
@@ -763,7 +792,7 @@ See Also
     Further details on structural subtyping.
 '''
 
-# ....................{ TYPES ~ data : mapping             }....................
+# ....................{ TYPES ~ kind : abc : mapping       }....................
 HashableType = _Hashable
 '''
 Type of all **hashable objects** (i.e., both concrete and structural instances
@@ -966,50 +995,61 @@ that enumeration's type and should be directly referenced as such: e.g.,
 '''
 
 # ....................{ TYPES ~ hint : pep : 585           }....................
-# Define this type as either...
-HintGenericSubscriptedType: type = (
-    # If the active Python interpreter targets at least Python >= 3.9 and thus
-    # supports PEP 585, this type;
-    type(list[str])  # type: ignore[misc]
-    if IS_PYTHON_AT_LEAST_3_9 else
-    # Else, a placeholder type.
-    UnavailableType
-)
-'''
-C-based type of all subscripted generics if the active Python interpreter
-targets Python >= 3.9 *or* :class:`.UnavailableType` otherwise.
+# If this submodule is currently being statically type-checked by a pure static
+# type-checker, ignore false positives complaining that this type is not a type.
+# Notably, mypy inexplicably refuses to accept this by emitting "errors"
+# resembling the following wherever this type is accessed:
+#     beartype/_util/hint/pep/proposal/utilpep695.py:120: error: Variable "beartype._cave._cavefast.HintPep695Type" is not valid as a type [valid-type]
+#     beartype/_util/hint/pep/proposal/utilpep695.py:120: note: See https://mypy.readthedocs.io/en/stable/common_issues.html#variables-vs-type-aliases
+if TYPE_CHECKING:
+    class HintGenericSubscriptedType(object): pass
+# Else, this submodule is *NOT* currently being statically type-checked by a
+# pure static type-checker. In this case, define this type properly. *sigh*
+else:
+    # Define this type as either...
+    HintGenericSubscriptedType: type = (
+        # If the active Python interpreter targets at least Python >= 3.9 and thus
+        # supports PEP 585, this type;
+        type(list[str])  # type: ignore[misc]
+        if IS_PYTHON_AT_LEAST_3_9 else
+        # Else, a placeholder type.
+        UnavailableType
+    )
+    '''
+    C-based type of all subscripted generics if the active Python interpreter
+    targets Python >= 3.9 *or* :class:`.UnavailableType` otherwise.
 
-This type is a version-agnostic generalization of the standard
-:class:`types.GenericAlias` type available only under Python >= 3.9. Subscripted
-generics include:
+    This type is a version-agnostic generalization of the standard
+    :class:`types.GenericAlias` type available only under Python >= 3.9. Subscripted
+    generics include:
 
-* :pep:`585`-compliant **builtin type hints** (i.e., C-based type hints
-  instantiated by subscripting either a concrete builtin container class like
-  :class:`list` or :class:`tuple` *or* an abstract base class (ABC) declared by
-  the :mod:`collections.abc` submodule like :class:`collections.abc.Iterable`
-  or :class:`collections.abc.Sequence`).
-* :pep:`484`-compliant **subscripted generics** (i.e., user-defined classes
-  subclassing one or more :pep:`484`-compliant type hints subsequently
-  subscripted by one or more PEP-compliant type hints).
-* :pep:`585`-compliant **subscripted generics** (i.e., user-defined classes
-  subclassing one or more :pep:`585`-compliant type hints subsequently
-  subscripted by one or more PEP-compliant type hints).
+    * :pep:`585`-compliant **builtin type hints** (i.e., C-based type hints
+      instantiated by subscripting either a concrete builtin container class like
+      :class:`list` or :class:`tuple` *or* an abstract base class (ABC) declared by
+      the :mod:`collections.abc` submodule like :class:`collections.abc.Iterable`
+      or :class:`collections.abc.Sequence`).
+    * :pep:`484`-compliant **subscripted generics** (i.e., user-defined classes
+      subclassing one or more :pep:`484`-compliant type hints subsequently
+      subscripted by one or more PEP-compliant type hints).
+    * :pep:`585`-compliant **subscripted generics** (i.e., user-defined classes
+      subclassing one or more :pep:`585`-compliant type hints subsequently
+      subscripted by one or more PEP-compliant type hints).
 
-Caveats
-----------
-**This low-level type ambiguously matches semantically unrelated PEP-compliant
-type hints,** rendering this type all but useless for most practical purposes.
-To distinguish between the various semantic types of hints ambiguously matched
-by this type, higher-level PEP-specific functions *must* be called instead.
-These include:
+    Caveats
+    -------
+    **This low-level type ambiguously matches semantically unrelated PEP-compliant
+    type hints,** rendering this type all but useless for most practical purposes.
+    To distinguish between the various semantic types of hints ambiguously matched
+    by this type, higher-level PEP-specific functions *must* be called instead.
+    These include:
 
-* :func:`beartype._util.hint.pep.proposal.pep484.utilpep484.is_hint_pep484_generic`,
-  detecting :pep:`484`-compliant generic type hints.
-* :func:`beartype._util.hint.pep.proposal.utilpep585.is_hint_pep585_builtin_subscripted`,
-  detecting :pep:`585`-compliant builtin type hints.
-* :func:`beartype._util.hint.pep.proposal.utilpep585.is_hint_pep585_generic`,
-  detecting :pep:`585`-compliant generic type hints.
-'''
+    * :func:`beartype._util.hint.pep.proposal.pep484.utilpep484.is_hint_pep484_generic`,
+      detecting :pep:`484`-compliant generic type hints.
+    * :func:`beartype._util.hint.pep.proposal.utilpep585.is_hint_pep585_builtin_subscripted`,
+      detecting :pep:`585`-compliant builtin type hints.
+    * :func:`beartype._util.hint.pep.proposal.utilpep585.is_hint_pep585_generic`,
+      detecting :pep:`585`-compliant generic type hints.
+    '''
 
 # ....................{ TYPES ~ hint : pep : 604           }....................
 # If this submodule is currently being statically type-checked by a pure static
@@ -1039,7 +1079,8 @@ else:
     '''
 
 
-HintPep604Types: _TupleTyping[type, ...] = (type, HintGenericSubscriptedType)
+HintPep604ItemTypes: _TupleTyping[type, ...] = (
+    type, HintGenericSubscriptedType)
 '''
 Tuple of all :pep:`604`-compliant **new union item types** (i.e., types of all
 objects permissible as the items of new unions), including:
@@ -1050,16 +1091,84 @@ objects permissible as the items of new unions), including:
   in the new union ``list[dict[str, int]] | None``).
 '''
 
+# ....................{ TYPES ~ hint : pep : 612           }....................
+# If this submodule is currently being statically type-checked by a pure static
+# type-checker, ignore false positives complaining that these types are not
+# types.
+if TYPE_CHECKING:
+    class HintPep612ParamSpecType(object): pass
+    class HintPep612ParamSpecArgType(object): pass
+    class HintPep612ParamSpecKwargType(object): pass
+# Else, this submodule is *NOT* currently being statically type-checked by a
+# pure static type-checker.
+#
+# If the active Python interpreter targets at least Python >= 3.10 and thus
+# supports PEP 612, define these types properly. *sigh*
+elif IS_PYTHON_AT_LEAST_3_10:
+    HintPep612ParamSpecType = _typing.ParamSpec
+    '''
+    C-based type of all :pep:`612`-compliant **parameter specifications** (i.e.,
+    low-level C-based :obj:`typing.ParamSpec` objects) if the active Python
+    interpreter targets Python >= 3.10 *or* :class:`.UnavailableType` otherwise.
+
+    This type is a version-agnostic generalization of the standard
+    :class:`typing.ParamSpec` type available only under Python >= 3.10.
+    '''
+
+
+    HintPep612ParamSpecArgType = _typing.ParamSpecArgs
+    '''
+    C-based type of all :pep:`612`-compliant **parameter specification variadic
+    positional parameter instance variables** (i.e., low-level C-based
+    :obj:`typing.ParamSpecArgs` objects annotating variadic positional
+    parameters with syntax resembling ``*args: P.args`` for ``P`` a low-level
+    C-based :obj:`typing.ParamSpec` parent object) if the active Python
+    interpreter targets Python >= 3.10 *or* :class:`.UnavailableType` otherwise.
+
+    This type is a version-agnostic generalization of the standard
+    :class:`typing.ParamSpecArgs` type available only under Python >= 3.10.
+    '''
+
+
+    HintPep612ParamSpecKwargType = _typing.ParamSpecKwargs
+    '''
+    C-based type of all :pep:`612`-compliant **parameter specification variadic
+    keyword parameter instance variables** (i.e., low-level C-based
+    :obj:`typing.ParamSpecArgs` objects annotating variadic keyword
+    parameters with syntax resembling ``**kwargs: P.kwargs`` for ``P`` a
+    low-level C-based :obj:`typing.ParamSpec` parent object) if the active
+    Python interpreter targets Python >= 3.10 *or* :class:`.UnavailableType`
+    otherwise.
+
+    This type is a version-agnostic generalization of the standard
+    :class:`typing.ParamSpecKwargs` type available only under Python >= 3.10.
+    '''
+# Else, the active Python interpreter targets Python < 3.10 and thus fails to
+# support PEP 612. In this case, define these types as placeholders. *sigh*
+else:
+    HintPep612ParamSpecType = \
+    HintPep612ParamSpecArgType = \
+    HintPep612ParamSpecKwargType = \
+        UnavailableType
+
+
+HintPep612ParamSpecVarTypes: _TupleTyping[type, ...] = (
+    HintPep612ParamSpecArgType, HintPep612ParamSpecKwargType,)
+'''
+Tuple of all :pep:`612`-compliant **parameter specification variadic parameter
+instance variables** (i.e., low-level C-based :obj:`typing.ParamSpecArgs`
+objects annotating variadic parameters with syntax resembling
+``*args: P.args`` and ``**kwargs: P.kwargs`` for ``P`` a low-level C-based
+:obj:`typing.ParamSpec` parent object).
+'''
+
 # ....................{ TYPES ~ hint : pep : 695           }....................
 # If this submodule is currently being statically type-checked by a pure static
 # type-checker, ignore false positives complaining that this type is not a type.
 # Notably, mypy inexplicably refuses to accept this by emitting "errors"
 # resembling the following wherever this type is accessed:
-#     beartype/_util/hint/pep/proposal/utilpep695.py:120: error: Variable
-#         "beartype._cave._cavefast.HintPep695Type" is not valid as a type
-#         [valid-type]
-#     beartype/_util/hint/pep/proposal/utilpep695.py:120: note: See
-#         https://mypy.readthedocs.io/en/stable/common_issues.html#variables-vs-type-aliases
+#     beartype/_util/hint/pep/proposal/utilpep695.py:120: error: Variable "beartype._cave._cavefast.HintPep695Type" is not valid as a type [valid-type]
+#     beartype/_util/hint/pep/proposal/utilpep695.py:120: note: See https://mypy.readthedocs.io/en/stable/common_issues.html#variables-vs-type-aliases
 if TYPE_CHECKING:
     class HintPep695Type(object): pass
 # Else, this submodule is *NOT* currently being statically type-checked by a
@@ -1101,7 +1210,7 @@ This type matches:
   builtin Unicode strings are usable.
 
 Caveats
-----------
+-------
 This type does *not* match **encoded byte strings** (i.e., sequences of
 physical encoded bytes, including the builtin :class:`bytestring` type), which
 require foreknowledge of the encoding previously used to encode those bytes.
@@ -1301,7 +1410,7 @@ Tuple of all **function types** (i.e., types whose instances are either
 built-in or user-defined functions).
 
 Caveats
-----------
+-------
 **This tuple may yield false positives when used to validate types.** Since
 Python fails to distinguish between C-based functions and methods, this tuple
 is the set of all function types as well as the ambiguous type of all C-based
@@ -1391,7 +1500,7 @@ Unbound decorator objects (e.g., non-callable instances of the builtin
 classes) are *not* callable and thus intentionally excluded.
 
 Caveats
-----------
+-------
 **This tuple may yield false positives when used to validate types.** Since
 Python fails to distinguish between C-based functions and methods, this tuple
 is the set of all pure-Python bound and unbound method types as well as the
@@ -1452,10 +1561,10 @@ Tuple of all callable types as well as the string type.
 '''
 
 
-#FIXME: Define a new "CallableClassType" by copying the "BoolType" approach
+#FIXME: Define a new "ClassCallableType" by copying the "BoolType" approach
 #except for the __call__() dunder method instead.
-#FIXME: Replace "ClassType" below by "CallableClassType".
-#FIXME: Add the "CallableClassType" type to the "CallableTypes" tuple as well.
+#FIXME: Replace "ClassType" below by "ClassCallableType".
+#FIXME: Add the "ClassCallableType" type to the "CallableTypes" tuple as well.
 DecoratorTypes = CallableTypes + (ClassType,)
 '''
 Tuple of all **decorator types** (i.e., both callable classes *and* the type of
