@@ -23,40 +23,90 @@ from beartype.typing import (
     Dict,
     Optional,
 )
+from beartype._check.metadata.metadecor import BeartypeDecorMeta
 from beartype._conf.confcls import BeartypeConf
 from beartype._data.hint.pep.sign.datapepsigncls import HintSign
 from beartype._data.hint.pep.sign.datapepsigns import (
+    HintSignAbstractSet,
     HintSignAnnotated,
+    HintSignAsyncContextManager,
+    HintSignAsyncGenerator,
+    HintSignAsyncIterable,
+    HintSignAsyncIterator,
+    HintSignAwaitable,
+    HintSignByteString,
+    HintSignCallable,
+    HintSignChainMap,
+    HintSignCollection,
+    HintSignContainer,
+    HintSignContextManager,
+    HintSignCoroutine,
+    HintSignCounter,
+    HintSignDefaultDict,
+    HintSignDeque,
+    HintSignDict,
     HintSignFinal,
+    HintSignFrozenSet,
+    HintSignGenerator,
     HintSignGeneric,
+    HintSignHashable,
+    HintSignItemsView,
+    HintSignIterable,
+    HintSignIterator,
+    HintSignKeysView,
+    HintSignList,
     HintSignLiteralString,
+    HintSignMappingView,
+    HintSignMapping,
+    HintSignMatch,
+    HintSignMutableMapping,
+    HintSignMutableSequence,
+    HintSignMutableSet,
     HintSignNewType,
     HintSignNone,
     HintSignNumpyArray,
+    HintSignOrderedDict,
     HintSignPanderaAny,
+    HintSignParamSpecArgs,
+    HintSignParamSpecKwargs,
+    HintSignPattern,
     HintSignPep557DataclassInitVar,
     HintSignPep585BuiltinSubscriptedUnknown,
     HintSignPep695TypeAlias,
+    HintSignReversible,
     HintSignSelf,
+    HintSignSequence,
+    HintSignSet,
+    HintSignSized,
+    HintSignTuple,
+    HintSignTupleFixed,
     HintSignType,
+    HintSignTypeAlias,
     HintSignTypeGuard,
     HintSignTypeVar,
     HintSignTypedDict,
+    HintSignUnpack,
+    HintSignValuesView,
 )
 from beartype._data.hint.datahinttyping import TypeStack
 from beartype._util.cache.utilcachecall import callable_cached
-from beartype._util.hint.nonpep.mod.utilmodnumpy import (
+from beartype._util.func.arg.utilfuncargiter import ArgKind
+from beartype._util.hint.nonpep.api.utilmodnumpy import (
     reduce_hint_numpy_ndarray)
-from beartype._util.hint.nonpep.mod.utilmodpandera import (
+from beartype._util.hint.nonpep.api.utilmodpandera import (
     reduce_hint_pandera)
 from beartype._util.hint.pep.proposal.pep484.utilpep484 import (
-    reduce_hint_pep484_none)
+    reduce_hint_pep484_deprecated,
+    reduce_hint_pep484_none,
+)
 from beartype._util.hint.pep.proposal.pep484.utilpep484generic import (
     reduce_hint_pep484_generic)
 from beartype._util.hint.pep.proposal.pep484.utilpep484newtype import (
     reduce_hint_pep484_newtype)
 from beartype._util.hint.pep.proposal.pep484.utilpep484typevar import (
     reduce_hint_pep484_typevar)
+from beartype._util.hint.pep.proposal.pep484585.utilpep484585container import (
+    reduce_hint_pep484585_itemsview)
 from beartype._util.hint.pep.proposal.pep484585.utilpep484585type import (
     reduce_hint_pep484585_type)
 from beartype._util.hint.pep.proposal.utilpep557 import (
@@ -66,12 +116,20 @@ from beartype._util.hint.pep.proposal.utilpep585 import (
 from beartype._util.hint.pep.proposal.utilpep589 import reduce_hint_pep589
 from beartype._util.hint.pep.proposal.utilpep591 import reduce_hint_pep591
 from beartype._util.hint.pep.proposal.utilpep593 import reduce_hint_pep593
+from beartype._util.hint.pep.proposal.utilpep612 import (
+    reduce_hint_pep612_args,
+    reduce_hint_pep612_kwargs,
+)
+from beartype._util.hint.pep.proposal.utilpep613 import reduce_hint_pep613
+from beartype._util.hint.pep.proposal.utilpep646692 import (
+    reduce_hint_pep646692_unpack)
 from beartype._util.hint.pep.proposal.utilpep647 import reduce_hint_pep647
 from beartype._util.hint.pep.proposal.utilpep673 import reduce_hint_pep673
 from beartype._util.hint.pep.proposal.utilpep675 import reduce_hint_pep675
 from beartype._util.hint.pep.proposal.utilpep695 import reduce_hint_pep695
 from beartype._util.hint.pep.utilpepget import get_hint_pep_sign_or_none
 from beartype._util.hint.pep.utilpepreduce import reduce_hint_pep_unsigned
+from beartype._util.utilobject import SENTINEL
 from collections.abc import Callable
 
 # ....................{ REDUCERS                           }....................
@@ -81,8 +139,10 @@ def reduce_hint(
     conf: BeartypeConf,
 
     # Optional parameters.
-    cls_stack: TypeStack = None,
+    decor_meta: Optional[BeartypeDecorMeta] = None,
     pith_name: Optional[str] = None,
+    arg_kind: Optional[ArgKind] = None,
+    cls_stack: TypeStack = None,
     exception_prefix: str = '',
 ) -> object:
     '''
@@ -110,10 +170,13 @@ def reduce_hint(
     conf : BeartypeConf
         **Beartype configuration** (i.e., self-caching dataclass encapsulating
         all settings configuring type-checking for the passed object).
-    cls_stack : TypeStack, optional
-        **Type stack** (i.e., either a tuple of the one or more
-        :func:`beartype.beartype`-decorated classes lexically containing the
-        class variable or method annotated by this hint *or* :data:`None`).
+    decor_meta : Optional[BeartypeDecorMeta], optional
+        Either:
+
+        * If this hint annotates a parameter or return of some callable, the
+          :mod:`beartype`-specific decorator metadata describing that callable.
+        * Else, :data:`None`.
+
         Defaults to :data:`None`.
     pith_name : Optional[str], optional
         Either:
@@ -123,10 +186,25 @@ def reduce_hint(
         * If this hint annotates the return of some callable, ``"return"``.
         * Else, :data:`None`.
 
+        Defaults to :data:`None`.
+    arg_kind : Optional[ArgKind]
+        Either:
+
+        * If this hint annotates a parameter of some callable, that parameter's
+          **kind** (i.e., :class:`.ArgKind` enumeration member conveying the
+          syntactic class of that parameter, constraining how the callable
+          declaring that parameter requires that parameter to be passed).
+        * Else, :data:`None`.
+
+        Defaults to :data:`None`.
+    cls_stack : TypeStack, optional
+        **Type stack** (i.e., either a tuple of the one or more
+        :func:`beartype.beartype`-decorated classes lexically containing the
+        class variable or method annotated by this hint *or* :data:`None`).
         Defaults to :data:`None`.
     exception_prefix : str, optional
-        Substring prefixing exception messages raised by this function. Defaults
-        to the empty string.
+        Human-readable substring prefixing exception messages raised by this
+        reducer. Defaults to the empty string.
 
     Returns
     -------
@@ -137,23 +215,48 @@ def reduce_hint(
         * Else, this hint as is unmodified.
     '''
 
-    # This possibly contextual hint inefficiently reduced to another hint.
-    #
-    # Note that we intentionally reduce lower-level contextual hints *BEFORE*
-    # higher-level context-free hints. In theory, order of reduction *SHOULD* be
-    # insignificant; in practice, we suspect unforeseen and unpredictable
-    # interactions between these two reductions. To reduce the likelihood of
-    # fire-breathing dragons, we reduce lower-level hints first.
-    hint = _reduce_hint_uncached(
-        hint=hint,
-        conf=conf,
-        pith_name=pith_name,
-        cls_stack=cls_stack,
-        exception_prefix=exception_prefix,
-    )
+    # Previously reduced instance of this hint, initialized to the sentinel to
+    # guarantee that the passed hint is *NEVER* equal to the previously reduced
+    # instance of this hint unless actually reduced below. This is necessary, as
+    # "None" is a valid type hint reduced to "type(None)" below.
+    hint_prev: object = SENTINEL
 
-    # This possibly context-free hint efficiently reduced to another hint.
-    hint = _reduce_hint_cached(hint, conf, exception_prefix)
+    # Repeatedly reduce this hint to increasingly irreducible hints until this
+    # hint is no longer reducible.
+    while True:
+        # This possibly contextual hint inefficiently reduced to another hint.
+        #
+        # Note that we intentionally reduce lower-level contextual hints
+        # *BEFORE* reducing higher-level context-free hints. In theory, order of
+        # reduction *SHOULD* be insignificant; in practice, we suspect
+        # unforeseen and unpredictable interactions between these two
+        # reductions. To reduce the likelihood of fire-breathing dragons here,
+        # we reduce lower-level hints first.
+        hint = _reduce_hint_uncached(
+            hint=hint,
+            conf=conf,
+            decor_meta=decor_meta,
+            pith_name=pith_name,
+            arg_kind=arg_kind,
+            cls_stack=cls_stack,
+            exception_prefix=exception_prefix,
+        )
+
+        # This possibly context-free hint efficiently reduced to another hint.
+        hint = _reduce_hint_cached(hint, conf, exception_prefix)
+
+        # If the current and previously reduced instances of this hint are
+        # identical, the above reductions preserved this hint as is rather than
+        # reducing this hint, implying this hint to irreducible. In this case,
+        # stop reducing.
+        if hint is hint_prev:
+            break
+        # Else, the current and previously reduced instances of this hint
+        # differ -- implying this hint to still be reducible. In this case,
+        # continue reducing.
+
+        # Previously reduced instance of this hint.
+        hint_prev = hint
 
     # Return this possibly reduced hint.
     return hint
@@ -162,8 +265,10 @@ def reduce_hint(
 def _reduce_hint_uncached(
     hint: Any,
     conf: BeartypeConf,
-    cls_stack: TypeStack,
+    decor_meta: Optional[BeartypeDecorMeta],
+    arg_kind: Optional[ArgKind],
     pith_name: Optional[str],
+    cls_stack: TypeStack,
     exception_prefix: str,
 ) -> object:
     '''
@@ -186,9 +291,12 @@ def _reduce_hint_uncached(
     conf : BeartypeConf
         **Beartype configuration** (i.e., self-caching dataclass encapsulating
         all settings configuring type-checking for the passed object).
-    cls_stack : TypeStack
-        **Type stack** (i.e., either tuple of zero or more arbitrary types *or*
-        :data:`None`). See also the :func:`.beartype_object` decorator.
+    decor_meta : Optional[BeartypeDecorMeta]
+        Either:
+
+        * If this hint annotates a parameter or return of some callable, the
+          :mod:`beartype`-specific decorator metadata describing that callable.
+        * Else, :data:`None`.
     pith_name : Optional[str]
         Either:
 
@@ -196,8 +304,21 @@ def _reduce_hint_uncached(
           parameter.
         * If this hint annotates the return of some callable, ``"return"``.
         * Else, :data:`None`.
+    arg_kind : Optional[ArgKind]
+        Either:
+
+        * If this hint annotates a parameter of some callable, that parameter's
+          **kind** (i.e., :class:`.ArgKind` enumeration member conveying the
+          syntactic class of that parameter, constraining how the callable
+          declaring that parameter requires that parameter to be passed).
+        * Else, :data:`None`.
+    cls_stack : TypeStack
+        **Type stack** (i.e., either a tuple of the one or more
+        :func:`beartype.beartype`-decorated classes lexically containing the
+        class variable or method annotated by this hint *or* :data:`None`).
     exception_prefix : str
-        Substring prefixing exception messages raised by this function.
+        Human-readable substring prefixing exception messages raised by this
+        reducer.
 
     Returns
     -------
@@ -209,8 +330,9 @@ def _reduce_hint_uncached(
     '''
 
     # Sign uniquely identifying this hint if this hint is identifiable *OR*
-    # "None" otherwise.
+    # "None" otherwise (e.g., if this hint is merely an isinstanceable class).
     hint_sign = get_hint_pep_sign_or_none(hint)
+    # print(f'_reduce_hint_uncached() hint_sign: {hint_sign}')
 
     # Callable reducing this hint if a callable reducing hints of this sign was
     # previously registered *OR* "None" otherwise (i.e., if *NO* such callable
@@ -219,13 +341,15 @@ def _reduce_hint_uncached(
 
     # If a callable reducing hints of this sign was previously registered,
     # reduce this hint to another hint via this callable.
-    if hint_reducer is not None:
+    if hint_reducer is not None:  # type: ignore[call-arg]
         # print(f'Reducing hint {repr(hint)} to...')
-        hint = hint_reducer(  # type: ignore[call-arg]
-            hint=hint,  # pyright: ignore[reportGeneralTypeIssues]
+        hint = hint_reducer(
+            hint=hint,  # pyright: ignore
             conf=conf,
-            cls_stack=cls_stack,
+            decor_meta=decor_meta,
             pith_name=pith_name,
+            arg_kind=arg_kind,
+            cls_stack=cls_stack,
             exception_prefix=exception_prefix,
         )
         # print(f'...{repr(hint)}.')
@@ -286,7 +410,7 @@ def _reduce_hint_cached(
         pass
 
     # Sign uniquely identifying this hint if this hint is identifiable *OR*
-    # "None" otherwise.
+    # "None" otherwise (e.g., if this hint is merely an isinstanceable class).
     hint_sign = get_hint_pep_sign_or_none(hint)
 
     # Callable reducing this hint if a callable reducing hints of this sign was
@@ -308,22 +432,35 @@ def _reduce_hint_cached(
     return hint
 
 # ....................{ PRIVATE ~ hints                    }....................
-_DictReducer = Dict[Optional[HintSign], Callable]
+# Note that these type hints would ideally be defined with the mypy-specific
+# "callback protocol" pseudostandard, documented here:
+#     https://mypy.readthedocs.io/en/stable/protocols.html#callback-protocols
+#
+# Doing so would enable static type-checkers to type-check that the values of
+# these dictionaries are valid reducer functions. Sadly, that pseudostandard is
+# absurdly strict to the point of practical uselessness. Attempting to conform
+# to that pseudostandard would require refactoring *ALL* reducer functions to
+# explicitly define the same signature. However, we have intentionally *NOT*
+# done that. Why? Doing so would substantially increase the fragility of this
+# API by preventing us from readily adding and removing infrequently required
+# parameters (e.g., "cls_stack", "pith_name"). Callback protocols suck, frankly.
+_HintSignToReduceHintCached = Dict[Optional[HintSign], Callable]
 '''
-PEP-compliant type hint matching a **reducer dictionary** (i.e., dictionary
-mapping from each sign uniquely identifying various type hints to a callable
-reducing those higher- to lower-level hints).
+PEP-compliant type hint matching a **cached reducer dictionary** (i.e.,
+mapping from each sign uniquely identifying various type hints to a memoized
+callable reducing those higher- to lower-level hints).
+'''
+
+
+_HintSignToReduceHintUncached = _HintSignToReduceHintCached
+'''
+PEP-compliant type hint matching an **uncached reducer dictionary** (i.e.,
+mapping from each sign uniquely identifying various type hints to an unmemoized
+callable reducing those higher- to lower-level hints).
 '''
 
 # ....................{ PRIVATE ~ dicts                    }....................
-#FIXME: After dropping Python 3.7 support:
-#* Replace "Callable[[object, str], object]" here with a callback protocol:
-#      https://mypy.readthedocs.io/en/stable/protocols.html#callback-protocols
-#  Why? Because the current approach forces positional arguments. But we call
-#  these callables with keyword arguments above! Chaos ensues.
-#* Remove the "# type: ignore[call-arg]" pragmas above, which are horrible.
-#* Remove the "# type: ignore[dict-item]" pragmas above, which are horrible.
-_HINT_SIGN_TO_REDUCE_HINT_CACHED: _DictReducer = {
+_HINT_SIGN_TO_REDUCE_HINT_CACHED: _HintSignToReduceHintCached = {
     # ..................{ NON-PEP                            }..................
     # If this hint is identified by *NO* sign, this hint is either an
     # isinstanceable type *OR* a hint unrecognized by beartype. In either case,
@@ -368,6 +505,10 @@ _HINT_SIGN_TO_REDUCE_HINT_CACHED: _DictReducer = {
     HintSignTypeVar: reduce_hint_pep484_typevar,
 
     # ..................{ PEP (484|585)                      }..................
+    # If this hint is a PEP 484- or 585-compliant items view type hint, reduce
+    # this hint to a more trivially consumable PEP 593-compliant type hint.
+    HintSignItemsView: reduce_hint_pep484585_itemsview,
+
     # If this hint is a PEP 484- or 585-compliant subclass type hint subscripted
     # by an ignorable child type hint (e.g., "object", "typing.Any"), silently
     # ignore this argument by reducing this hint to the "type" superclass.
@@ -388,6 +529,78 @@ _HINT_SIGN_TO_REDUCE_HINT_CACHED: _DictReducer = {
     HintSignPep557DataclassInitVar: reduce_hint_pep557_initvar,
 
     # ..................{ PEP 585                            }..................
+    #FIXME: *NON-IDEAL.* Some hints superficially identified as
+    #"HintSignPep585BuiltinSubscriptedUnknown" are actually deeply
+    #type-checkable as is. This is the case for *ALL* builtin collection type
+    #subclasses, for example -- hardly an uncommon edge case: e.g.,
+    #    >>> from beartype._util.hint.pep.utilpepget import get_hint_pep_sign
+    #    >>> class UserList(list): pass
+    #    >>> get_hint_pep_sign(UserList[str])
+    #    HintSignPep585BuiltinSubscriptedUnknown
+    #
+    #Although "UserList[str]" is identified as unknown, "UserList[str]" is
+    #deeply type-checkable as a PEP 593-compliant type hint resembling:
+    #    Annotated[List[str], IsInstance[UserList]]
+    #
+    #That is to say, "UserList[str]" should be deeply type-checked as
+    #semantically equivalent to "List[str]" that just happens to be an instance
+    #of "UserList" rather than "list".
+    #
+    #Thankfully, this isn't terribly arduous to support. Generalize
+    #reduce_hint_pep585_builtin_subscripted_unknown() as follows. The basic idea
+    #is to just defer to the existing
+    #_infer_hint_factory_collection_builtin() function, which interestingly does
+    #a great deal of what we already need:
+    #    def reduce_hint_pep585_builtin_subscripted_unknown(
+    #        hint: object, *args, **kwargs) -> type:
+    #
+    #        # Avoid circular import dependencies.
+    #        from beartype.door._func.infer.collection.infercollectionbuiltin import (
+    #            _infer_hint_factory_collection_builtin)
+    #        from beartype._util.api.utilapityping import import_typing_attr_or_none
+    #        from beartype._util.hint.pep.utilpepget import (
+    #            get_hint_pep_args,
+    #            get_hint_pep_origin_type,
+    #        )
+    #
+    #        # Pure-Python origin type originating this unrecognized subscripted builtin
+    #        # type hint if this hint originates from such a type *OR* raise an
+    #        # exception otherwise (i.e., if this hint originates from *NO* such type).
+    #        hint_origin_type = get_hint_pep_origin_type(hint)
+    #
+    #        # Hint to be returned, defaulting to this origin type.
+    #        hint = hint_origin_type
+    #
+    #        builtin_factory, builtin_origin_type = _infer_hint_factory_collection_builtin(
+    #            hint_origin_type)
+    #
+    #        if builtin_factory is not None:
+    #            Annotated = import_typing_attr_or_none('Annotated')
+    #
+    #            if Annotated is not None:
+    #                # Defer heavyweight imports.
+    #                from beartype.vale import IsInstance
+    #
+    #                hint_args = get_hint_pep_args(hint)
+    #
+    #                #FIXME: Unsure if this works. If not, try:
+    #                #    hint_builtin = builtin_factory.__getitem__(*hint_args)
+    #                #FIXME: Can "hint_args" be the empty tuple here? Probably.
+    #                #We should probably avoid unpacking at all in that case.
+    #                hint_builtin = builtin_factory[*hint_args]
+    #
+    #                hint = Annotated[hint_builtin, IsInstance[hint_origin_type]]
+    #
+    #        # Return this hint.
+    #        return hint
+    #
+    #Since the _infer_hint_factory_collection_builtin() function appears to be
+    #of public relevance, let's at least rename that
+    #infer_hint_factory_collection_builtin().
+    #
+    #Pretty cool, eh? Fairly trivial and *SHOULD* definitely work. Let's give
+    #this a go as time permits, please.
+
     # If this hint is a PEP 585-compliant unrecognized subscripted builtin type
     # hint (i.e., C-based type hint that is *NOT* an isinstanceable type,
     # instantiated by subscripting a pure-Python origin class subclassing the
@@ -466,8 +679,7 @@ to that sign's **cached reducer** (i.e., low-level function efficiently memoized
 by the :func:`.callable_cached` decorator reducing those higher- to lower-level
 hints).
 
-Each value of this dictionary should be a valid reducer, defined as a function
-with signature resembling:
+Each value of this dictionary is expected to have a signature resembling:
 
 .. code-block:: python
 
@@ -488,31 +700,114 @@ Note that:
   expected sign. By design, a reducer is only ever passed a type hint of the
   expected sign.
 * Reducers should *not* be memoized (e.g., by the
-  :func:`.callable_cached` decorator). Since the higher-level
-  :func:`.reduce_hint` function that is the sole entry point to calling all
-  lower-level reducers is itself memoized, reducers themselves do neither
-  require nor benefit from memoization. Moreover, even if they did either
-  require or benefit from memoization, they couldn't be -- at least, not
-  directly. Why? Because :func:`.reduce_hint` necessarily passes keyword
-  arguments to all reducers. But memoized functions *cannot* receive keyword
-  arguments (without destroying efficiency and thus the entire impetus for
-  memoization). Ergo, reducers *cannot* be memoized.
+  ``callable_cached`` decorator). Since the higher-level :func:`.reduce_hint`
+  function that is the sole entry point to calling all lower-level reducers is
+  itself memoized, reducers themselves neither require nor benefit from
+  memoization. Moreover, even if they did either require or benefit from
+  memoization, they couldn't be -- at least, not directly. Why? Because
+  :func:`.reduce_hint` necessarily passes keyword arguments to all reducers. But
+  memoized functions *cannot* receive keyword arguments (without destroying
+  efficiency and thus the entire point of memoization).
 '''
 
 
-_HINT_SIGN_TO_REDUCE_HINT_UNCACHED: _DictReducer = {
-    # ..................{ PEP 647                            }..................
-    # If this hint is a PEP 647-compliant "typing.TypeGuard[...]" type hint,
+_HINT_SIGN_TO_REDUCE_HINT_UNCACHED: _HintSignToReduceHintUncached = {
+    # ..................{ PEP 484                            }..................
+    # Preserve deprecated PEP 484-compliant type hints as is while emitting one
+    # non-fatal deprecation warning for each.
+    #
+    # Note that, to ensure that one such warning is emitted for each such hint,
+    # these reducers are intentionally uncached rather than cached.
+    HintSignAbstractSet: reduce_hint_pep484_deprecated,
+    HintSignAsyncContextManager: reduce_hint_pep484_deprecated,
+    HintSignAsyncGenerator: reduce_hint_pep484_deprecated,
+    HintSignAsyncIterable: reduce_hint_pep484_deprecated,
+    HintSignAsyncIterator: reduce_hint_pep484_deprecated,
+    HintSignAwaitable: reduce_hint_pep484_deprecated,
+    HintSignByteString: reduce_hint_pep484_deprecated,
+    HintSignCallable: reduce_hint_pep484_deprecated,
+    HintSignChainMap: reduce_hint_pep484_deprecated,
+    HintSignCollection: reduce_hint_pep484_deprecated,
+    HintSignContainer: reduce_hint_pep484_deprecated,
+    HintSignContextManager: reduce_hint_pep484_deprecated,
+    HintSignCoroutine: reduce_hint_pep484_deprecated,
+    HintSignCounter: reduce_hint_pep484_deprecated,
+    HintSignDefaultDict: reduce_hint_pep484_deprecated,
+    HintSignDeque: reduce_hint_pep484_deprecated,
+    HintSignDict: reduce_hint_pep484_deprecated,
+    HintSignFrozenSet: reduce_hint_pep484_deprecated,
+    HintSignGenerator: reduce_hint_pep484_deprecated,
+    HintSignHashable: reduce_hint_pep484_deprecated,
+    HintSignItemsView: reduce_hint_pep484_deprecated,
+    HintSignIterable: reduce_hint_pep484_deprecated,
+    HintSignIterator: reduce_hint_pep484_deprecated,
+    HintSignKeysView: reduce_hint_pep484_deprecated,
+    HintSignList: reduce_hint_pep484_deprecated,
+    HintSignMappingView: reduce_hint_pep484_deprecated,
+    HintSignMapping: reduce_hint_pep484_deprecated,
+    HintSignMatch: reduce_hint_pep484_deprecated,
+    HintSignMutableMapping: reduce_hint_pep484_deprecated,
+    HintSignMutableSequence: reduce_hint_pep484_deprecated,
+    HintSignMutableSet: reduce_hint_pep484_deprecated,
+    HintSignOrderedDict: reduce_hint_pep484_deprecated,
+    HintSignPattern: reduce_hint_pep484_deprecated,
+    HintSignReversible: reduce_hint_pep484_deprecated,
+    HintSignSequence: reduce_hint_pep484_deprecated,
+    HintSignSet: reduce_hint_pep484_deprecated,
+    HintSignSized: reduce_hint_pep484_deprecated,
+    HintSignTuple: reduce_hint_pep484_deprecated,
+    HintSignTupleFixed: reduce_hint_pep484_deprecated,
+    HintSignType: reduce_hint_pep484_deprecated,
+    HintSignValuesView: reduce_hint_pep484_deprecated,
+
+    # ..................{ PEP 612                            }..................
+    #FIXME: Ideally, PEP 612-compliant type hints like "*args: P.args" and
+    #"**kwargs: P.kwargs" would be runtime-checkable. However, it's unclear
+    #whether these hints even *CAN* be runtime type-checked in theory -- let
+    #alone practice. For the moment, shallowly ignoring them is the best that
+    #@beartype can do. Let's readdress this if and when @beartype begins deeply
+    #type-checking type variables (i.e., "typing.TypeVar" objects), which share
+    #a vague similarity with PEP 612-compliant "typing.ParamSpec" objects.
+
+    # Reduce PEP 612-compliant type hints that are instances of the low-level
+    # C-based "typing.ParamSpecArgs" or "typing.ParamSpecKwargs" types when
+    # annotating variadic positional or keyword arguments with syntax resembling
+    # "*args: P.args" or "**kwargs: P.kwargs" to an arbitrary ignorable hint.
+    HintSignParamSpecArgs:   reduce_hint_pep612_args,
+    HintSignParamSpecKwargs: reduce_hint_pep612_kwargs,
+
+    # ..................{ PEP 613                            }..................
+    # Reduce PEP 613-compliant "typing.TypeAlias" type hints to an arbitrary
+    # ignorable type hint *AND* emit a non-fatal deprecation warning.
+    #
+    # Note that, to ensure that one such warning is emitted for each such hint,
+    # this reducer is intentionally uncached rather than cached.
+    HintSignTypeAlias: reduce_hint_pep613,
+
+    # ..................{ PEP (646|692)                      }..................
+    # Reduce PEP 646- or 692-compliant "typing.Unpack[...]" type hints to
     # either:
-    # * If this hint annotates the return of some callable, reduce this hint to
-    #   the standard "bool" type.
+    # * If this hint annotates the variadic positional argument of some
+    #   callable *AND* this is a PEP 692-compliant
+    #   "typing.Unpack[{SomeTypedDict}]" for "{SomeTypedDict}" some user-defined
+    #   PEP 589-compliant "typing.TypedDict" subclass, the ignorable "object"
+    #   superclass.
+    # * Else if this is a PEP 646-compliant "typing.Unpack[TypeVarTuple(...)]"
+    #   for some user-defined PEP 646-compliant type variable tuple
+    #   "TypeVarTuple(...)", the ignorable "object" superclass.
+    # * Else, raise an exception.
+    HintSignUnpack: reduce_hint_pep646692_unpack,
+
+    # ..................{ PEP 647                            }..................
+    # Reduce PEP 647-compliant "typing.TypeGuard[...]" type hints to either:
+    # * If this hint annotates the return of some callable, the "bool" type.
     # * Else, raise an exception.
     HintSignTypeGuard: reduce_hint_pep647,
 
     # ..................{ PEP 673                            }..................
-    # If this hint is a PEP 673-compliant "typing.Self" type hint, either:
-    # * If @beartype is currently decorating a class, reduce this hint to the
-    #   most deeply nested class on the passed type stack.
+    # Reduce PEP 673-compliant "typing.Self" type hints to either:
+    # * If @beartype is currently decorating a class, the most deeply nested
+    #   class on the passed type stack.
     # * Else, raise an exception.
     HintSignSelf: reduce_hint_pep673,
 }
@@ -523,7 +818,7 @@ decision contextually depends on the currently decorated callable and thus
 *cannot* be efficiently memoized by the :func:`.callable_cached` decorator).
 
 See Also
-----------
+--------
 :data:`._HINT_SIGN_TO_REDUCE_HINT_CACHED`
     Further details.
 '''
