@@ -16,7 +16,8 @@ from beartype.typing import (
     Any,
     Optional,
 )
-from beartype._check.checkcall import BeartypeCall
+from beartype._cave._cavemap import NoneTypeOr
+from beartype._check.metadata.metadecor import BeartypeDecorMeta
 from beartype._check.convert.convcoerce import (
     coerce_func_hint_root,
     coerce_hint_any,
@@ -28,6 +29,7 @@ from beartype._data.error.dataerrmagic import EXCEPTION_PLACEHOLDER
 from beartype._data.func.datafuncarg import ARG_NAME_RETURN
 from beartype._data.hint.datahinttyping import TypeStack
 from beartype._util.cache.map.utilmapbig import CacheUnboundedStrong
+from beartype._util.func.arg.utilfuncargiter import ArgKind
 from beartype._util.hint.pep.proposal.pep484585.utilpep484585func import (
     reduce_hint_pep484585_func_return)
 from beartype._util.hint.utilhinttest import is_hint_ignorable
@@ -36,11 +38,12 @@ from beartype._util.hint.utilhinttest import is_hint_ignorable
 #FIXME: Unit test us up, please.
 def sanify_hint_root_func(
     # Mandatory parameters.
+    decor_meta: BeartypeDecorMeta,
     hint: object,
     pith_name: str,
-    bear_call: BeartypeCall,
 
     # Optional parameters.
+    arg_kind: Optional[ArgKind] = None,
     exception_prefix: str = EXCEPTION_PLACEHOLDER,
 ) -> object:
     '''
@@ -81,20 +84,25 @@ def sanify_hint_root_func(
 
     Parameters
     ----------
+    decor_meta : BeartypeDecorMeta
+        Decorated callable directly annotated by this hint.
     hint : object
         Possibly PEP-noncompliant root type hint to be sanified.
-    cls_stack : TypeStack, optional
-        **Type stack** (i.e., either a tuple of the one or more
-        :func:`beartype.beartype`-decorated classes lexically containing the
-        class variable or method annotated by this hint *or* :data:`None`).
-        Defaults to :data:`None`.
     pith_name : str
         Either:
 
         * If this hint annotates a parameter, the name of that parameter.
         * If this hint annotates the return, ``"return"``.
-    bear_call : BeartypeCall
-        Decorated callable directly annotated by this hint.
+    arg_kind : Optional[ArgKind]
+        Either:
+
+        * If this hint annotates a parameter, that parameter's **kind** (i.e.,
+          :class:`.ArgKind` enumeration member conveying the syntactic class of
+          that parameter, constraining how the callable declaring that parameter
+          requires that parameter to be passed).
+        * If this hint annotates the return, :data:`None`.
+
+        Defaults to :data:`None`.
     exception_prefix : str, optional
         Human-readable label prefixing exception messages raised by this
         function. Defaults to :data:`EXCEPTION_PLACEHOLDER`.
@@ -116,39 +124,44 @@ def sanify_hint_root_func(
         * A PEP-noncompliant type hint.
         * A supported PEP-compliant type hint.
     '''
+    assert isinstance(arg_kind, NoneTypeOr[ArgKind]), (
+        f'{repr(arg_kind)} neither argument kind nor "None".')
 
     #!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
     # CAUTION: Synchronize with the sanify_hint_root_statement() sanitizer.
     #!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
 
-    # PEP-compliant type hint coerced (i.e., permanently converted in the
-    # annotations dunder dictionary of the passed callable) from this possibly
+    #FIXME: This attempt at mutating the "__annotations__" dunder dictionary is
+    #likely to fail under Python >= 3.13. Contemplate alternatives, please.
+    # PEP-compliant type hint coerced from this possibly (i.e., permanently
+    # converted in the annotations dunder dictionary of the passed callable)
     # PEP-noncompliant type hint if this hint is coercible *OR* this hint as is
     # otherwise. Since the passed hint is *NOT* necessarily PEP-compliant,
     # perform this coercion *BEFORE* validating this hint to be PEP-compliant.
-    hint = bear_call.func_wrappee.__annotations__[pith_name] = (
-        coerce_func_hint_root(
-            hint=hint,
-            pith_name=pith_name,
-            bear_call=bear_call,
-            exception_prefix=exception_prefix,
-        )
+    hint = decor_meta.func_arg_name_to_hint[pith_name] = coerce_func_hint_root(
+        decor_meta=decor_meta,
+        hint=hint,
+        pith_name=pith_name,
+        exception_prefix=exception_prefix,
     )
 
-    # If this hint annotates the return, reduce this hint to a simpler hint if
-    # this hint is either PEP 484- or 585-compliant *AND* requires reduction
-    # (e.g., from "Coroutine[None, None, str]" to just "str"). Raise an
-    # exception if this hint is contextually invalid for this callable (e.g.,
-    # generator whose return is *NOT* annotated as "Generator[...]").
+    # If this hint annotates the return, then (in order):
+    # * If this hint is contextually invalid for this callable (e.g., generator
+    #   whose return is not annotated as "Generator[...]"), raise an exception.
+    # * If this hint is either PEP 484- or 585-compliant *AND* requires
+    #   reduction (e.g., from "Coroutine[None, None, str]" to just "str"),
+    #   reduce this hint accordingly.
     #
     # Perform this reduction *BEFORE* performing subsequent tests (e.g., to
-    # accept "Coroutine[None, None, typing.NoReturn]" as expected).
-    #
-    # Note that this logic *ONLY* pertains to callables (rather than statements)
-    # and is thus *NOT* performed by the sanify_hint_root_statement() sanitizer.
+    # accept "Coroutine[None, None, typing.NoReturn]" as expected). Note that
+    # this logic *ONLY* pertains to callables (rather than statements) and is
+    # thus *NOT* performed by the sanify_hint_root_statement() sanitizer.
     if pith_name == ARG_NAME_RETURN:
         hint = reduce_hint_pep484585_func_return(
-            func=bear_call.func_wrappee, exception_prefix=exception_prefix)
+            func=decor_meta.func_wrappee,
+            func_arg_name_to_hint=decor_meta.func_arg_name_to_hint,
+            exception_prefix=exception_prefix,
+        )
     # Else, this hint annotates a parameter.
 
     # Reduce this hint to a lower-level PEP-compliant type hint if this hint is
@@ -177,8 +190,10 @@ def sanify_hint_root_func(
     # optimize memoization efficiency and circumvent memoization warnings.
     hint = reduce_hint(
         hint=hint,
-        conf=bear_call.conf,
-        cls_stack=bear_call.cls_stack,
+        conf=decor_meta.conf,
+        decor_meta=decor_meta,
+        arg_kind=arg_kind,
+        cls_stack=decor_meta.cls_stack,
         pith_name=pith_name,
         exception_prefix=exception_prefix,
     )
