@@ -21,7 +21,7 @@ from beartype.roar import (
 )
 from beartype.roar._roarexc import _BeartypeUtilCallableScopeNotFoundException
 from beartype.typing import Optional
-from beartype._check.checkcall import BeartypeCall
+from beartype._check.metadata.metadecor import BeartypeDecorMeta
 from beartype._check.forward.fwdscope import BeartypeForwardScope
 from beartype._data.hint.datahinttyping import TypeException
 from beartype._data.kind.datakinddict import DICT_EMPTY
@@ -31,16 +31,19 @@ from beartype._util.func.utilfuncscope import (
     get_func_globals,
     get_func_locals,
 )
-from beartype._util.module.utilmodget import get_object_module_name
+from beartype._util.module.utilmodget import get_object_module_name_or_none
 from beartype._util.py.utilpyversion import IS_PYTHON_AT_MOST_3_9
+from beartype._util.text.utiltextansi import color_hint
+from beartype._util.utilobject import get_object_name
 from builtins import __dict__ as func_builtins  # type: ignore[attr-defined]
+from traceback import format_exc
 
 # ....................{ RESOLVERS                          }....................
 #FIXME: Unit test us up, please.
 def resolve_hint(
     # Mandatory parameters.
     hint: str,
-    bear_call: BeartypeCall,
+    decor_meta: BeartypeDecorMeta,
 
     # Optional parameters.
     exception_cls: TypeException = BeartypeDecorHintForwardRefException,
@@ -63,7 +66,7 @@ def resolve_hint(
     ----------
     hint : str
         Stringified type hint to be resolved.
-    bear_call : BeartypeCall
+    decor_meta : BeartypeDecorMeta
         Decorated callable annotated by this hint.
     exception_cls : Type[Exception], optional
         Type of exception to be raised in the event of a fatal error. Defaults
@@ -94,28 +97,28 @@ def resolve_hint(
         Python >= 3.10.
     '''
     assert isinstance(hint, str), f'{repr(hint)} not stringified type hint.'
-    assert isinstance(bear_call, BeartypeCall), (
-        f'{repr(bear_call)} not @beartype call.')
+    assert isinstance(decor_meta, BeartypeDecorMeta), (
+        f'{repr(decor_meta)} not @beartype call.')
     # print(f'Resolving stringified type hint {repr(hint)}...')
 
     # ..................{ LOCALS                             }..................
     # Decorated callable and metadata associated with that callable, localized
     # to improve both readability and negligible efficiency when accessed below.
-    func = bear_call.func_wrappee_wrappee
+    func = decor_meta.func_wrappee_wrappee
 
     # If the frozen set of the unqualified names of all parent callables
     # lexically containing this decorated callable has yet to be decided...
-    if bear_call.func_wrappee_scope_nested_names is None:
+    if decor_meta.func_wrappee_scope_nested_names is None:
         # Decide this frozen set as either...
-        bear_call.func_wrappee_scope_nested_names = (
+        decor_meta.func_wrappee_scope_nested_names = (
             # If the decorated callable is nested, the non-empty frozen set of
             # the unqualified names of all parent callables lexically containing
             # this nested decorated callable (including this nested decorated
             # callable itself);
             frozenset(func.__qualname__.rsplit(sep='.'))
-            if bear_call.func_wrappee_is_nested else
-            # Else, the decorated callable is a global function. In this
-            # case, the empty frozen set.
+            if decor_meta.func_wrappee_is_nested else
+            # Else, the decorated callable is a global function. In this case,
+            # the empty frozen set.
             FROZENSET_EMPTY
         )
     # Else, this frozen set has already been decided.
@@ -225,7 +228,7 @@ def resolve_hint(
     # * This edge case is both trivial and efficient to support.
     #
     # tl;dr: Preserve this hint for disambiguity by reducing to a noop.
-    if hint in bear_call.func_wrappee_scope_nested_names:  # type: ignore[operator]
+    if hint in decor_meta.func_wrappee_scope_nested_names:  # type: ignore[operator]
         return hint
     # Else, this hint is *NOT* the unqualified name of a parent callable or
     # class of the decorated callable. In this case, this hint *COULD* require
@@ -245,20 +248,13 @@ def resolve_hint(
     #         return 'This is hashable, yo.'
 
     # If the forward scope of the decorated callable has yet to be decided...
-    if bear_call.func_wrappee_scope_forward is None:
+    if decor_meta.func_wrappee_scope_forward is None:
         # Localize metadata for readability and efficiency. Look. Just do it.
-        cls_stack = bear_call.cls_stack
-
-        # Fully-qualified name of the module declaring the decorated callable,
-        # which also serves as the name of this module and thus global scope.
-        func_module_name = get_object_module_name(func)  # type: ignore[operator]
-
-        # Global scope of the decorated callable.
-        func_globals = get_func_globals(func=func, exception_cls=exception_cls)
+        cls_stack = decor_meta.cls_stack
 
         # If the decorated callable is nested (rather than global) and thus
         # *MAY* have a non-empty local nested scope...
-        if bear_call.func_wrappee_is_nested:
+        if decor_meta.func_wrappee_is_nested:
             # Attempt to...
             try:
                 # Local scope of the decorated callable, localized to improve
@@ -315,7 +311,7 @@ def resolve_hint(
                     # additional frames that we could technically ignore. These
                     # include:
                     # * The call to the parent
-                    #   beartype._check.checkcall.BeartypeCall.reinit() method.
+                    #   beartype._check.metadata.metadecor.BeartypeDecorMeta.reinit() method.
                     # * The call to the parent @beartype.beartype() decorator.
                     #
                     # Why? Because the @beartype codebase has been sufficiently
@@ -419,14 +415,11 @@ def resolve_hint(
                 # Ergo, the local scopes for parent classes of this class
                 # (including the root decorated class) are irrelevant.
                 cls_curr_locals = get_type_locals(
-                    cls=cls_curr,
-                    exception_cls=exception_cls,
-                )
+                    cls=cls_curr, exception_cls=exception_cls)
 
-                # Forcefully merge this local scope into the current
-                # local scope, implicitly overwriting any locals of the
-                # same name. Class locals necessarily assume lexical
-                # precedence over:
+                # Forcefully merge this local scope into the current local
+                # scope, implicitly overwriting any locals of the same name.
+                # Class locals necessarily assume lexical precedence over:
                 # * These classes themselves.
                 # * Locals defined by higher-level parent classes.
                 # * Locals defined by closures defining these classes.
@@ -438,6 +431,38 @@ def resolve_hint(
         else:
             func_locals = DICT_EMPTY
 
+        # Fully-qualified name of the module declaring the decorated callable if
+        # that callable defines the "__module__" dunder attribute *OR* "None"
+        # (i.e., if that callable fails to define that attribute).
+        func_module_name = get_object_module_name_or_none(func)  # type: ignore[operator]
+
+        # If the decorated callable fails to define the "__module__" dunder
+        # attribute, there exists *NO* known module against which to resolve
+        # this stringified type hint. Since this implies that this hint *CANNOT*
+        # be reliably resolved, raise an exception.
+        #
+        # Note that this is an uncommon edge case that nonetheless occurs
+        # frequently enough to warrant explicit handling by raising a more
+        # human-readable exception than would otherwise be raised (e.g., if the
+        # lower-level get_object_module_name() getter were called instead
+        # above). Notably, the third-party "markdown-exec" package behaved like
+        # this -- and possibly still does. See also:
+        #     https://github.com/beartype/beartype/issues/381
+        if not func_module_name:
+            raise exception_cls(
+                f'{exception_prefix}forward reference type hint "{hint}" '
+                f'unresolvable, as '
+                f'"{get_object_name(func)}.__module__" dunder attribute '
+                f'undefined (e.g., due to {repr(func)} being defined only '
+                f'dynamically in-memory). '
+                f'So much bad stuff is happening here all at once that '
+                f'@beartype can no longer cope with the explosion in badness.'
+            )
+        # Else, the decorated callable defines that attribute.
+
+        # Global scope of the decorated callable.
+        func_globals = get_func_globals(func=func, exception_cls=exception_cls)
+
         # Forward scope compositing this global and local scope of the decorated
         # callable as well as dynamically replacing each unresolved attribute of
         # this stringified type hint with a forward reference proxy resolving
@@ -469,7 +494,7 @@ def resolve_hint(
         # eccentricity would be less efficient and trivial than simply
         # initializing this forward scope with all builtin attributes, we prefer
         # the current (admittedly sus af) approach. Do not squint at this.
-        bear_call.func_wrappee_scope_forward = BeartypeForwardScope(
+        decor_meta.func_wrappee_scope_forward = BeartypeForwardScope(
             scope_dict=func_builtins, scope_name=func_module_name)
 
         # Composite this global and local scope into this forward scope (in that
@@ -478,9 +503,9 @@ def resolve_hint(
         # each global and then local attribute of the same name. Since locals
         # *ALWAYS* assume precedence over globals *ALWAYS* assume precedence
         # over builtins, order of operations is *EXTREMELY* significant here.
-        bear_call.func_wrappee_scope_forward.update(func_globals)
-        bear_call.func_wrappee_scope_forward.update(func_locals)
-        # print(f'Forward scope: {bear_call.func_wrappee_scope_forward}')
+        decor_meta.func_wrappee_scope_forward.update(func_globals)
+        decor_meta.func_wrappee_scope_forward.update(func_locals)
+        # print(f'Forward scope: {decor_meta.func_wrappee_scope_forward}')
     # Else, this forward scope has already been decided.
     #
     # In either case, this forward scope should now all have been decided.
@@ -489,7 +514,7 @@ def resolve_hint(
     # Attempt to resolve this stringified type hint into a non-string type hint
     # against both the global and local scopes of the decorated callable.
     try:
-        hint_resolved = eval(hint, bear_call.func_wrappee_scope_forward)
+        hint_resolved = eval(hint, decor_meta.func_wrappee_scope_forward)
         # print(f'Resolved stringified type hint {repr(hint)} to {repr(hint_resolved)}...')
     # If doing so failed for *ANY* reason whatsoever...
     except Exception as exception:
@@ -583,17 +608,20 @@ def resolve_hint(
             # Human-readable message to be raised.
             exception_message = (
                 f'{exception_prefix}stringified type hint '
-                f'{repr(hint)} syntactically invalid '
-                f'(i.e., {repr(exception)}).'
+                f'{color_hint(text=repr(hint), is_color=decor_meta.conf.is_color)} '
+                f'invalid, as attempting to dynamically import '
+                f'the attribute referred to by this hint raises:\n'
+                f'{format_exc()}'
             )
 
             # If the beartype configuration associated with the decorated
             # callable enabled debugging, append debug-specific metadata to this
             # message.
-            if bear_call.conf.is_debug:
+            # if True:
+            if decor_meta.conf.is_debug:
                 exception_message += (
-                    f' Composite global and local scope enclosing this hint:\n\n'
-                    f'{repr(bear_call.func_wrappee_scope_forward)}'
+                    f'\nComposite global and local scope enclosing this hint:\n\n'
+                    f'{repr(decor_meta.func_wrappee_scope_forward)}'
                 )
             # Else, the beartype configuration associated with the decorated
             # callable disabled debugging. In this case, avoid appending
