@@ -21,7 +21,10 @@ callers.
 
 #FIXME: [DOCOS] Document all newly defined configuration parameters in our
 #reST-formatted docos, please -- including:
+#* "claw_decoration_position_funcs".
+#* "claw_decoration_position_types".
 #* "claw_is_pep526".
+#* "claw_skip_package_names".
 #* "hint_overrides".
 #* "violation_door_type".
 #* "violation_param_type".
@@ -32,14 +35,14 @@ callers.
 
 # ....................{ IMPORTS                            }....................
 from beartype.roar._roarwarn import (
-    _BeartypeConfReduceDecoratorExceptionToWarningDefault,
-)
+    _BeartypeConfReduceDecoratorExceptionToWarningDefault)
 from beartype.typing import (
     TYPE_CHECKING,
     Dict,
     Optional,
 )
 from beartype._conf.confenum import (
+    BeartypeDecorationPosition,
     BeartypeStrategy,
     BeartypeViolationVerbosity,
 )
@@ -55,6 +58,7 @@ from beartype._conf.conftest import (
 from beartype._conf._confget import get_is_color
 from beartype._data.hint.datahinttyping import (
     BoolTristateUnpassable,
+    CollectionStrs,
     DictStrToAny,
     TypeException,
     TypeWarning,
@@ -63,7 +67,7 @@ from beartype._data.func.datafuncarg import ARG_VALUE_UNPASSED
 from beartype._util.utilobject import get_object_type_basename
 from threading import Lock
 
-# ....................{ CLASSES                            }....................
+# ....................{ DATACLASSES                        }....................
 class BeartypeConf(object):
     '''
     **Beartype configuration** (i.e., self-caching dataclass encapsulating all
@@ -73,12 +77,29 @@ class BeartypeConf(object):
 
     Attributes
     ----------
+    _claw_decoration_position_funcs : BeartypeDecorationPosition
+        **Import hook callable decorator position** (i.e., location to which the
+        :func:`beartype.beartype` decorator will be implicitly injected into
+        existing chains of one or more decorators decorating functions and
+        methods defined by modules imported under :mod:`beartype.claw` import
+        hooks).
+    _claw_decoration_position_types : BeartypeDecorationPosition
+        **Import hook class decorator position** (i.e., location to which the
+        :func:`beartype.beartype` decorator will be implicitly injected into
+        existing chains of one or more decorators decorating classes defined by
+        modules imported under :mod:`beartype.claw` import hooks).
     _claw_is_pep526 : bool
         :data:`True` only if type-checking **annotated variable assignments**
         (i.e., :pep:`526`-compliant assignments to local, global, class, and
         instance variables annotated by type hints) when importing modules
-        under import hooks published by the :mod:`beartype.claw` subpackage. See
-        also the :meth:`__new__` method docstring.
+        under import hooks published by the :mod:`beartype.claw` subpackage.
+    _claw_skip_package_names: Collection[str], optional
+        Collection of the absolute names of all packages and modules to be
+        **skipped** (i.e., blacklisted, excluded, ignored, omitted) rather than
+        runtime type-checked by import hooks published by the
+        :mod:`beartype.claw` subpackage -- especially the otherwise fragile
+        :mod:`beartype.claw.beartype_all` import hook, which subjects *all*
+        packages to runtime type-checking by default.
     _conf_args : tuple
         Tuple of the values of *all* possible keyword parameters (in arbitrary
         order) configuring this configuration.
@@ -143,7 +164,7 @@ class BeartypeConf(object):
         member) with which to implement all type-checks in the wrapper function
         dynamically generated by the :func:`beartype.beartype` decorator for
         the decorated callable.
-    violation_door_type : TypeException
+    _violation_door_type : TypeException
         **DOOR violation type** (i.e., type of exception raised by the
         :func:`beartype.door.die_if_unbearable` type-checker when the object
         passed to that type-checker violates the type hint passed to that
@@ -181,9 +202,6 @@ class BeartypeConf(object):
     #!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
     # CAUTION: Synchronize this slots list with the implementations of:
     # * The __new__() dunder method.
-    # * The __eq__() dunder method.
-    # * The __hash__() dunder method.
-    # * The __repr__() dunder method.
     # CAUTION: Subclasses declaring uniquely subclass-specific instance
     # variables *MUST* additionally slot those variables. Subclasses violating
     # this constraint will be usable but unslotted, which defeats our purposes.
@@ -194,7 +212,10 @@ class BeartypeConf(object):
     # cache dunder methods. Slotting has been shown to reduce read and write
     # costs by approximately ~10%, which is non-trivial.
     __slots__ = (
+        '_claw_decoration_position_funcs',
+        '_claw_decoration_position_types',
         '_claw_is_pep526',
+        '_claw_skip_package_names',
         '_conf_args',
         '_conf_kwargs',
         '_hash',
@@ -219,7 +240,10 @@ class BeartypeConf(object):
     # Squelch false negatives from mypy. This is absurd. This is mypy. See:
     #     https://github.com/python/mypy/issues/5941
     if TYPE_CHECKING:
+        _claw_decoration_position_funcs: BeartypeDecorationPosition
+        _claw_decoration_position_types: BeartypeDecorationPosition
         _claw_is_pep526: bool
+        _claw_skip_package_names: CollectionStrs
         _conf_args: tuple
         _conf_kwargs: DictStrToAny
         _hash: int
@@ -258,9 +282,14 @@ class BeartypeConf(object):
 
         # Uncomment us when implementing O(n) type-checking, please.
         # check_time_max_multiplier: Union[int, None] = 1000,
+        claw_decoration_position_funcs: BeartypeDecorationPosition = (
+            BeartypeDecorationPosition.LAST),
+        claw_decoration_position_types: BeartypeDecorationPosition = (
+            BeartypeDecorationPosition.LAST),
         claw_is_pep526: bool = True,
+        claw_skip_package_names: CollectionStrs = (),
         hint_overrides: BeartypeHintOverrides = BEARTYPE_HINT_OVERRIDES_EMPTY,
-        is_color: BoolTristateUnpassable = ARG_VALUE_UNPASSED,
+        is_color: BoolTristateUnpassable = ARG_VALUE_UNPASSED,  # pyright: ignore
         is_debug: bool = False,
         is_pep484_tower: bool = False,
         strategy: BeartypeStrategy = BeartypeStrategy.O1,
@@ -299,20 +328,21 @@ class BeartypeConf(object):
             total running time of the active Python interpreter exceeds this
             integer multiplied by the running time consumed by both the current
             type-check and all prior type-checks *and* the caller also passed a
-            non-default ``strategy``) *or* ``None`` if :mod:`beartype` should
-            never prematurely halt runtime type-checks.
+            non-default ``strategy``) *or* :data:`None` if :mod:`beartype`
+            should never prematurely halt runtime type-checks.
 
-            Increase this quantity to type-check more container items at a cost
-            of decreasing application responsiveness. Likewise, decrease this
-            quantity to increase application responsiveness at a cost of
-            type-checking fewer container items.
+            Increasing this integer increases the number of container items that
+            :mod:`beartype` type-checks at a cost of decreasing application
+            responsiveness. Likewise, decreasing this integer increases
+            application responsiveness at a cost of decreasing the number of
+            container items that :mod:`beartype` type-checks.
 
             Ignored when ``strategy`` is :attr:`BeartypeStrategy.O1`, as that
             strategy is already effectively instantaneous; imposing deadlines
             and thus bureaucratic bookkeeping on that strategy would only
             reduce its efficiency for no good reason, which is a bad reason.
 
-            Defaults to 1000, in which case a maximum of %0.1 of the total
+            Defaults to 1000, in which case a maximum of 0.10% of the total
             runtime of the active Python process will be devoted to performing
             non-constant :mod:`beartype` type-checks over container items. This
             default has been carefully tuned to strike a reasonable balance
@@ -320,19 +350,19 @@ class BeartypeConf(object):
             typically enabling smaller containers to be fully type-checked
             without noticeably impacting codebase performance.
 
-            *Theory time.* Let:
+            **Theory time.** Let:
 
-            * ``T`` be the total time this interpreter has been running.
-            * ``b`` be the total time :mod:`beartype` has spent type-checking in
-              this interpreter.
+            * :math:`T` be the total time this interpreter has been running.
+            * :math:``b` be the total time :mod:`beartype` has spent
+              type-checking in this interpreter.
 
-            Clearly, ``b <= T``. Generally, ``b <<<<<<< T`` (i.e., type-checks
-            consume much less time than the total time consumed by the process).
-            However, it's all too easy to exhibit worst-case behaviour of
-            ``b ~= T`` (i.e., type-checks consume most of the total time). How?
-            By passing the :func:`beartype.door.is_bearable` tester an absurdly
-            large nested container subject to the non-default ``strategy`` of
-            :attr:`BeartypeStrategy.On`.
+            Clearly, :math:`b <= T`. Generally, :math:`b <<<<<<< T` (i.e.,
+            type-checks consume much less time than the total time consumed by
+            the process). However, it's all too easy to exhibit worst-case
+            behaviour of :math:`b ~= T` (i.e., type-checks consume most of the
+            total time). How? By passing the :func:`beartype.door.is_bearable`
+            tester an absurdly large nested container subject to the non-default
+            ``strategy`` of :attr:`BeartypeStrategy.On`.
 
             This deadline multiplier mitigates that worst-case behaviour.
             Specifically, :mod:`beartype` will prematurely halt any iterative
@@ -341,20 +371,94 @@ class BeartypeConf(object):
             .. code-block:: python
 
                b * check_time_max_multiplier >= T
+        claw_decoration_position_funcs : BeartypeDecorationPosition, optional
+            **Import hook callable decorator position** (i.e., location to which
+            the :func:`beartype.beartype` decorator will be implicitly injected
+            into existing chains of one or more decorators decorating functions
+            and methods defined by modules imported under :mod:`beartype.claw`
+            import hooks). Defaults to :attr:`BeartypeDecorationPosition.LAST`.
+
+            Modifying this configures import hooks to inject
+            :func:`beartype.beartype` as the first (rather than last) decorator
+            for callables. If your codebase requires this, consider submitting
+            an issue to the :mod:`beartype` issue tracker. Ideally, the
+            :func:`beartype.beartype` decorator should be order-invariant with
+            respect to decorator chaining and thus support decoration in *any*
+            position – including the default last position: e.g.,
+
+            .. code-block:: python
+
+               # Registering this import hook...
+               from beartype import BeartypeConf, BeartypeDecorationPosition
+               from beartype.claw import beartype_this_package
+               beartype_this_package(conf=BeartypeConf(
+                   claw_decoration_position_funcs=(
+                       BeartypeDecorationPosition.FIRST)))
+
+               # ...transforms chains of function decorators like this...
+               from functools import cache
+               @cache
+               def chad_func() -> int:
+                   return 42
+
+               # ...into chains of function decorators like this.
+               from beartype import beartype
+               from functools import cache
+               @cache
+               @beartype  # <-- @beartype decorates first rather than last! \\o/
+               def chad_func() -> int:
+                   return 42
+        claw_decoration_position_types : BeartypeDecorationPosition, optional
+            **Import hook class decorator position** (i.e., location to which
+            the :func:`beartype.beartype` decorator will be implicitly injected
+            into existing chains of one or more decorators decorating classes
+            defined by modules imported under :mod:`beartype.claw` import
+            hooks). Defaults to :attr:`BeartypeDecorationPosition.LAST`.
+
+            Modifying this configures import hooks to inject
+            :func:`beartype.beartype` as the first (rather than last) decorator
+            for classes. If your codebase requires this, consider submitting an
+            issue to the :mod:`beartype` issue tracker. Ideally, the
+            :func:`beartype.beartype` decorator should be order-invariant with
+            respect to decorator chaining and thus support decoration in *any*
+            position – including the default last position: e.g.,
+
+            .. code-block:: python
+
+               # Registering this import hook...
+               from beartype import BeartypeConf, BeartypeDecorationPosition
+               from beartype.claw import beartype_this_package
+               beartype_this_package(conf=BeartypeConf(
+                   claw_decoration_position_types=(
+                       BeartypeDecorationPosition.FIRST)))
+
+               # ...transforms chains of class decorators like this...
+               from dataclasses import dataclass
+               @dataclass
+               class ClassyData(object):
+                   integral_datum: int
+
+               # ...into chains of class decorators like this.
+               from beartype import beartype
+               from dataclasses import dataclass
+               @dataclass
+               @beartype  # <-- @beartype decorates first rather than last! \\o/
+               class ClassyData(object):
+                   integral_datum: int
         claw_is_pep526 : bool, optional
             :data:`True` only if implicitly type-checking **annotated variable
             assignments** (i.e., :pep:`526`-compliant assignments to local,
-            global, class, and instance variables annotated by type hints) when
-            importing modules under import hooks published by the
-            :mod:`beartype.claw` subpackage by injecting calls to the
-            :func:`beartype.door.die_if_unbearable` function immediately *after*
-            those assignments in those modules. Enabling this boolean:
+            global, class, or instance variables annotated by type hints) when
+            importing modules under :mod:`beartype.claw` import hooks by
+            injecting calls to the :func:`beartype.door.die_if_unbearable`
+            function immediately *after* those assignments in those modules.
+            Enabling this boolean:
 
             * Effectively augments :mod:`beartype` into a full-blown **hybrid
               runtime-static type-checker** (i.e., performing both standard
               runtime type-checking *and* non-standard static type-checking at
               runtime).
-            * Adds negligible runtime overhead to all annotated variable
+            * Adds mostly negligible runtime overhead to all annotated variable
               assignments in all modules imported under those import hooks.
               Although the *individual* cost of this overhead for any given
               assignment is negligible, the *aggregate* cost across all such
@@ -362,8 +466,30 @@ class BeartypeConf(object):
 
             Ideally, this boolean should only be disabled for a small subset of
             performance-sensitive modules *after* profiling those modules to
-            suffer performance regressions under import hooks published by the
-            :mod:`beartype.claw` subpackage. Defaults to :data:`True`.
+            suffer performance regressions under :mod:`beartype.claw` import
+            hooks. Defaults to :data:`True`.
+        claw_skip_package_names: Collection[str], optional
+            Collection of the absolute names of all packages and modules to be
+            **skipped** (i.e., blacklisted, excluded, ignored, omitted) rather
+            than runtime type-checked by import hooks published by the
+            :mod:`beartype.claw` subpackage -- especially the otherwise fragile
+            :mod:`beartype.claw.beartype_all` import hook, which subjects *all*
+            packages to runtime type-checking by default.
+
+            Import hooks published by the :mod:`beartype.claw` subpackage will
+            avoid applying runtime type-checking to *any* package or module:
+
+            * Whose absolute name is directly listed in this iterable *or*...
+            * Which is a subpackage or submodule transitively residing in *any*
+              package or module whose absolute name is directly listed in this
+              iterable. Listing the name of a package in this iterable thus
+              suffices to skip both that package *and* all transitive
+              subpackages and submodules of that package in entirety. Individual
+              subpackages and submodules need *not* be explicitly listed
+              (e.g., ``claw_skip_package_names=('worst_package_evah',)`` skips
+              the ``worst_package_evah`` package in entirety).
+
+            Defaults to the empty tuple.
         hint_overrides : BeartypeHintOverrides
             **Type hint overrides** (i.e., frozen dictionary mapping from
             arbitrary source to target type hints), enabling callers to lie to
@@ -424,10 +550,10 @@ class BeartypeConf(object):
             enabling end users to enforce a global colour policy across their
             full app stack. If ``${BEARTYPE_IS_COLOR}`` is set to a different
             value than that of this parameter, this constructor emits a
-            non-fatal :class:`.BeartypeConfShellVarWarning` warning informing
-            the caller of this configuration conflict. To avoid this conflict,
-            open-source libraries are recommended to *not* pass this parameter;
-            ideally, *only* end user apps should pass this parameter.
+            non-fatal :class:`beartype.roar.BeartypeConfShellVarWarning` warning
+            informing the caller of this configuration conflict. To avoid this
+            conflict, open-source libraries are recommended to *not* pass this
+            parameter; ideally, *only* end user apps should pass this parameter.
 
             Effectively defaults to :data:`None`. Technically, this parameter
             defaults to a private magic constant *not* intended to be passed by
@@ -600,10 +726,6 @@ class BeartypeConf(object):
               ``"False"``, nor ``"None"``).
         '''
 
-        #!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
-        # CAUTION: Synchronize this tuple with the similar "self._conf_kwargs"
-        # dictionary defined below.
-        #!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
         # In a non-reentrant thread lock specific to beartype configurations...
         #
         # Note that this lock is potentially overkill and thus unnecessary.
@@ -618,9 +740,16 @@ class BeartypeConf(object):
             # value of the ${BEARTYPE_IS_COLOR} environment variable (if set).
             is_color = get_is_color(is_color)
 
+            #!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
+            # CAUTION: Synchronize this tuple with the similar
+            # "self._conf_kwargs" dictionary defined below.
+            #!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
             # Efficiently hashable tuple of these parameters in arbitrary order.
             conf_args = (
+                claw_decoration_position_funcs,
+                claw_decoration_position_types,
                 claw_is_pep526,
+                claw_skip_package_names,
                 hint_overrides,
                 is_color,
                 is_debug,
@@ -648,7 +777,10 @@ class BeartypeConf(object):
             # defined *AFTER* this method first attempts to efficiently reduce
             # to a noop by returning a previously instantiated configuration.
             conf_kwargs = dict(
+                claw_decoration_position_funcs=claw_decoration_position_funcs,
+                claw_decoration_position_types=claw_decoration_position_types,
                 claw_is_pep526=claw_is_pep526,
+                claw_skip_package_names=claw_skip_package_names,
                 hint_overrides=hint_overrides,
                 is_color=is_color,
                 is_debug=is_debug,
@@ -717,7 +849,13 @@ class BeartypeConf(object):
             # parameters from the "conf_kwargs" dictionary possibly modified by
             # the above call to the default_conf_kwargs() function rather than
             # the original passed values of these parameters.
+            self._claw_decoration_position_funcs = conf_kwargs[  # pyright: ignore
+                'claw_decoration_position_funcs']
+            self._claw_decoration_position_types = conf_kwargs[  # pyright: ignore
+                'claw_decoration_position_types']
             self._claw_is_pep526 = conf_kwargs['claw_is_pep526']  # pyright: ignore
+            self._claw_skip_package_names = conf_kwargs[
+                'claw_skip_package_names']  # pyright: ignore
             self._hint_overrides = conf_kwargs['hint_overrides']  # pyright: ignore
             self._is_color = conf_kwargs['is_color']  # pyright: ignore
             self._is_debug = conf_kwargs['is_debug']  # pyright: ignore
@@ -739,9 +877,17 @@ class BeartypeConf(object):
 
             # ..................{ CLASSIFY ~ more            }..................
             # If the value of the "warning_cls_on_decorator_exception" parameter
-            # is still the default private fake warning category established
-            # above, then the caller failed to explicitly pass a valid value. In
-            # this case...
+            # is the default private fake warning category established above,
+            # the caller failed to pass a valid value. In this case...
+            #
+            # Note that this default is intentionally handled manually here
+            # rather than in either the default_conf_kwargs_before() or
+            # default_conf_kwargs_after() functions called above. Why? Because
+            # the original default
+            # "_BeartypeConfReduceDecoratorExceptionToWarningDefault" *MUST* be
+            # preserved in the public "conf_kwargs" property to ensure that
+            # permutations of this configuration created via that property
+            # preserve the original default. (Look. It's complicated. I sigh!)
             if (
                 warning_cls_on_decorator_exception is
                 _BeartypeConfReduceDecoratorExceptionToWarningDefault
@@ -788,12 +934,12 @@ class BeartypeConf(object):
            # Arbitrary input beartype configuration.
            conf = BeartypeConf(is_color=True)
 
-           # Permuted output beartype configuration keyword dictionary.
-           kwargs = conf.kwargs.copy()
-           kwargs['is_debug'] = True
+           # New keyword dictionary permuted from this input.
+           conf_kwargs = conf.kwargs.copy()
+           conf_kwargs['is_debug'] = True
 
-           # Output beartype configuration permuted from this input.
-           debug_conf = BeartypeConf(**kwargs)
+           # New beartype configuration initialized by this dictionary.
+           debug_conf = BeartypeConf(**conf_kwargs)
 
         See Also
         --------
@@ -806,6 +952,16 @@ class BeartypeConf(object):
     # ..................{ PROPERTIES ~ options               }..................
     # Read-only public properties with which this configuration was originally
     # instantiated (as keyword-only parameters).
+    #
+    # Note that *ALL* of these properties could be automated away with a single
+    # sufficiently intelligent __getattr__() implementation. Indeed, we briefly
+    # attempted to do just that. So what happened? Static type-checkers.
+    # Although tedious and error-prone, the current approach of manually
+    # implementing one read-only public property for each keyword-only parameter
+    # has the distinct advantage of informing static type-checkers of the type
+    # hints annotating these properties. While automated and error-free, the
+    # __getattr__() approach destroyed that typing -- which then effectively
+    # broke backward compatibility with end users using static type-checkers.
 
     @property
     def hint_overrides(self) -> BeartypeHintOverrides:
@@ -861,26 +1017,6 @@ class BeartypeConf(object):
         return self._warning_cls_on_decorator_exception
 
     # ..................{ PROPERTIES ~ options : bool        }..................
-    # Read-only public properties with which this configuration was originally
-    # instantiated (as keyword-only parameters).
-
-    @property
-    def claw_is_pep526(self) -> bool:
-        '''
-        :data:`True` only if type-checking **annotated variable assignments**
-        (i.e., :pep:`526`-compliant assignments to local, global, class, and
-        instance variables annotated by type hints) when importing modules
-        under import hooks published by the :mod:`beartype.claw` subpackage.
-
-        See Also
-        --------
-        :meth:`__new__`
-            Further details.
-        '''
-
-        return self._claw_is_pep526
-
-
     @property
     def is_color(self) -> Optional[bool]:
         '''
@@ -935,6 +1071,77 @@ class BeartypeConf(object):
 
         return self._is_pep484_tower
 
+    # ..................{ PROPERTIES ~ options : claw        }..................
+    @property
+    def claw_decoration_position_funcs(self) -> BeartypeDecorationPosition:
+        '''
+        **Import hook callable decorator position** (i.e., location to which the
+        :func:`beartype.beartype` decorator will be implicitly injected into
+        existing chains of one or more decorators decorating functions and
+        methods defined by modules imported under :mod:`beartype.claw` import
+        hooks).
+
+        See Also
+        --------
+        :meth:`__new__`
+            Further details.
+        '''
+
+        return self._claw_decoration_position_funcs
+
+
+    @property
+    def claw_decoration_position_types(self) -> BeartypeDecorationPosition:
+        '''
+        **Import hook class decorator position** (i.e., location to which the
+        :func:`beartype.beartype` decorator will be implicitly injected into
+        existing chains of one or more decorators decorating classes defined by
+        modules imported under :mod:`beartype.claw` import hooks).
+
+        See Also
+        --------
+        :meth:`__new__`
+            Further details.
+        '''
+
+        return self._claw_decoration_position_types
+
+
+    @property
+    def claw_is_pep526(self) -> bool:
+        '''
+        :data:`True` only if type-checking **annotated variable assignments**
+        (i.e., :pep:`526`-compliant assignments to local, global, class, and
+        instance variables annotated by type hints) when importing modules
+        under import hooks published by the :mod:`beartype.claw` subpackage.
+
+        See Also
+        --------
+        :meth:`__new__`
+            Further details.
+        '''
+
+        return self._claw_is_pep526
+
+
+    @property
+    def claw_skip_package_names(self) -> CollectionStrs:
+        '''
+        Collection of the absolute names of all packages and modules to be
+        **skipped** (i.e., blacklisted, excluded, ignored, omitted) rather than
+        runtime type-checked by import hooks published by the
+        :mod:`beartype.claw` subpackage -- especially the otherwise fragile
+        :mod:`beartype.claw.beartype_all` import hook, which subjects *all*
+        packages to runtime type-checking by default.
+
+        See Also
+        --------
+        :meth:`__new__`
+            Further details.
+        '''
+
+        return self._claw_skip_package_names
+
     # ..................{ PROPERTIES ~ options : violation   }..................
     @property
     def violation_door_type(self) -> TypeException:
@@ -1093,6 +1300,9 @@ class BeartypeConf(object):
         # If machine-readable representation of this configuration has yet to be
         # computed...
         if self._repr is None:
+            # Avoid circular import dependencies.
+            from beartype._conf.confcommon import BEARTYPE_CONF_DEFAULT
+
             # Initialize this representation to the unqualified basename of the
             # class of this configuration.
             conf_repr = f'{get_object_type_basename(self)}('
@@ -1154,17 +1364,3 @@ memoization optimization, the only harmful consequences of a race condition
 between threads contending over this cache is a mildly inefficient (but
 otherwise harmless) repeated re-memoization of duplicate configurations.
 '''
-
-# ....................{ GLOBALS                            }....................
-# This global is intentionally defined *AFTER* all other attributes above, which
-# this global implicitly assumes to be defined.
-BEARTYPE_CONF_DEFAULT = BeartypeConf()
-'''
-**Default beartype configuration** (i.e., :class:`BeartypeConf` class
-instantiated with *no* parameters and thus default parameters), globalized to
-trivially optimize external access to this configuration throughout this
-codebase.
-
-Note that this global is *not* publicized to end users, who can simply
-instantiate ``BeartypeConf()`` to obtain the same singleton.
-'''
