@@ -14,7 +14,6 @@ This private submodule is *not* intended for importation by downstream callers.
 from beartype.typing import (
     Dict,
     ForwardRef,
-    FrozenSet,
 )
 from beartype._cave._cavefast import (
     ClassType,
@@ -23,13 +22,18 @@ from beartype._cave._cavefast import (
     MethodDecoratorBuiltinTypes,
     NoneType,
 )
+from beartype._data.hint.datahinttyping import (
+    DictStrToType,
+    FrozenSetTypes,
+    TupleTypes,
+)
 from collections.abc import (
     Set as SetABC,
 )
 from pathlib import Path
 
 # ....................{ TYPES ~ abc                        }....................
-TYPES_CONTEXTMANAGER_FAKE = (Path,)
+TYPES_CONTEXTMANAGER_FAKE: TupleTypes = (Path,)
 '''
 Tuple of all **fake context manager types** (i.e., types that erroneously
 masquerade as being context managers by defining fake ``__enter__()`` dunder
@@ -42,9 +46,10 @@ This set includes:
 '''
 
 
-TYPES_SET_OR_TUPLE = (SetABC, tuple)
+TYPES_SET_OR_TUPLE: TupleTypes = (tuple, SetABC,)
 '''
-2-tuple containing the superclasses of all frozen sets and tuples.
+Tuple of all **set and tuple types** (i.e., superclasses of all sets and
+tuples).
 
 Note that the :class:`Set` abstract base class (ABC) rather than the concrete
 :class:`set` subclass is intentionally listed here, as the concrete
@@ -64,23 +69,24 @@ Note that the :class:`Set` abstract base class (ABC) rather than the concrete
 # listed in descending order of real-world prevalence for negligible efficiency
 # gains when performing isinstance()-based tests against this tuple. These
 # include the types of *ALL*...
-TYPES_BEARTYPEABLE = (
+TYPES_BEARTYPEABLE: TupleTypes = (
     # Pure-Python unbound functions and methods.
     FunctionType,
     # Pure-Python classes.
     ClassType,
+) + (
     # C-based builtin method descriptors wrapping pure-Python unbound methods,
     # including class methods, static methods, and property methods.
-    MethodDecoratorBuiltinTypes,
+    MethodDecoratorBuiltinTypes
 )
 '''
 Tuple of all **beartypeable types** (i.e., types of all objects that may be
 decorated by the :func:`beartype.beartype` decorator).
 '''
 
-# ....................{ TYPES ~ module                     }....................
+# ....................{ TYPES ~ builtin                    }....................
 # Defined below by the _init() function.
-TYPE_BUILTIN_NAME_TO_TYPE: Dict[str, type] = None  # type: ignore[assignment]
+TYPE_BUILTIN_NAME_TO_TYPE: DictStrToType = None  # type: ignore[assignment]
 '''
 Dictionary mapping from the name of each **builtin type** (i.e., globally
 accessible C-based type implicitly accessible from all scopes and thus
@@ -89,13 +95,42 @@ requiring *no* explicit importation) to that type.
 
 
 # Defined below by the _init() function.
-TYPES_BUILTIN: FrozenSet[type] = None  # type: ignore[assignment]
+TYPES_BUILTIN: FrozenSetTypes = None  # type: ignore[assignment]
 '''
 Frozen set of all **builtin types** (i.e., globally accessible C-based types
 implicitly accessible from all scopes and thus requiring *no* explicit
 importation).
 '''
 
+
+TYPES_BUILTIN_SCALAR: FrozenSetTypes = frozenset((
+    bytes,
+    complex,
+    float,
+    int,
+    str,
+))
+'''
+Frozen set of all **builtin scalar types** (i.e., globally accessible C-based
+types whose instances are scalar values).
+'''
+
+# ....................{ TYPES ~ exception                  }....................
+TYPES_EXCEPTION_NAMESPACE = (
+    # Standard exception raised when attempting to access a currently undefined
+    # attribute of a defined object via "." syntax (e.g., an undefined attribute
+    # "obj.attr" of a defined object "obj").
+    AttributeError,
+    # Standard exception raised when attempting to access an object defined in
+    # neither the current local or global scopes.
+    NameError,
+)
+'''
+Tuple of all **standard scope exception types** (i.e., types of all standard
+exceptions raised when a **namespace** (e.g., global or local scope, class or
+object dictionary) fails to define a given attribute or name).
+'''
+
 # ....................{ PEP ~ (484|585)                    }....................
 TYPES_PEP484585_REF = (str, ForwardRef)
 '''
