@@ -24,9 +24,12 @@ from beartype.typing import (
     AbstractSet,
     Any,
     Callable,
+    Collection,
     Dict,
     ForwardRef,
+    FrozenSet,
     Iterable,
+    Iterator,
     List,
     Literal,
     Mapping,
@@ -44,6 +47,7 @@ from beartype._cave._cavefast import (
 )
 from beartype._data.hint.pep.sign.datapepsigncls import HintSign
 from beartype._data.func.datafuncarg import ARG_VALUE_UNPASSED
+from beartype._util.py.utilpyversion import IS_PYTHON_AT_LEAST_3_10
 from collections.abc import Callable as CallableABC
 from importlib.abc import PathEntryFinder
 from pathlib import Path
@@ -277,7 +281,7 @@ PEP-compliant type hint matching the standard type of the single positional
 argument accepted by the ``__getitem__` dunder method.
 '''
 
-# ....................{ CALLABLE ~ decor                   }....................
+# ....................{ CALLABLE ~ decorator               }....................
 BeartypeConfedDecorator = Callable[[BeartypeableT], BeartypeableT]
 '''
 PEP-compliant type hint matching a **configured beartype decorator** (i.e.,
@@ -294,20 +298,44 @@ of the :func:`beartype.beartype` decorator, including calls to that decorator
 in both configuration and decoration modes.
 '''
 
-# ....................{ DICT                               }....................
-HintSignTrie = Dict[str, Union[HintSign, 'HintSignTrie']]
+# ....................{ CALLABLE ~ decorator               }....................
+CallableStrFormat = Callable[..., str]
 '''
-PEP-compliant type hint matching a **sign trie** (i.e.,
-dictionary-of-dictionaries tree data structure enabling efficient mapping from
-the machine-readable representations of type hints created by an arbitrary
-number of type hint factories defined by an external third-party package to
-their identifying sign).
+PEP-compliant type hint matching the signature of the standard
+:meth:`str.format` method.
+'''
+
+# ....................{ COLLECTION                         }....................
+CollectionStrs = Collection[str]
+'''
+PEP-compliant type hint matching *any* collection of zero or more strings.
+'''
+
+# ....................{ DICT                               }....................
+DictStrToType = Dict[str, type]
+'''
+PEP-compliant type hint matching a dictionary mapping from strings to types.
 '''
 
 # ....................{ DICT ~ any                         }....................
 DictStrToAny = Dict[str, Any]
 '''
-PEP-compliant type hint matching a mapping whose keys are *all* strings.
+PEP-compliant type hint matching a dictionary mapping from strings to arbitrary
+objects.
+'''
+
+
+MappingStrToAny = Mapping[str, object]
+'''
+PEP-compliant type hint matching a mapping mapping from keys to arbitrary
+objects.
+'''
+
+
+DictTypeToAny = Dict[type, Any]
+'''
+PEP-compliant type hint matching a dictionary mapping from types to arbitrary
+objects.
 '''
 
 
@@ -319,10 +347,30 @@ variable of a class to the type hint annotating that parameter, return, or
 variable).
 '''
 
-
-MappingStrToAny = Mapping[str, object]
+# ....................{ DICT ~ sign                        }....................
+DictStrToHintSign = Dict[str, HintSign]
 '''
-PEP-compliant type hint matching a mapping whose keys are *all* strings.
+PEP-compliant type hint matching a dictionary mapping from strings to **signs**
+(i.e., objects uniquely identifying type hints).
+'''
+
+
+HintSignTrie = Dict[str, Union[HintSign, 'HintSignTrie']]
+'''
+PEP-compliant type hint matching a **sign trie** (i.e.,
+dictionary-of-dictionaries tree data structure enabling efficient mapping from
+the machine-readable representations of type hints created by an arbitrary
+number of type hint factories defined by an external third-party package to
+their identifying sign).
+'''
+
+
+HintSignToCallableStrFormat = Dict[HintSign, CallableStrFormat]
+'''
+PEP-compliant type hint matching a **sign-to-string-formatter map** (i.e.,
+dictionary mapping from signs uniquely identifying type hints to
+:meth:`str.format` methods bound to code snippets type-checking various aspects
+of those type hints).
 '''
 
 # ....................{ CODE                               }....................
@@ -356,12 +404,68 @@ func_wrapper_scope, hint_refs_type_basename)``, where:
   List['YoClass']]``).
 '''
 
+# ....................{ FROZENSET                          }....................
+FrozenSetInts = FrozenSet[int]
+'''
+PEP-compliant type hint matching *any* frozen set of zero or more integers.
+'''
+
+
+FrozenSetStrs = FrozenSet[str]
+'''
+PEP-compliant type hint matching *any* frozen set of zero or more strings.
+'''
+
+
+FrozenSetTypes = FrozenSet[type]
+'''
+PEP-compliant type hint matching *any* frozen set of zero or more types.
+'''
+
 # ....................{ ITERABLE                           }....................
 IterableStrs = Iterable[str]
 '''
 PEP-compliant type hint matching *any* iterable of zero or more strings.
 '''
 
+# ....................{ ITERATOR                           }....................
+EnumeratorItem = Tuple[int, object]
+'''
+PEP-compliant type hint matching *any* **enumerator item** (i.e., item of the
+iterator created and returned by the :func:`enumerate` builtin). An enumerator
+item is a 2-tuple of the form ``(item_index, item)``, where:
+
+* ``item_index`` is the 0-based index of the currently enumerated item.
+* ``item`` is the currently enumerated item.
+'''
+
+
+Enumerator = Iterator[EnumeratorItem]
+'''
+PEP-compliant type hint matching *any* **enumerator** (i.e., arbitrary iterator
+satisfying the :func:`enumerate` protocol). This iterator is expected to yield
+zero or more 2-tuples of the form ``(item_index, item)``, where:
+
+* ``item_index`` is the 0-based index of the currently enumerated item.
+* ``item`` is the currently enumerated item.
+'''
+
+# ....................{ OBJECT                             }....................
+GetObjectAttrsDir = Optional[List[str]]
+'''
+PEP-compliant type hint matching the ``obj_dir`` parameter accepted by all
+**object attribute getters** (e.g.,
+:func:`beartype._util.utilobject.get_object_attrs_name_to_value_explicit`).
+'''
+
+
+GetObjectAttrsPredicate = Optional[Callable[[str, object], bool]]
+'''
+PEP-compliant type hint matching the ``predicate`` parameter accepted by all
+**object attribute getters** (e.g.,
+:func:`beartype._util.utilobject.get_object_attrs_name_to_value_explicit`).
+'''
+
 # ....................{ PATH                               }....................
 CommandWords = IterableStrs
 '''
@@ -381,6 +485,8 @@ the :func:`isinstance` and :func:`issubclass` builtins.
 '''
 
 
+#FIXME: *INSUFFICIENT.* Generalize this to additionally accept the types of PEP
+#604-compliant new unions (e.g., "int | str").
 TypeOrTupleTypes = Union[type, TupleTypes]
 '''
 PEP-compliant type hint matching either a single class *or* a tuple of zero or
@@ -517,15 +623,34 @@ instances definitely encapsulating pathnames).
 
 # ....................{ PEP 484                            }....................
 # Type hints required to fully comply with PEP 484.
+#
+# Note that:
+# * If the active Python interpreter targets Python >= 3.10, type unions are
+#   intentionally defined to preferably be PEP 604-compliant (e.g., "float |
+#   int").
+# * Else, type unions fallback to be PEP 484-compliant (e.g., "Union[float,
+#   int]").
+#
+# Why? Because obsolete PEP 484-compliant type unions fail to support various
+# edge cases, including recursive "beartype.HintOverrides" globally defined by
+# the "beartype._conf.confoverrides" submodule.
 
-Pep484TowerComplex = Union[complex, float, int]
+Pep484TowerComplex = (
+    complex | float | int  # type: ignore[operator]
+    if IS_PYTHON_AT_LEAST_3_10 else
+    Union[complex, float, int]
+)
 '''
 :pep:`484`-compliant type hint matching the **implicit complex tower** (i.e.,
 complex numbers, floating-point numbers, and integers).
 '''
 
 
-Pep484TowerFloat = Union[float, int]
+Pep484TowerFloat = (
+    float | int  # type: ignore[operator]
+    if IS_PYTHON_AT_LEAST_3_10 else
+    Union[float, int]
+)
 '''
 :pep:`484`-compliant type hint matching the **implicit floating-point tower**
 (i.e., both floating-point numbers and integers).
