@@ -10,8 +10,6 @@ describing modules and packages bundled with CPython's standard library).
 This private submodule is *not* intended for importation by downstream callers.
 '''
 
-# ....................{ IMPORTS                            }....................
-
 # ....................{ NAMES                              }....................
 BUILTINS_MODULE_NAME = 'builtins'
 '''
@@ -19,3 +17,10 @@ Fully-qualified name of the **builtins module** (i.e., objects defined by the
 standard :mod:`builtins` module and thus globally available by default
 *without* requiring explicit importation).
 '''
+
+
+SCRIPT_MODULE_NAME = '__main__'
+'''
+Fully-qualified name of the **script module** (i.e., arbitrary module name
+assigned to scripts run outside of a package context).
+'''
