@@ -17,7 +17,10 @@ from beartype.roar import (
     BeartypeDecorWrappeeException,
     BeartypeDecorWrapperException,
 )
-from beartype.typing import no_type_check
+from beartype.typing import (
+    Optional,
+    no_type_check,
+)
 from beartype._cave._cavefast import (
     MethodBoundInstanceOrClassType,
     MethodDecoratorClassType,
@@ -25,7 +28,10 @@ from beartype._cave._cavefast import (
     MethodDecoratorPropertyType,
     MethodDecoratorStaticType,
 )
-from beartype._check.checkcall import make_beartype_call
+from beartype._check.metadata.metadecor import (
+    cull_beartype_call,
+    make_beartype_call,
+)
 from beartype._conf.confcls import BeartypeConf
 from beartype._conf.confenum import BeartypeStrategy
 from beartype._data.hint.datahinttyping import (
@@ -39,13 +45,12 @@ from beartype._util.api.utilapibeartype import (
 from beartype._util.api.utilapicontextlib import (
     is_func_contextlib_contextmanager)
 from beartype._util.api.utilapifunctools import is_func_functools_lru_cache
-from beartype._util.cache.pool.utilcachepoolobjecttyped import (
-    release_object_typed)
 from beartype._util.func.utilfuncget import get_func_boundmethod_self
 from beartype._util.func.utilfuncmake import make_func
 from beartype._util.func.utilfunctest import (
     is_func_boundmethod,
     is_func_python,
+    is_func_wrapper,
 )
 from beartype._util.func.utilfuncwrap import (
     unwrap_func_once,
@@ -54,6 +59,7 @@ from beartype._util.func.utilfuncwrap import (
     unwrap_func_staticmethod_once,
 )
 from beartype._util.py.utilpyversion import IS_PYTHON_3_8
+from collections.abc import Callable
 from contextlib import contextmanager
 from functools import lru_cache
 
@@ -112,7 +118,7 @@ def beartype_nontype(obj: BeartypeableT, **kwargs) -> BeartypeableT:
     # * Under Python >= 3.10:
     #   * Descriptors created by @classmethod and @property are uncallable.
     #   * Descriptors created by @staticmethod are technically callable but
-    #     C-based and thus unsuitable for decoration.
+    #     C-based and thus unsuitable for direct decoration.
     if obj_type in MethodDecoratorBuiltinTypes:
         return beartype_descriptor_decorator_builtin(obj, **kwargs)  # type: ignore[return-value]
     # Else, this object is *NOT* an uncallable builtin method descriptor.
@@ -188,6 +194,7 @@ def beartype_func(
     conf: BeartypeConf,
 
     # Variadic keyword parameters.
+    wrapper: Optional[Callable] = None,
     **kwargs
 ) -> BeartypeableT:
     '''
@@ -200,51 +207,72 @@ def beartype_func(
     conf : BeartypeConf
         Beartype configuration configuring :func:`beartype.beartype` uniquely
         specific to this callable.
+    wrapper : Optional[Callable]
+        Wrapper callable to be unwrapped in the event that the callable to be
+        unwrapped differs from the callable to be decorated. Typically, these
+        two callables are the same. Edge cases in which these two callables
+        differ include:
+
+        * When ``wrapper`` is a **pseudo-callable** (i.e., otherwise uncallable
+          object whose type renders that object callable by defining the
+          ``__call__()`` dunder method) *and* ``func`` is that ``__call__()``
+          dunder method. If that pseudo-callable wraps a lower-level callable,
+          then that pseudo-callable (rather than ``__call__()`` dunder method)
+          defines the ``__wrapped__`` instance variable providing that callable.
+
+        Defaults to :data:`None`, in which case this parameter *actually*
+        defaults to ``func``.
 
     All remaining keyword parameters are passed as is to the
-    :meth:`beartype._check.checkcall.BeartypeCall.reinit` method.
+    :meth:`beartype._check.metadata.metadecor.BeartypeDecorMeta.reinit` method.
 
     Returns
     -------
     BeartypeableT
         New pure-Python callable wrapping this callable with type-checking.
     '''
+
+    # If the caller failed to pass a callable to be unwrapped, default that to
+    # the callable to be type-checked.
+    if wrapper is None:
+        wrapper = func  # type: ignore[assignment]
+    # Else, the caller passed a callable to be unwrapped. Preserve it up!
+
+    # Validate all explicitly passed parameters.
+    assert isinstance(conf, BeartypeConf), f'{repr(conf)} not configuration.'
     assert callable(func), f'{repr(func)} uncallable.'
-    # assert isinstance(conf, BeartypeConf), f'{repr(conf)} not configuration.'
-    # assert isinstance(cls_root, NoneTypeOr[type]), (
-    #     f'{repr(cls_root)} neither type nor "None".')
-    # assert isinstance(cls_curr, NoneTypeOr[type]), (
-    #     f'{repr(cls_curr)} neither type nor "None".')
+    assert callable(wrapper), f'{repr(wrapper)} uncallable.'
 
     #FIXME: Uncomment to display all annotations in "pytest" tracebacks.
     # func_hints = func.__annotations__
 
     # If this configuration enables the no-time strategy performing *NO*
     # type-checking, monkey-patch that callable with the standard
-    # @typing.no_type_check decorator detected above by the call to the
+    # @typing.no_type_check decorator detected below by the call to the
     # is_func_unbeartypeable() tester on all subsequent decorations passed the
     # same callable... Doing so prevents all subsequent decorations from
     # erroneously ignoring this previously applied no-time strategy.
     if conf.strategy is BeartypeStrategy.O0:
-        no_type_check(func)  # pyright: ignore[reportGeneralTypeIssues]
+        no_type_check(func)  # pyright: ignore
     # Else, this configuration enables a positive-time strategy performing at
     # least the minimal amount of type-checking.
 
-    # If that callable is unbeartypeable (i.e., if this decorator should
-    # preserve that callable as is rather than wrap that callable with
-    # constant-time type-checking), silently reduce to the identity decorator.
+    # If the callable to be unwrapped is unbeartypeable (i.e., if this decorator
+    # should preserve that callable as is rather than wrap that callable with
+    # type-checking), silently reduce to the identity decorator.
     #
     # Note that this conditional implicitly handles the prior conditional! :O
-    if is_func_unbeartypeable(func):  # type: ignore[arg-type]
+    if is_func_unbeartypeable(wrapper):  # type: ignore[arg-type]
         # print(f'Ignoring unbeartypeable callable {repr(func)}...')
         return func  # type: ignore[return-value]
     # Else, that callable is beartypeable. Let's do this, folks.
 
     # Beartype call metadata describing that callable.
-    bear_call = make_beartype_call(func, conf, **kwargs)  # pyright: ignore[reportGeneralTypeIssues]
+    decor_meta = make_beartype_call(
+        func=func, conf=conf, wrapper=wrapper, **kwargs)  # pyright: ignore
 
     # Generate the raw string of Python statements implementing this wrapper.
-    func_wrapper_code = generate_code(bear_call)
+    func_wrapper_code = generate_code(decor_meta)
 
     # If that callable requires *NO* type-checking, silently reduce to a noop
     # and thus the identity decorator by returning that callable as is.
@@ -260,31 +288,11 @@ def beartype_func(
     # attributes are *ALWAYS* first looked up as local attributes before falling
     # back to being looked up as global attributes.
     func_wrapper = make_func(
-        func_name=bear_call.func_wrapper_name,
+        func_name=decor_meta.func_wrapper_name,
         func_code=func_wrapper_code,
-        func_locals=bear_call.func_wrapper_scope,
-
-        #FIXME: String formatting is infamously slow. As an optimization, it'd
-        #be strongly preferable to instead pass a lambda function accepting *NO*
-        #parameters and returning the desired string, which make_func() should
-        #then internally call on an as-needed basis to make this string: e.g.,
-        #    func_label_factory=lambda: f'@beartyped {bear_call.func_wrapper_name}() wrapper',
-        #
-        #This is trivial. The only question then is: "Which is actually faster?"
-        #Before finalizing this refactoring, let's profile both, adopt whichever
-        #outperforms the other, and then document this choice in make_func().
-        #FIXME: *WAIT.* We don't need a lambda at all. All we need is to:
-        #* Define a new BeartypeCall.label_func_wrapper() method resembling:
-        #      def label_func_wrapper(self) -> str:
-        #          return f'@beartyped {self.func_wrapper_name}() wrapper'
-        #* Refactor make_func() to accept a new optional keyword-only
-        #  "func_label_factory" parameter, passed here as:
-        #      func_label_factory=bear_call.label_func_wrapper,
-        #
-        #That's absolutely guaranteed to be the fastest approach.
-        func_label=f'@beartyped {bear_call.func_wrapper_name}() wrapper',
-
-        func_wrapped=func,
+        func_locals=decor_meta.func_wrapper_scope,
+        func_wrapped=func,  # pyright: ignore
+        func_labeller=decor_meta.label_func_wrapper,
         is_debug=conf.is_debug,
         exception_cls=BeartypeDecorWrapperException,
     )
@@ -294,8 +302,8 @@ def beartype_func(
     # already decorated by @beartype by efficiently reducing to a noop.
     set_func_beartyped(func_wrapper)
 
-    # Release this beartype call metadata back to its object pool.
-    release_object_typed(bear_call)
+    # Deinitialize this beartype call metadata.
+    cull_beartype_call(decor_meta)
 
     # Return this wrapper.
     return func_wrapper  # type: ignore[return-value]
@@ -329,7 +337,7 @@ def beartype_func_contextlib_contextmanager(
 
     # Original pure-Python generator factory function decorated by
     # @contextlib.contextmanager.
-    generator = unwrap_func_once(func)
+    generator = unwrap_func_once(func)  # type: ignore[arg-type]
 
     # Decorate this generator factory function with type-checking.
     generator_checked = beartype_func(func=generator, **kwargs)
@@ -610,7 +618,7 @@ def _beartype_descriptor_boundmethod(
 def beartype_pseudofunc(pseudofunc: BeartypeableT, **kwargs) -> BeartypeableT:
     '''
     Monkey-patch the passed **pseudo-callable** (i.e., arbitrary pure-Python
-    *or* C-based object whose class defines the ``__call__``) dunder method
+    *or* C-based object whose class defines the ``__call__()`` dunder method
     enabling this object to be called like a standard callable) with dynamically
     generated type-checking.
 
@@ -633,11 +641,15 @@ def beartype_pseudofunc(pseudofunc: BeartypeableT, **kwargs) -> BeartypeableT:
     BeartypeableT
         The object monkey-patched by :func:`beartype.beartype`.
     '''
-    # print(f'@beartyping pseudo-callable {repr(obj)}...')
+    # print(f'@beartyping pseudo-callable {repr(pseudofunc)}...')
 
-    # __call__() dunder method defined by this object if this object defines
+    # Bound __call__() dunder method bound to this object if this object defines
     # this method *OR* "None" otherwise.
-    pseudofunc_call_method = getattr(pseudofunc, '__call__')
+    pseudofunc_call_boundmethod = getattr(pseudofunc, '__call__')
+
+    # Unbound __call__() dunder method defined by the type of this object if
+    # this type defines this method *OR* "None" otherwise.
+    pseudofunc_call_type_method = getattr(pseudofunc.__class__, '__call__')
 
     # If this object does *NOT* define this method, this object is *NOT* a
     # pseudo-callable. In this case, raise an exception.
@@ -648,75 +660,83 @@ def beartype_pseudofunc(pseudofunc: BeartypeableT, **kwargs) -> BeartypeableT:
     # is a pseudo-callable, this object *MUST* be a pseudo-callable. That said,
     # languages change; it's not inconceivable that Python could introduce yet
     # another kind of callable object under future versions.
-    if pseudofunc_call_method is None:
-        raise BeartypeDecorWrappeeException(  # pragma: no cover
-            f'Callable {repr(pseudofunc)} not pseudo-callable '
-            f'(i.e., callable object defining __call__() dunder method).'
+    if pseudofunc_call_boundmethod is None:  # pragma: no cover
+        raise BeartypeDecorWrappeeException(
+            f'Callable {repr(pseudofunc)} not pseudo-callable object '
+            f'(i.e., defines no bound __call__() dunder method).'
         )
     # Else, this object is a pseudo-callable.
     #
-    # If this method is *NOT* pure-Python, this method is C-based. In this
-    # case...
+    # If this object does *NOT* define this method, this object is *NOT* a
+    # pseudo-callable. In this case, raise an exception.
+    elif pseudofunc_call_type_method is None:  # pragma: no cover
+        raise BeartypeDecorWrappeeException(
+            f'Callable {repr(pseudofunc)} type {repr(pseudofunc.__class__)} '
+            f'not pseudo-callable object type '
+            f'(i.e., defines no unbound __call__() dunder method).'
+        )
+    # Else, this object type is a pseudo-callable type.
     #
-    # Note that this is non-ideal. Whereas logic below safely monkey-patches
-    # pure-Python pseudo-callables in a general-purpose manner, that same logic
-    # does *NOT* apply to C-based pseudo-callables; indeed, there exists *NO*
-    # general-purpose means of safely monkey-patching the latter. Instead,
-    # specific instances of the latter *MUST* be manually detected and handled.
-    elif not is_func_python(pseudofunc_call_method):
-        # If this is a C-based @functools.lru_cache-memoized callable (i.e.,
-        # low-level C-based callable object both created and returned by the
-        # standard @functools.lru_cache decorator), @beartype was listed above
-        # rather than below the @functools.lru_cache decorator creating and
-        # returning this callable in the chain of decorators decorating this
-        # decorated callable.
-        #
-        # This conditional branch effectively reorders @beartype to be the first
-        # decorator decorating the pure-Python callable underlying this C-based
-        # pseudo-callable: e.g.,
-        #
-        #     from functools import lru_cache
-        #
-        #     # This branch detects and reorders this edge case...
-        #     @beartype
-        #     @lru_cache
-        #     def muh_lru_cache() -> None: pass
-        #
-        #     # ...to resemble this direct decoration instead.
-        #     @lru_cache
-        #     @beartype
-        #     def muh_lru_cache() -> None: pass
-        if is_func_functools_lru_cache(pseudofunc):
-            # Return a new callable decorating that callable with type-checking.
-            return beartype_pseudofunc_functools_lru_cache(  # type: ignore
-                pseudofunc=pseudofunc, **kwargs)  # pyright: ignore
-        # Else, this is *NOT* a C-based @functools.lru_cache-memoized callable.
-
-    # Replace the existing bound method descriptor to this __call__() dunder
-    # method with a new bound method descriptor to a new __call__() dunder
-    # method wrapping the old method with runtime type-checking.
+    # If this is a C-based @functools.lru_cache-memoized callable (i.e.,
+    # low-level C-based callable object both created and returned by the
+    # standard @functools.lru_cache decorator), @beartype was listed above
+    # rather than below the @functools.lru_cache decorator creating and
+    # returning this callable in the chain of decorators decorating this
+    # decorated callable.
     #
-    # Note that:
-    # * This is a monkey-patch. Since the caller is intentionally decorating
-    #   this pseudo-callable with @beartype, this is exactly what the caller
-    #   wanted. Probably. Hopefully. Okay! We're crossing our fingers here.
-    # * This monkey-patches the *CLASS* of this object rather than this object
-    #   itself. Why? Because Python. For unknown reasons (so, speed is what
-    #   we're saying), Python accesses the __call__() dunder method on the
-    #   *CLASS* of an object rather than on the object itself. Of course, this
-    #   implies that *ALL* instances of this pseudo-callable (rather than merely
-    #   the passed instance) will be monkey-patched. This may *NOT* necessarily
-    #   be what the caller wanted. Unfortunately, the only alternative would be
-    #   for @beartype to raise an exception when passed a pseudo-callable. Since
-    #   doing something beneficial is generally preferable to doing something
-    #   harmful, @beartype prefers the former. See also official documentation
-    #   on the subject:
-    #       https://docs.python.org/3/reference/datamodel.html#special-method-names
-    pseudofunc.__class__.__call__ = _beartype_descriptor_boundmethod(  # type: ignore[assignment,method-assign]
-        descriptor=pseudofunc_call_method, **kwargs)
+    # This conditional branch effectively reorders @beartype to be the first
+    # decorator decorating the pure-Python callable underlying this C-based
+    # pseudo-callable: e.g.,
+    #     from functools import lru_cache
+    #
+    #     # This branch detects and reorders this edge case...
+    #     @beartype
+    #     @lru_cache
+    #     def muh_lru_cache() -> None: pass
+    #
+    #     # ...to resemble this direct decoration instead.
+    #     @lru_cache
+    #     @beartype
+    #     def muh_lru_cache() -> None: pass
+    elif is_func_functools_lru_cache(pseudofunc):
+        # Return a new callable decorating that callable with type-checking.
+        return beartype_pseudofunc_functools_lru_cache(  # type: ignore
+            pseudofunc=pseudofunc, **kwargs)  # pyright: ignore
+    # Else, this is *NOT* a C-based @functools.lru_cache-memoized callable.
+    #
+    # If...
+    elif (
+        # This pseudo-callable object is a wrapper *AND*...
+        is_func_wrapper(pseudofunc) and
+        # This unbound __call__() dunder method is *NOT* a wrapper...
+        not is_func_wrapper(pseudofunc_call_type_method)
+    ):
+        # print(f'Pseudo-callable wrapper {repr(pseudofunc)} identified!')
 
-    # Return this monkey-patched object.
-    return pseudofunc  # type: ignore[return-value]
+        # Transitively pass the optional "wrapper" parameter to the
+        # BeartypeDecorMeta.reinit() method, ensuring that this pseudo-callable
+        # wrapper object is correctly unwrapped.
+        #
+        # This edge case handles edge-case pseudo-callable wrapper objects
+        # defined by popular third-party packages, including:
+        # * The pseudo-callable wrapper objects created and returned by the
+        #   @equinox.filter_jit wrapper. Although private and extremely
+        #   non-trivial, the types of these objects vaguely resembles:
+        #       class _JitWrapper(object):
+        #           def __init__(self, func):
+        #               self.__wrapped__ = func
+        #
+        #           def __call__(self, *args, **kwargs):
+        #               return self.__wrapped__(*args, **kwargs)
+        kwargs['wrapper'] = pseudofunc
+    # Else, either this pseudo-callable object is not a wrapper *OR* this
+    # unbound __call__() dunder method is already a wrapper.
+
+    # Unbound __call__() dunder method runtime type-checking the original bound
+    # __call__() dunder method of the passed pseudo-callable object.
+    pseudofunc_call_type_method_checked = beartype_func(
+        func=pseudofunc_call_boundmethod, **kwargs)
+    return pseudofunc_call_type_method_checked
 
 
 def beartype_pseudofunc_functools_lru_cache(
