@@ -102,7 +102,7 @@ def copy_node_metadata(
             f'{repr(node_trg_cur)} not AST node.')
 
         # Copy all source code metadata from this source to target node.
-        node_trg_cur.lineno         = node_src.lineno
-        node_trg_cur.col_offset     = node_src.col_offset
+        node_trg_cur.lineno         = node_src.lineno  # type: ignore[attr-defined]
+        node_trg_cur.col_offset     = node_src.col_offset  # type: ignore[attr-defined]
         node_trg_cur.end_lineno     = node_src.end_lineno  # type: ignore[attr-defined]
         node_trg_cur.end_col_offset = node_src.end_col_offset  # type: ignore[attr-defined]
