@@ -14,25 +14,22 @@ This private submodule is *not* intended for importation by downstream callers.
 # ....................{ IMPORTS                            }....................
 from beartype.roar._roarexc import _BeartypeUtilCallableException
 from beartype.typing import (
-    Dict,
     Iterable,
     Optional,
     Tuple,
 )
 from beartype._data.hint.datahinttyping import (
-    # Codeobjable,
     TypeException,
 )
 from beartype._data.kind.datakinddict import DICT_EMPTY
-from beartype._util.func.utilfunccodeobj import get_func_codeobj
-from beartype._util.func.utilfuncwrap import unwrap_func_all_isomorphic
+from beartype._util.func.arg.utilfuncarglen import get_func_args_lens
+from beartype._util.utilobject import Iota
 from collections.abc import Callable
 from enum import (
     Enum,
     auto as next_enum_member_value,
     unique as die_unless_enum_member_values_unique,
 )
-from inspect import CO_VARARGS, CO_VARKEYWORDS
 from itertools import count
 from types import CodeType
 
@@ -60,7 +57,7 @@ class ArgKind(Enum):
     POSITIONAL_OR_KEYWORD : EnumMemberType
         Kind of all **flexible parameters** (i.e., parameters permitted to be
         passed either positionally or by keyword).
-    VAR_POSITIONAL : EnumMemberType
+    VARIADIC_POSITIONAL : EnumMemberType
         Kind of all **variadic positional parameters** (i.e., tuple of zero or
         more positional parameters *not* explicitly named by preceding
         positional-only or flexible parameters, syntactically preceded by the
@@ -69,7 +66,7 @@ class ArgKind(Enum):
         Kind of all **keyword-only parameters** (i.e., parameters required to
         be passed by keyword, syntactically preceded in the signatures of
         their callables by the :pep:`3102`-compliant ``*,`` pseudo-parameter).
-    VAR_KEYWORD : EnumMemberType
+    VARIADIC_KEYWORD : EnumMemberType
         Kind of all **variadic keyword parameters** (i.e., tuple of zero or
         more keyword parameters *not* explicitly named by preceding
         keyword-only or flexible parameters, syntactically preceded by the
@@ -78,36 +75,64 @@ class ArgKind(Enum):
 
     POSITIONAL_ONLY = next_enum_member_value()
     POSITIONAL_OR_KEYWORD = next_enum_member_value()
-    VAR_POSITIONAL = next_enum_member_value()
+    VARIADIC_POSITIONAL = next_enum_member_value()
     KEYWORD_ONLY = next_enum_member_value()
-    VAR_KEYWORD = next_enum_member_value()
+    VARIADIC_KEYWORD = next_enum_member_value()
 
 # ....................{ SINGLETONS                         }....................
-ArgMandatory = object()
+ArgMandatory = Iota()
 '''
-Arbitrary sentinel singleton assigned by the
-:func:`iter_func_args` generator to the :data:`ARG_META_INDEX_DEFAULT` fields
-of all :data:`ArgMeta` instances describing **mandatory parameters** (i.e.,
+Arbitrary sentinel singleton assigned by the :func:`.iter_func_args` generator
+to the tuple item with index :data:`.ARG_META_INDEX_DEFAULT` of all
+:class:`.ArgMeta` instances, describing **mandatory parameters** (i.e.,
 parameters that *must* be explicitly passed to their callables).
 '''
 
 # ....................{ HINTS                              }....................
 ArgMeta = Tuple[ArgKind, str, object]
 '''
-PEP-compliant type hint matching each 3-tuple ``(arg_kind, arg_name,
-default_value_or_mandatory)`` iteratively yielded by the :func:`iter_func_args`
-generator for each parameter accepted by the passed pure-Python callable, where:
+PEP-compliant type hint matching each **callable parameter metadata**
+iteratively yielded by the :func:`.iter_func_args` generator for each parameter
+accepted by the pure-Python callable passed to that generator, defined as the
+4-tuple ``(arg_kind, arg_name, arg_default_or_mandatory, arg_hint_or_unhinted)``
+where:
 
-* ``arg_kind`` is this parameter's **kind** (i.e., :class:`ArgKind` enumeration
-  member conveying this parameter's syntactic class, constraining how the
+* ``arg_kind`` is this parameter's **kind** (i.e., :class:`.ArgKind` enumeration
+  member conveying the syntactic class of this parameter, constraining how the
   callable declaring this parameter requires this parameter to be passed).
-* ``name`` is this parameter's **name** (i.e., syntactically valid Python
+* ``arg_name`` is this parameter's **name** (i.e., syntactically valid Python
   identifier uniquely identifying this parameter in its parameter list).
-* ``default_value_or_mandatory`` is either:
+* ``arg_default_or_mandatory`` is either:
 
-    * If this parameter is mandatory, the magic constant :data:`ArgMandatory`.
-    * Else, this parameter is optional and thus defaults to a default value
-      when unpassed. In this case, this is that default value.
+  * If this parameter is mandatory, the magic constant :data:`.ArgMandatory`.
+  * Else, this parameter is optional and thus defaults to a default value when
+    unpassed. In this case, this is that default value.
+
+Caveats
+-------
+**This metadata intentionally omits the type hint annotating this parameter.**
+Why? Because deciding *which* type hint annotates this parameter (if any) is
+non-trivial in common edge cases. Notably, if the pure-Python callable passed to
+that generator differs from the callable to be unwrapped with respect to type
+hints, then that generator *cannot* reliably decide which type hint annotates
+this parameter without refactoring both that generator and all other callables
+transitively calling that generator to also accept and forward on a new
+``type_hint_wrapper`` parameter providing the callable to be unwrapped with
+respect to type hints. Although feasible, doing so would only invite even
+further API confusion with little to no tangible benefit. Edge cases in which
+this arises include:
+
+* When ``type_hint_wrapper`` is a **pseudo-callable** (i.e., otherwise
+  uncallable object whose type renders that object callable by defining the
+  ``__call__()`` dunder method) *and* ``func`` is that ``__call__()`` dunder
+  method. If that pseudo-callable wraps a lower-level callable, then that
+  pseudo-callable (rather than ``__call__()`` dunder method) defines the
+  ``__wrapped__`` instance variable providing that callable.
+
+The caller is thus responsible for mapping parameters to type hints. Thankfully,
+the existing
+:attr:`beartype._check.meta.checkdecor.BeartypeDecorMeta.func_arg_name_to_hint`
+dictionary makes this trivial for most use cases.
 '''
 
 # ....................{ CONSTANTS ~ index                  }....................
@@ -118,18 +143,18 @@ __arg_meta_index_counter = count(start=0, step=1)
 
 ARG_META_INDEX_KIND = next(__arg_meta_index_counter)
 '''
-0-based index into each 4-tuple iteratively yielded by the generator returned
-by the :func:`iter_func_args` generator function of the currently iterated
-parameter's **kind** (i.e., :class:`ArgKind` enumeration member conveying
-this parameter's syntactic class, constraining how the callable declaring this
+0-based index into each 4-tuple iteratively yielded by the generator returned by
+the :func:`.iter_func_args` generator function providing the currently iterated
+parameter's **kind** (i.e., :class:`ArgKind` enumeration member conveying this
+parameter's syntactic class, constraining how the callable declaring this
 parameter requires this parameter to be passed).
 '''
 
 
 ARG_META_INDEX_NAME = next(__arg_meta_index_counter)
 '''
-0-based index into each 4-tuple iteratively yielded by the generator returned
-by the :func:`iter_func_args` generator function of the currently iterated
+0-based index into each 4-tuple iteratively yielded by the generator returned by
+the :func:`.iter_func_args` generator function providing the currently iterated
 parameter's **name** (i.e., syntactically valid Python identifier uniquely
 identifying this parameter in its parameter list).
 '''
@@ -137,11 +162,11 @@ identifying this parameter in its parameter list).
 
 ARG_META_INDEX_DEFAULT = next(__arg_meta_index_counter)
 '''
-0-based index into each 4-tuple iteratively yielded by the generator returned
-by the :func:`iter_func_args` generator function of the currently iterated
-parameter's **default value** specified as either:
+0-based index into each 4-tuple iteratively yielded by the generator returned by
+the :func:`.iter_func_args` generator function providing the currently iterated
+parameter's **default value**, defined as either:
 
-* If this parameter is mandatory, the magic constant :data:`ArgMandatory`.
+* If this parameter is mandatory, the magic constant :data:`.ArgMandatory`.
 * Else, this parameter is optional and thus defaults to a default value when
   unpassed. In this case, this is that default value.
 '''
@@ -157,16 +182,18 @@ def iter_func_args(
 
     # Optional parameters.
     func_codeobj: Optional[CodeType] = None,
+    is_omit_boundmethod_arg_first: bool = True,
     is_unwrap: bool = True,
     exception_cls: TypeException = _BeartypeUtilCallableException,
+    exception_prefix: str = '',
 # Note this generator is intentionally annotated as returning a high-level
 # "Iterable[...]" rather than a low-level "Generator[..., ..., ...]", as the
 # syntax governing the latter is overly verbose and largely unhelpful.
 ) -> Iterable[ArgMeta]:
     '''
-    Generator yielding one **parameter metadata tuple** (i.e., tuple whose
-    items describe a single parameter) for each parameter accepted by the
-    passed pure-Python callable.
+    Generator yielding one **parameter metadata tuple** (i.e., tuple whose items
+    describe a single parameter) for each parameter accepted by the passed
+    pure-Python callable.
 
     For consistency with the official grammar for callable signatures
     standardized by :pep:`570`, this generator is guaranteed to yield parameter
@@ -186,7 +213,7 @@ def iter_func_args(
       :attr:`ArgKind.POSITIONAL_OR_KEYWORD` and whose default value is *not*
       :data:`ArgMandatory`).
     * **Variadic positional parameters** (i.e., parameter metadata whose kind
-      is :attr:`ArgKind.VAR_POSITIONAL` and whose default value is
+      is :attr:`ArgKind.VARIADIC_POSITIONAL` and whose default value is
       :data:`ArgMandatory`).
     * **Mandatory and optional keyword-only parameters** (i.e., parameter
       metadata whose kind is :attr:`ArgKind.KEYWORD_ONLY`). Unlike all other
@@ -194,7 +221,7 @@ def iter_func_args(
       ergo, Python explicitly permits mandatory and optional keyword-only
       parameters to be heterogeneously intermingled rather than clustered.
     * **Variadic keyword parameters** (i.e., parameter metadata whose kind
-      is :attr:`ArgKind.VAR_KEYWORD` and whose default value is
+      is :attr:`ArgKind.VARIADIC_KEYWORD` and whose default value is
       :data:`ArgMandatory`).
 
     Caveats
@@ -211,26 +238,73 @@ def iter_func_args(
     func_codeobj: CodeType, optional
         Code object underlying that callable unwrapped. Defaults to
         :data:`None`, in which case this iterator internally defers to the
-        comparatively slower :func:`get_func_codeobj` function.
-    is_unwrap: bool, optional
+        comparatively slower :func:`.get_func_codeobj` function.
+    is_omit_boundmethod_arg_first : bool, optional
+        :data:`True` only if this generator implicitly omits the first mandatory
+        flexible parameter accepted by that callable if that callable is a
+        C-based bound method descriptor encapsulating either an instance method
+        bound to an instance of a class *or* a class method bound to a class.
+        Defaults to :data:`True`, instructing this generator to transparently
+        yield the *actual* high-level parameters accepted by this bound method
+        descriptor (rather than the low-level parameters accepted by the unbound
+        method encapsulated by this bound method descriptor). While the default
+        behaviour is typically desirable, valid use cases for the non-default
+        behaviour do exist (e.g., crudely detecting the kind of that based on
+        whether the unbound method encapsulated by this bound method descriptor
+        accepts a first parameter named ``cls`` or ``self``).
+
+        The default behaviour enables:
+
+        * This generator to transparently support bound method descriptors,
+          which then enables...
+        * The private :func:`beartype._decor._decornontype.beartype_pseudofunc`
+          decorator to type-check the bound ``__call__()`` method descriptor
+          encapsulating the unbound ``__call__()`` dunder method defined on the
+          class of pseudo-callable objects, which then enables...
+        * The public :func:`beartype.beartype` decorator to type-check
+          pseudo-callable objects.
+
+        How? In this case, the aforementioned ``beartype_pseudofunc``
+        decorator wraps this bound method descriptor with a dynamically
+        generated wrapper function that does *not* accept a ``self`` or ``cls``
+        parameter, since a bound method does *not* accept a ``self`` or ``cls``
+        parameter. After all, that's why bound methods exist; they implicitly
+        pass the instance or class to which they are bound as the value of the
+        ``self`` or ``cls`` parameter to the unbound method they encapsulate.
+        However, the code object of a bound method descriptor is only an alias
+        to the code object of the corresponding unbound method. Since the latter
+        accepts a ``self`` parameter, so too does the former.
+
+        The default behaviour resolves this internal discrepancy (contradiction)
+        that arises between:
+
+        * The code object of a bound method descriptor, which declares that
+          callable object to accept a ``self`` parameter.
+        * The real-world calling semantics of a bound method descriptor, which
+          by definition accepts *no* ``self`` parameter.
+    is_unwrap : bool, optional
         :data:`True` only if this generator implicitly calls the
-        :func:`unwrap_func_all_isomorphic` function to unwrap this possibly higher-level
-        wrapper into its possibly lowest-level wrappee *before* returning the
-        code object of that wrappee. Note that doing so incurs worst-case time
-        complexity ``O(n)`` for ``n`` the number of lower-level wrappees
-        wrapped by this wrapper. Defaults to :data:`True` for robustness. Why?
-        Because this generator *must* always introspect lowest-level wrappees
-        rather than higher-level wrappers. The latter typically do *not* wrap
-        the default values of the former, since this is the default behaviour
-        of the :func:`functools.update_wrapper` function underlying the
-        :func:`functools.wrap` decorator underlying all sane decorators. If
-        this boolean is set to :data:`False` while that callable is actually a
-        wrapper, this generator will erroneously misidentify optional as
-        mandatory parameters and fail to yield their default values. Only set
-        this boolean to :data:`False` if you pretend to know what you're doing.
+        :func:`unwrap_func_all_isomorphic` function to unwrap this possibly
+        higher-level wrapper into its possibly lowest-level wrappee *before*
+        returning the code object of that wrappee. Note that doing so incurs
+        worst-case time complexity ``O(n)`` for ``n`` the number of lower-level
+        wrappees wrapped by this wrapper. Defaults to :data:`True` for
+        robustness. Why? Because this generator *must* always introspect
+        lowest-level wrappees rather than higher-level wrappers. The latter
+        typically do *not* wrap the default values of the former, since this is
+        the default behaviour of the :func:`functools.update_wrapper` function
+        underlying the :func:`functools.wrap` decorator underlying all sane
+        decorators. If this boolean is set to :data:`False` while that callable
+        is actually a wrapper, this generator will erroneously misidentify
+        optional as mandatory parameters and fail to yield their default values.
+        Only set this boolean to :data:`False` if you pretend to know what
+        you're doing.
     exception_cls : type, optional
         Type of exception to be raised in the event of a fatal error. Defaults
         to :class:`._BeartypeUtilCallableException`.
+    exception_prefix : str, optional
+        Human-readable label prefixing the message of any exception raised in
+        the event of a fatal error. Defaults to the empty string.
 
     Yields
     ------
@@ -242,8 +316,17 @@ def iter_func_args(
     exception_cls
          If that callable is *not* pure-Python.
     '''
+    assert isinstance(is_omit_boundmethod_arg_first, bool), (
+        f'{repr(is_omit_boundmethod_arg_first)} not boolean.')
+    assert isinstance(is_unwrap, bool), f'{repr(is_unwrap)} not boolean.'
 
-    # ..................{ LOCALS ~ noop                      }..................
+    # ..................{ IMPORTS                            }..................
+    # Avoid circular import dependencies.
+    from beartype._util.func.utilfunccodeobj import get_func_codeobj
+    from beartype._util.func.utilfunctest import is_func_boundmethod
+    from beartype._util.func.utilfuncwrap import unwrap_func_all_isomorphic
+
+    # ..................{ LOCALS ~ core                      }..................
     # If unwrapping that callable, do so *BEFORE* obtaining the code object of
     # that callable for safety (to avoid desynchronization between the two).
     if is_unwrap:
@@ -252,41 +335,33 @@ def iter_func_args(
     # caller. We should probably assert that, but doing so requires an
     # expensive call to hasattr(). What you gonna do?
 
-    # If passed *NO* code object, query that callable for its code object.
-    if func_codeobj is None:
-        func_codeobj = get_func_codeobj(func=func, exception_cls=exception_cls)
-    # In any case, that code object is now defined.
-
-    # Bit field of OR-ed binary flags describing this callable.
-    func_codeobj_flags = func_codeobj.co_flags
-
-    # Number of both optional and mandatory non-keyword-only parameters (i.e.,
-    # positional-only *AND* flexible (i.e., positional or keyword) parameters)
-    # accepted by that callable.
-    args_len_posonly_or_flex = func_codeobj.co_argcount
-
-    # Number of both optional and mandatory keyword-only parameters accepted by
-    # that callable.
-    args_len_kwonly = func_codeobj.co_kwonlyargcount
-
-    #!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
-    # CAUTION: Synchronize with the is_func_arg_variadic_positional() and
-    # is_func_arg_variadic_keyword() testers.
-    #!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
-    # True only if that callable accepts variadic positional or keyword
-    # parameters. For efficiency, these tests are inlined from the
-    # is_func_arg_variadic_positional() and is_func_arg_variadic_keyword()
-    # testers. Yes, this optimization has been profiled to yield joy.
-    is_arg_var_pos = bool(func_codeobj_flags & CO_VARARGS)
-    is_arg_var_kw  = bool(func_codeobj_flags & CO_VARKEYWORDS)
-    # print(f'func.__name__ = {func.__name__}\nis_arg_var_pos = {is_arg_var_pos}\nis_arg_var_kw = {is_arg_var_kw}')
+    # Number of various kinds of parameters accepted by that callable.
+    (
+        # Number of both optional and mandatory non-keyword-only parameters
+        # (i.e., positional-only *AND* flexible (i.e., positional or keyword)
+        # parameters) accepted by that callable.
+        args_len_posonly_or_flex,
+        # Number of both optional and mandatory keyword-only parameters accepted
+        # by that callable.
+        args_len_kwonly,
+        # 1 only if that callable accepts variadic positional or keyword
+        # parameters and 0 otherwise.
+        is_arg_var_pos,
+        is_arg_var_kw,
+    ) = get_func_args_lens(
+        func=func,
+        is_unwrap=False,  # <-- "func" was already unwrapped above. I sigh.
+        exception_cls=exception_cls,
+        exception_prefix=exception_prefix,
+    )
 
     # If that callable accepts *NO* parameters, silently reduce to the empty
     # generator (i.e., noop) for both space and time efficiency. Just. Do. It.
     #
-    # Note that this is a critical optimization when @beartype is
-    # unconditionally applied with import hook automation to *ALL* physical
-    # callables declared by a package, many of which will be argumentless.
+    # Note that this is a critical optimization for the common use case that
+    # @beartype is unconditionally applied with "beartype.claw"-based import
+    # hook automation to *ALL* callables physically declared by a package, many
+    # of which will inevitably be argumentless.
     if (
         args_len_posonly_or_flex +
         args_len_kwonly +
@@ -297,7 +372,16 @@ def iter_func_args(
         return
     # Else, that callable accepts one or more parameters.
 
-    # ..................{ LOCALS ~ names                     }..................
+    # If passed *NO* code object, query that callable for its code object.
+    if func_codeobj is None:
+        func_codeobj = get_func_codeobj(
+            func=func,
+            is_unwrap=False,  # <-- "func" was already unwrapped above. I sigh.
+            exception_cls=exception_cls,
+            exception_prefix=exception_prefix,
+        )
+    # In any case, that code object is now defined.
+
     # Tuple of the names of all variables localized to that callable.
     #
     # Note that this tuple contains the names of both:
@@ -309,7 +393,7 @@ def iter_func_args(
     #
     # Lastly, note the "func_codeobj.co_names" attribute is incorrectly
     # documented in the "inspect" module as the "tuple of names of local
-    # variables." That's a lie. That attribute is instead a mostly useless
+    # variables." That's a lie. Instead, that attribute is a mostly useless
     # tuple of the names of both globals and object attributes accessed in the
     # body of that callable. *shrug*
     args_name = func_codeobj.co_varnames
@@ -317,8 +401,8 @@ def iter_func_args(
     # ..................{ LOCALS ~ defaults                  }..................
     # Tuple of the default values assigned to all optional non-keyword-only
     # parameters (i.e., all optional positional-only *AND* optional flexible
-    # (i.e., positional or keyword) parameters) accepted by that callable if
-    # any *OR* the empty tuple otherwise.
+    # (i.e., positional or keyword) parameters) accepted by that callable if any
+    # *OR* the empty tuple otherwise.
     args_defaults_posonly_or_flex = func.__defaults__ or ()  # type: ignore[attr-defined]
     # print(f'args_defaults_posonly_or_flex: {args_defaults_posonly_or_flex}')
 
@@ -327,9 +411,9 @@ def iter_func_args(
     # if any *OR* the empty dictionary otherwise.
     #
     # For both space and time efficiency, the empty dictionary is intentionally
-    # *NOT* accessed here as "{}". Whereas each instantiation of the empty
-    # tuple efficiently reduces to the same empty tuple, each instantiation of
-    # the empty dictionary inefficiently creates a new empty dictionary: e.g.,
+    # *NOT* accessed here as "{}". Whereas each instantiation of the empty tuple
+    # efficiently reduces to the same empty tuple, each instantiation of the
+    # empty dictionary inefficiently creates a new empty dictionary: e.g.,
     #     >>> () is ()
     #     True
     #     >>> {} is {}
@@ -397,7 +481,7 @@ def iter_func_args(
     # Number of mandatory flexible parameters accepted by that callable.
     args_len_flex_mandatory = args_len_flex - args_len_flex_optional
 
-    # ..................{ INTROSPECTION                      }..................
+    # ..................{ ITERATE ~ positional-only          }..................
     # 0-based index of the first parameter of the currently iterated kind
     # accepted by that callable in the "args_name" tuple.
     args_index_kind_first = 0
@@ -413,6 +497,7 @@ def iter_func_args(
 
         # 0-based index of the first parameter of the next iterated kind.
         args_index_kind_first = args_len_posonly_mandatory
+    # Else, that callable accepts *NO* mandatory positional-only parameters.
 
     # If that callable accepts at least one optional positional-only
     # parameter...
@@ -438,22 +523,74 @@ def iter_func_args(
 
         # 0-based index of the first parameter of the next iterated kind.
         args_index_kind_first = args_index_kind_last_after
+    # Else, that callable accepts *NO* optional positional-only parameters.
 
+    # ..................{ ITERATE ~ flexible                 }..................
     # If that callable accepts at least one mandatory flexible parameter...
     if args_len_flex_mandatory:
-        # 0-based index of the parameter following the last mandatory
-        # flexible parameter in the "args_name" tuple.
+        # 0-based index of the parameter following the last mandatory flexible
+        # parameter in the "args_name" tuple.
         args_index_kind_last_after = (
             args_index_kind_first + args_len_flex_mandatory)
 
-        # For each mandatory flexible parameter accepted by that callable,
-        # yield a tuple describing this parameter.
+        # If...
+        if (
+            # Omitting the first mandatory flexible parameter accepted by that
+            # callable if that callable is a C-based bound method descriptor
+            # encapsulating either an instance method bound to an instance of a
+            # class or a class method bound to a class *AND*...
+            is_omit_boundmethod_arg_first and
+            # That callable is such a C-based bound method descriptor...
+            is_func_boundmethod(func)
+        ):
+            # print(f'Ignoring bound method {repr(func)} first argument...')
+            # Increment the 0-based index of the first mandatory flexible
+            # parameter accepted by this method in the "args_name" tuple to
+            # account for the first mandatory flexible "self" parameter
+            # implicitly passed by this bound method descriptor to this method,
+            # effectively ignoring this "self" parameter.
+            #
+            # Note that:
+            # * We intentionally increment this index *AFTER* computing the
+            #   derivative "args_index_kind_last_after" index above with the
+            #   original value of this index.
+            # * Handling this common edge case enables:
+            #   * This generator to transparently support bound method
+            #     descriptors, which then enables...
+            #   * The private @beartype._decor._decornontype.beartype_pseudofunc
+            #     decorator to type-check the bound __call__() method descriptor
+            #     encapsulating the unbound __call__() dunder method defined on
+            #     the class of pseudo-callable objects, which then enables...
+            #   * The public @beartype.beartype decorator to type-check
+            #     pseudo-callable objects.
+            #
+            #   How? In this case, the aforementioned @beartype_pseudofunc
+            #   decorator wraps this bound method descriptor with a dynamically
+            #   generated wrapper function that does *NOT* accept a "self"
+            #   parameter, since a bound method does *NOT* accept a "self"
+            #   parameter. However, the code object of a bound method descriptor
+            #   is simply an alias of the code object of the corresponding
+            #   unbound method. Since the latter accepts a "self" parameter, so
+            #   too does the former. Thus, an internal discrepancy (arguably,
+            #   contradiction) arises between:
+            #
+            #   * The code object of a bound method descriptor, which declares
+            #     that callable object to accept a "self" parameter.
+            #   * The real-world calling semantics of a bound method descriptor,
+            #     which by definition accepts *NO* "self" parameter.
+            args_index_kind_first += 1
+        # Else, that callable is *NOT* such a descriptor (and is thus almost
+        # certainly a vanilla pure-Python callable).
+
+        # For each mandatory flexible parameter accepted by that callable, yield
+        # a tuple describing this parameter.
         for arg_name in args_name[
             args_index_kind_first:args_index_kind_last_after]:
             yield (ArgKind.POSITIONAL_OR_KEYWORD, arg_name, ArgMandatory,)
 
         # 0-based index of the first parameter of the next iterated kind.
         args_index_kind_first = args_index_kind_last_after
+    # Else, that callable accepts *NO* mandatory flexible parameters.
 
     # If that callable accepts at least one optional flexible parameter...
     if args_len_flex_optional:
@@ -479,7 +616,9 @@ def iter_func_args(
 
         # 0-based index of the first parameter of the next iterated kind.
         args_index_kind_first = args_index_kind_last_after
+    # Else, that callable accepts *NO* optional flexible parameters.
 
+    # ..................{ ITERATE ~ variadic positional      }..................
     # 0-based index of the parameter following the last keyword-only
     # parameter in the "args_name" tuple. This index is required by multiple
     # branches below (rather than merely one branch) and thus unconditionally
@@ -502,11 +641,13 @@ def iter_func_args(
     #   despite syntactic constraints on their lexical position.
     if is_arg_var_pos:
         yield (
-            ArgKind.VAR_POSITIONAL,
+            ArgKind.VARIADIC_POSITIONAL,
             args_name[args_index_kind_last_after],
             ArgMandatory,
         )
+    # Else, that callable accepts *NO* variadic positional parameter.
 
+    # ..................{ ITERATE ~ keyword-only             }..................
     # If that callable accepts at least one keyword-only parameter...
     if args_len_kwonly:
         # dict.get() method repeatedly called below and thus localized for
@@ -527,7 +668,9 @@ def iter_func_args(
                 #   placeholder "ArgMandatory" singleton.
                 args_defaults_kwonly_get(arg_name, ArgMandatory),
             )
+    # Else, that callable accepts *NO* keyword-only parameters.
 
+    # ..................{ ITERATE ~ variadic keyword         }..................
     # If that callable accepts a variadic keyword parameter...
     if is_arg_var_kw:
         # 0-based index of the variadic keyword parameter accepted by that
@@ -543,15 +686,8 @@ def iter_func_args(
 
         # Yield a tuple describing this parameter.
         yield (
-            ArgKind.VAR_KEYWORD,
+            ArgKind.VARIADIC_KEYWORD,
             args_name[args_index_kind_last_after],
             ArgMandatory,
         )
-
-# ....................{ PRIVATE ~ constants                }....................
-_ARGS_DEFAULTS_KWONLY_EMPTY: Dict[str, object] = {}
-'''
-Empty dictionary suitable for use as the default dictionary mapping the name of
-each optional keyword-only parameter accepted by a callable to the default
-value assigned to that parameter.
-'''
+    # Else, that callable accepts *NO* variadic keyword parameter.
