@@ -20,6 +20,7 @@ from beartype.typing import (
     Optional,
 )
 from beartype._util.utilobject import get_object_basename_scoped
+from beartype._data.func.datafunccodeobj import FUNC_CODEOBJ_NAME_MODULE
 from beartype._data.hint.datahinttyping import (
     LexicalScope,
     TypeException,
@@ -126,13 +127,13 @@ def get_func_locals(
     as type hints when annotating the methods of that class). When declaring a
     class, Python creates a stack frame for the declaration of that class whose
     local scope is the set of all class-scoped attributes declared in the body
-    of that class (including class variables, class methods, static methods,
-    and instance methods). When passed any method, this getter finds and
-    returns that local scope. When passed the ``MuhClass.muh_method` method
-    declared by the following example, for example, this getter returns the
-    local scope containing the key ``'muh_class_var'`` with value ``int``:
+    of that class -- including class variables, class methods, static methods,
+    and instance methods. When passed any method, this getter finds and returns
+    that local scope. When passed the ``MuhClass.muh_method` method declared by
+    the following example, for example, this getter returns the local scope
+    containing the key ``'muh_class_var'`` with value ``int``:
 
-    .. code-block:: python
+    .. code-block:: pycon
 
        >>> from typing import ClassVar
        >>> class MuhClass(object):
@@ -156,11 +157,11 @@ def get_func_locals(
 
     **This high-level getter is inefficient and should thus only be called if
     absolutely necessary.** Specifically, deciding the local scope for any
-    callable is an ``O(k)`` operation for ``k`` the distance in call stack
-    frames from the call of the current function to the call of the top-most
-    parent scope transitively declaring the passed callable in its submodule.
-    Ergo, this decision problem should be deferred as long as feasible to
-    minimize space and time consumption.
+    callable exhibits worst-case linear time complexity :math:`O(k)` for the
+    distance :math:`k` in call stack frames from the call of the current
+    function to the call of the top-most parent scope transitively declaring the
+    passed callable in its submodule. Ergo, this decision problem should be
+    deferred as long as feasible to minimize space and time consumption.
 
     Parameters
     ----------
@@ -215,16 +216,16 @@ def get_func_locals(
 
     # ..................{ IMPORTS                            }..................
     # Avoid circular import dependencies.
-    from beartype._data.func.datafunccodeobj import FUNC_CODEOBJ_NAME_MODULE
     from beartype._util.func.utilfunccodeobj import get_func_codeobj_or_none
     from beartype._util.func.utilfuncframe import iter_frames
     from beartype._util.func.utilfunctest import is_func_nested
+    from beartype._util.module.utilmodget import get_object_module_name_or_none
 
     # ..................{ NOOP                               }..................
     # Fully-qualified name of the module declaring the passed callable if that
     # callable was physically declared by an on-disk module *OR* "None"
     # otherwise (i.e., if that callable was dynamically declared in-memory).
-    func_module_name = func.__module__
+    func_module_name = get_object_module_name_or_none(func)
 
     # Note that we intentionally return the local scope for this wrapper rather
     # than wrappee callable, as local scope can *ONLY* be obtained by
@@ -274,8 +275,8 @@ def get_func_locals(
     # containing that nested callable (including that nested callable itself).
     #
     # Note that:
-    # * The set of all callables embodied by the current runtime call stack is
-    #   a (usually proper) superset of the set of all callables embodied by the
+    # * The set of all callables embodied by the current runtime call stack is a
+    #   (usually proper) superset of the set of all callables embodied by the
     #   lexical scopes encapsulating this nested callable. Ergo:
     #   * Some stack frames have no corresponding lexical scopes (e.g., stack
     #     frames embodying callables defined by different modules).
@@ -397,8 +398,9 @@ def get_func_locals(
     # stack frame if that callable is pure-Python *OR* "None".
     func_frame_codeobj: Optional[CodeType] = None
 
-    # Fully-qualified name of that callable's module.
-    func_frame_module_name = ''
+    # Fully-qualified name of the module defining that callable if any *OR*
+    # "None" (i.e., if that callable is defined outside a module).
+    func_frame_module_name: Optional[str] = ''
 
     # Unqualified name of that callable.
     func_frame_name = ''
@@ -421,12 +423,12 @@ def get_func_locals(
     #         return bruh
     for func_frame in iter_frames(
         # 0-based index of the first non-ignored frame following the last
-        # ignored frame, ignoring an additional frame embodying the current
-        # call to this getter.
+        # ignored frame, ignoring an additional frame embodying the current call
+        # to this getter.
         func_stack_frames_ignore=func_stack_frames_ignore + 1,
     ):
-        # Code object underlying this frame's scope if that scope is
-        # pure-Python *OR* "None" otherwise.
+        # Code object underlying this frame's scope if that scope is pure-Python
+        # *OR* "None" otherwise.
         func_frame_codeobj = get_func_codeobj_or_none(func_frame)
 
         # If this code object does *NOT* exist, this scope is C-based. In this
@@ -435,21 +437,35 @@ def get_func_locals(
             continue
         # Else, this code object exists, implying this scope to be pure-Python.
 
-        # Fully-qualified name of that scope's module.
-        func_frame_module_name = func_frame.f_globals['__name__']
+        # Fully-qualified name of the module defining this scope if any *OR*
+        # "None" otherwise (i.e., if this scope is defined outside a module).
+        func_frame_module_name = func_frame.f_globals.get('__name__')
 
-        # Unqualified name of that scope.
+        # If either...
+        if (
+            # This scope is defined outside a module *OR*...
+            func_frame_module_name is None or
+            # This scope is defined inside the root "beartype" package *OR*...
+            func_frame_module_name == 'beartype' or
+            # This scope is defined inside a "beartype" subpackage...
+            func_frame_module_name.startswith('beartype.')
+        ):
+            # Then silently ignore this scope and proceed to the next frame.
+            continue
+        # Else, this scope is defined inside a module that is *NOT* "beartype".
+
+        # Unqualified name of this scope.
         func_frame_name = func_frame_codeobj.co_name
         # print(f'{func_frame_name}() locals: {repr(func_frame.f_locals)}')
 
-        # If that scope is the placeholder string assigned by the active Python
-        # interpreter to all scopes encapsulating the top-most lexical scope of
-        # a module in the current call stack, this search has just crossed a
-        # module boundary and is thus no longer searching within the module
-        # declaring this nested callable and has thus failed to find the
+        # If this scope is the placeholder string assigned by Python to all
+        # scopes encapsulating the top-most lexical scope of a module
+        # declaration in the current call stack, this search has just crossed a
+        # module declaration boundary and is thus no longer searching within the
+        # module declaring this nested callable and has thus failed to find the
         # lexical scope of the parent declaring this nested callable. Why?
-        # Because that scope *MUST* necessarily be in the same module as that
-        # of this nested callable. In this case, raise an exception.
+        # Because this scope *MUST* necessarily be in the same module as that of
+        # this nested callable. In this case, raise an exception.
         if func_frame_name == FUNC_CODEOBJ_NAME_MODULE:
             raise _BeartypeUtilCallableScopeNotFoundException(
                 f'{func_name_qualified}() parent lexical scope '
@@ -494,6 +510,36 @@ def get_func_locals(
             # body of this parent callable. Well, isn't that special?
             func_scope = func_frame.f_locals
 
+            # If this local scope is *NOT* a "dict" instance, coerce this local
+            # scope into a "dict" instance. Why? Several justifiable reasons:
+            # * This getter is annotated as returning a "LexicalScope", which is
+            #   currently just a readable alias for "DictStrToAny", which is
+            #   itself an efficiency alias for "Dict[Str, object]". Ergo, static
+            #   type-checkers expect this getter to return "dict" instances.
+            # * Under Python <= 3.12, the "func_frame.f_locals" instance
+            #   variable actually is a "dict" instance.
+            # * Under Python >= 3.12, the "func_frame.f_locals" instance
+            #   variable actually is instead a "mappingproxy" instance. Although
+            #   interchangeable for many purposes, "dict" and "mappingproxy"
+            #   instances are *NOT* perfectly interchangeable. In particular,
+            #   callers of this function frequently pass this local scope to
+            #   the dict.update() method -- which expects the passed mapping to
+            #   also be a "dict" instance: e.g.,
+            #
+            #       cls_curr_locals = get_type_locals(
+            #           cls=cls_curr, exception_cls=exception_cls)
+            #   >   func_locals.update(cls_curr_locals)
+            #   E   TypeError: update() argument must be dict or another FrameLocalsProxy
+            #
+            #   Why? No idea. Ideally, the dict.update() method would accept
+            #   arbitrary mappings -- but it doesn't. Since it doesn't, we have
+            #   *NO* recourse but to preserve forward compatibility with future
+            #   Python versions by coercing non-"dict" to "dict" instances here
+            #   on behalf of the caller. It is what it is. We sigh! *sigh*
+            if not isinstance(func_scope, dict):
+                func_scope = dict(func_scope)
+            # Else, this local scope is already a "dict" instance.
+
             # Halt iteration.
             break
         # Else, that callable does *NOT* embody the current lexical scope to be
