@@ -12,14 +12,18 @@ This private submodule is *not* intended for importation by downstream callers.
 
 # ....................{ IMPORTS                            }....................
 from beartype.roar._roarexc import _BeartypeUtilCallableException
-from beartype.typing import Any
+from beartype.typing import (
+    Any,
+    Optional,
+)
+from beartype._cave._cavefast import MethodBoundInstanceOrClassType
 from beartype._data.hint.datahintfactory import TypeGuard
 from beartype._data.hint.datahinttyping import (
     Codeobjable,
     TypeException,
 )
-from beartype._util.cache.utilcachecall import callable_cached
-from beartype._util.func.arg.utilfuncargget import (
+# from beartype._util.cache.utilcachecall import callable_cached
+from beartype._util.func.arg.utilfuncarglen import (
     get_func_args_nonvariadic_len)
 from beartype._util.func.arg.utilfuncargtest import (
     is_func_arg_variadic_positional,
@@ -34,6 +38,7 @@ from inspect import (
 )
 
 # ....................{ CONSTANTS                          }....................
+#FIXME: Shift into the "beartype._data.func.datafunc" submodule, please.
 FUNC_NAME_LAMBDA = '<lambda>'
 '''
 Default name of all **pure-Python lambda functions** (i.e., function declared
@@ -44,7 +49,7 @@ Python initializes the names of *all* lambda functions to this lambda-specific
 placeholder string on lambda definition.
 
 Caveats
-----------
+-------
 **Usage of this placeholder to differentiate lambda from non-lambda callables
 invites false positives in unlikely edge cases.** Technically, malicious third
 parties may externally change the name of any lambda function *after* defining
@@ -55,7 +60,7 @@ AST-based parsing, which comes with its own substantial caveats, concerns,
 edge cases, and false positives. If you must pick your poison, pick this one.
 '''
 
-# ....................{ VALIDATORS                         }....................
+# ....................{ RAISERS                            }....................
 def die_unless_func_python(
     # Mandatory parameters.
     func: Codeobjable,
@@ -114,7 +119,63 @@ def die_unless_func_python(
             f'{exception_prefix}{repr(func)} not pure-Python function.')
     # Else, that callable is pure-Python.
 
-# ....................{ VALIDATORS ~ descriptors           }....................
+# ....................{ RAISERS ~ descriptors              }....................
+#FIXME: Unit test us up, please.
+def die_unless_func_boundmethod(
+    # Mandatory parameters.
+    func: Any,
+
+    # Optional parameters.
+    exception_cls: TypeException = _BeartypeUtilCallableException,
+    exception_prefix: str = '',
+) -> None:
+    '''
+    Raise an exception unless the passed object is a **C-based bound instance
+    method descriptor** callable implicitly instantiated and assigned on the
+    instantiation of an object whose class declares an instance function (whose
+    first parameter is typically named ``self``) as an instance variable of that
+    object such that that callable unconditionally passes that object as the
+    value of that first parameter on all calls to that callable).
+
+    Parameters
+    ----------
+    func : Any
+        Object to be inspected.
+    exception_cls : TypeException, optional
+        Type of exception to be raised. Defaults to
+        :class:`._BeartypeUtilCallableException`.
+    exception_prefix : str, optional
+        Human-readable label prefixing the representation of this object in the
+        exception message. Defaults to the empty string.
+
+    Raises
+    ------
+    exception_cls
+         If the passed object is *not* a bound method descriptor.
+
+    See Also
+    --------
+    :func:`.is_func_boundmethod`
+        Further details.
+    '''
+
+    # If this object is *NOT* a bound method descriptor, raise an exception.
+    if not is_func_boundmethod(func):
+        assert isinstance(exception_cls, type), (
+            f'{repr(exception_cls)} not class.')
+        assert issubclass(exception_cls, Exception), (
+            f'{repr(exception_cls)} not exception subclass.')
+        assert isinstance(exception_prefix, str), (
+            f'{repr(exception_prefix)} not string.')
+
+        # Raise a human-readable exception.
+        raise exception_cls(
+            f'{exception_prefix}{repr(func)} not '
+            f'C-based bound instance method descriptor.'
+        )
+    # Else, this object is a bound method descriptor.
+
+
 def die_unless_func_classmethod(
     # Mandatory parameters.
     func: Any,
@@ -257,7 +318,7 @@ def die_unless_func_staticmethod(
          If the passed object is *not* a static method descriptor.
 
     See Also
-    ----------
+    --------
     :func:`.is_func_staticmethod`
         Further details.
     '''
@@ -279,7 +340,7 @@ def die_unless_func_staticmethod(
     # Else, this object is a static method descriptor.
 
 # ....................{ TESTERS                            }....................
-def is_func_lambda(func: Any) -> bool:
+def is_func_lambda(func: Any) -> TypeGuard[Callable]:
     '''
     :data:`True` only if the passed object is a **pure-Python lambda function**
     (i.e., function declared as a ``lambda`` expression embedded in a larger
@@ -337,6 +398,42 @@ def is_func_python(func: object) -> TypeGuard[Callable]:
     return get_func_codeobj_or_none(func) is not None
 
 # ....................{ TESTERS ~ descriptor               }....................
+#FIXME: Unit test us up, please.
+def is_func_boundmethod(func: Any) -> TypeGuard[MethodBoundInstanceOrClassType]:
+    '''
+    :data:`True` only if the passed object is a **C-based bound instance method
+    descriptor** (i.e., callable implicitly instantiated and assigned on the
+    instantiation of an object whose class declares an instance function (whose
+    first parameter is typically named ``self``) as an instance variable of that
+    object such that that callable unconditionally passes that object as the
+    value of that first parameter on all calls to that callable).
+
+    Caveats
+    -------
+    Instance method objects are *only* directly accessible as instance
+    attributes. When accessed as either class attributes *or* via the low-level
+    :attr:`object.__dict__` dictionary, instance methods are only functions
+    (i.e., instances of the standard :class:`beartype.cave.FunctionType` type).
+
+    Instance method objects are callable. Indeed, the callability of instance
+    method objects is the entire point of instance method objects.
+
+    Parameters
+    ----------
+    func : object
+        Object to be inspected.
+
+    Returns
+    -------
+    bool
+        :data:`True` only if this object is a C-based bound instance method
+        descriptor.
+    '''
+
+    # Only the penitent one-liner shall pass.
+    return isinstance(func, MethodBoundInstanceOrClassType)
+
+
 def is_func_classmethod(func: Any) -> TypeGuard[classmethod]:
     '''
     :data:`True` only if the passed object is a **C-based unbound class method
@@ -350,11 +447,12 @@ def is_func_classmethod(func: Any) -> TypeGuard[classmethod]:
     -------
     Class method objects are *only* directly accessible via the low-level
     :attr:`object.__dict__` dictionary. When accessed as class or instance
-    attributes, class methods reduce to instances of the standard
-    :class:`MethodBoundInstanceOrClassType` type.
+    attributes, class methods are indistinguishable from **bound method
+    descriptors** (i.e., :class:`MethodBoundInstanceOrClassType` instances)
+    bound to that class.
 
     Class method objects are *not* callable, as their implementations fail to
-    define the ``__call__`` dunder method.
+    define the ``__call__()`` dunder method.
 
     Parameters
     ----------
@@ -520,7 +618,7 @@ def is_func_coro(func: object) -> TypeGuard[Callable]:
         :data:`True` only if this object is an asynchronous coroutine factory.
 
     See Also
-    ----------
+    --------
     :func:`inspect.iscoroutinefunction`
         Stdlib function strongly inspiring this implementation.
     '''
@@ -558,7 +656,7 @@ def is_func_async_generator(func: object) -> TypeGuard[Callable]:
         :data:`True` only if this object is an asynchronous generator.
 
     See Also
-    ----------
+    --------
     :func:`inspect.isasyncgenfunction`
         Stdlib function strongly inspiring this implementation.
     '''
@@ -595,7 +693,7 @@ def is_func_sync_generator(func: object) -> TypeGuard[Callable]:
         :data:`True` only if this object is a synchronous generator.
 
     See Also
-    ----------
+    --------
     :func:`inspect.isgeneratorfunction`
         Stdlib function strongly inspiring this implementation.
     '''
@@ -776,8 +874,13 @@ def is_func_wrapper(func: Any) -> TypeGuard[Callable]:
     return hasattr(func, '__wrapped__')
 
 
-@callable_cached
-def is_func_wrapper_isomorphic(func: Any) -> TypeGuard[Callable]:
+def is_func_wrapper_isomorphic(
+    # Mandatory parameters.
+    func: Any,
+
+    # Optional parameters.
+    wrapper: Optional[Callable] = None,
+) -> TypeGuard[Callable]:
     '''
     :data:`True` only if the passed object is an **isomorphic wrapper** (i.e.,
     callable decorated by the standard :func:`functools.wraps` decorator for
@@ -790,7 +893,14 @@ def is_func_wrapper_isomorphic(func: Any) -> TypeGuard[Callable]:
     decorated by an isomorphic decorator, which constitutes *most* real-world
     decorators of interest.
 
-    This tester is memoized for efficiency.
+    This tester is currently *not* memoized for efficiency, despite performing a
+    relatively non-trivial (albeit technically :math:`O(1)`) operation. Why?
+    Because this tester should typically be called at most once by the parent
+    :func:`beartype._util.func.utilfuncwrap.unwrap_func_all_isomorphic`
+    function, which is currently:
+
+    * The *only* other function calling this tester.
+    * Itself currently unmemoized.
 
     Caveats
     -------
@@ -802,6 +912,21 @@ def is_func_wrapper_isomorphic(func: Any) -> TypeGuard[Callable]:
     ----------
     func : object
         Object to be inspected.
+    wrapper : Optional[Callable]
+        Wrapper callable to be unwrapped in the event that the callable to be
+        inspected for isomorphism differs from the callable to be unwrapped.
+        Typically, these two callables are the same. Edge cases in which these
+        two callables differ include:
+
+        * When ``wrapper`` is a **pseudo-callable** (i.e., otherwise uncallable
+          object whose type renders that object callable by defining the
+          ``__call__()`` dunder method) *and* ``func`` is that ``__call__()``
+          dunder method. If that pseudo-callable wraps a lower-level callable,
+          then that pseudo-callable (rather than ``__call__()`` dunder method)
+          defines the ``__wrapped__`` instance variable providing that callable.
+
+        Defaults to :data:`None`, in which case this parameter *actually*
+        defaults to ``func``.
 
     Returns
     -------
@@ -809,24 +934,83 @@ def is_func_wrapper_isomorphic(func: Any) -> TypeGuard[Callable]:
         :data:`True` only if this object is an isomorphic decorator wrapper.
     '''
 
-    # If the passed callable is *NOT* a wrapper, immediately return false.
-    if not is_func_wrapper(func):
+    # If the caller failed to explicitly pass a callable to be unwrapped,
+    # default the callable to be unwrapped to the passed callable.
+    if wrapper is None:
+        wrapper = func
+    # Else, the caller explicitly passed a callable to be unwrapped. In this
+    # case, preserve that callable as is.
+
+    # If that callable is *NOT* a wrapper, immediately return false.
+    if not is_func_wrapper(wrapper):
         return False
     # Else, that callable is a wrapper.
 
+    # Number of non-variadic arguments permitted for this wrapper if isomorphic,
+    # defaulting to 0.
+    func_args_nonvariadic_len = 0
+
+    # If this object is a C-based bound method descriptor...
+    if is_func_boundmethod(func):
+        # Avoid circular import dependencies.
+        from beartype._util.func.utilfuncwrap import (
+            unwrap_func_boundmethod_once)
+        # print(f'Detecting bound method f{repr(func)} isomorphism...')
+
+        # Unwrap this descriptor to the pure-Python callable encapsulated by
+        # this descriptor.
+        func = unwrap_func_boundmethod_once(func)
+
+        # Permit this pure-Python callable to accept exactly one non-variadic
+        # argument, typically named "self" whose value is the object to which
+        # this bound method descriptor was bound at object instantiation time.
+        func_args_nonvariadic_len = 1
+    # Else, this object is *NOT* a C-based bound method descriptor.
+
     # Code object underlying that callable as is (rather than possibly unwrapped
     # to another code object entirely) if that callable is pure-Python *OR*
     # "None" otherwise (i.e., if that callable is C-based).
     func_codeobj = get_func_codeobj_or_none(func)
 
+    # If that callable is C-based...
+    if not func_codeobj:  # pragma: no cover
+        # print(f'Detecting C-based callable {repr(func)} isomorphism...')
+        # Return true only if that C-based callable is the __call__() dunder
+        # method of a pseudo-callable parent object. Although this tester
+        # *CANNOT* positively decide whether that object is isomorphic or not,
+        # *ALMOST* all __call__() dunder methods are C-based. Technically, this
+        # *COULD* constitute a false positive in various edge cases.
+        # Pragmatically, the alternatives are all worse. Blindly rejecting *ALL*
+        # C-based __call__() dunder methods as non-isomorphic would effectively
+        # prevent @beartype from decorating numerous pseudo-callable objects of
+        # interest, including:
+        # * Pseudo-callables dynamically generated by the third-party
+        #   "@jax.jit" decorator: e.g.,
+        #       from beartype import beartype
+        #       from jax import jit
+        #
+        #       # The @jax.jit decorator creates and returns a C-based
+        #       # pseudo-callable object defining an isomorphic __call__()
+        #       # dunder method. If this tester erroneously rejected that method
+        #       # as non-isomorphic, @beartype would be unable to decorate these
+        #       # pseudo-callable objects! Clearly, that would be bad.
+        #       @beartype
+        #       @jit
+        #       def muh_func(muh_arg: int) -> int:
+        #           return muh_arg
+        return func.__name__ == '__call__'
+    # Else, that callable is pure-Python.
+
     # Return true only if...
     return (
-        # That callable is pure-Python *AND*...
-        func_codeobj is not None and
-        # That callable accepts a variadic positional argument *AND*...
-        is_func_arg_variadic_positional(func_codeobj) and
-        # That callable accepts a variadic keyword argument *AND*...
-        is_func_arg_variadic_keyword(func_codeobj) and
-        # That callable accepts *NO* non-variadic arguments.
-        get_func_args_nonvariadic_len(func_codeobj) == 0
+        # That callable accepts no non-variadic arguments *AND*...
+        (
+            get_func_args_nonvariadic_len(func_codeobj) ==
+            func_args_nonvariadic_len
+        ) and
+        # That callable accepts variadic positional and/or keyword arguments.
+        (
+            is_func_arg_variadic_positional(func_codeobj) or
+            is_func_arg_variadic_keyword(func_codeobj)
+        )
     )
