@@ -31,7 +31,7 @@ from beartype._data.hint.pep.datapeprepr import (
     HINT_REPR_PREFIX_ARGS_0_OR_MORE_TO_SIGN,
     HINT_REPR_PREFIX_ARGS_1_OR_MORE_TO_SIGN,
     HINT_REPR_PREFIX_TRIE_ARGS_0_OR_MORE_TO_SIGN,
-    HINT_TYPE_NAME_TO_SIGN,
+    HINT_MODULE_NAME_TO_TYPE_BASENAME_TO_SIGN,
 )
 from beartype._data.hint.pep.sign.datapepsigncls import HintSign
 from beartype._data.hint.pep.sign.datapepsigns import (
@@ -43,18 +43,21 @@ from beartype._data.hint.pep.sign.datapepsigns import (
 from beartype._data.hint.pep.sign.datapepsignset import (
     HINT_SIGNS_ORIGIN_ISINSTANCEABLE,
 )
+from beartype._data.kind.datakinddict import DICT_EMPTY
 from beartype._util.cache.utilcachecall import callable_cached
 from beartype._util.hint.pep.proposal.pep484.utilpep484newtype import (
     is_hint_pep484_newtype_pre_python310)
 from beartype._util.hint.pep.proposal.pep484585.utilpep484585generic import (
     is_hint_pep484585_generic)
+from beartype._util.hint.pep.proposal.pep484585.utilpep484585tuple import (
+    get_hint_pep484585_sign_tuplefixed_or_same)
 from beartype._util.hint.pep.proposal.utilpep585 import (
     get_hint_pep585_generic_typevars,
     is_hint_pep585_builtin_subscripted,
     is_hint_pep585_generic,
 )
 from beartype._util.hint.pep.proposal.utilpep589 import is_hint_pep589
-from beartype._util.hint.pep.proposal.utilpep604 import (
+from beartype._util.hint.pep.proposal.utilpep484604 import (
     die_if_hint_pep604_inconsistent)
 from beartype._util.py.utilpyversion import (
     # IS_PYTHON_AT_LEAST_3_10,
@@ -69,8 +72,9 @@ from beartype._data.hint.datahinttyping import TupleTypes
 if IS_PYTHON_AT_LEAST_3_9:
     def get_hint_pep_args(hint: object) -> tuple:
 
-        # Return the value of the "__args__" dunder attribute if this hint
-        # defines this attribute *OR* "None" otherwise.
+        # Tuple of the zero or more child type hints subscripting this hint if
+        # this hint defines of the "__args__" dunder attribute *OR* "None"
+        # otherwise (i.e., if this hint fails to define this attribute).
         hint_args = getattr(hint, '__args__', None)
 
         # If this hint does *NOT* define this attribute, return the empty tuple.
@@ -78,9 +82,10 @@ if IS_PYTHON_AT_LEAST_3_9:
             return ()
         # Else, this hint defines this attribute.
         #
-        # If this hint appears to be unsubscripted, then this hint *WAS*
-        # actually subscripted by the empty tuple (e.g., "tuple[()]",
-        # "typing.Tuple[()]"). Why? Because:
+        # If this hint is subscripted by zero child type hints, this hint only
+        # superficially appears to be unsubscripted but was actually subscripted
+        # by the empty tuple (e.g., "tuple[()]", "typing.Tuple[()]"). Why?
+        # Because:
         # * Python 3.11 made the unfortunate decision of ambiguously conflating
         #   unsubscripted type hints (e.g., "tuple", "typing.Tuple") with type
         #   hints subscripted by the empty tuple, preventing downstream
@@ -91,8 +96,9 @@ if IS_PYTHON_AT_LEAST_3_9:
         #   continued to correctly declare an "__args__" dunder attribute of
         #   "((),)" until Python 3.11.
         #
-        # Disambiguate these two cases on behalf of callers by returning a tuple
-        # containing only the empty tuple rather than returning the empty tuple.
+        # Disambiguate these two cases on behalf of callers by returning a
+        # 1-tuple containing only the empty tuple (i.e., "((),)") rather than
+        # returning the empty tuple (i.e., "()").
         elif not hint_args:
             return _HINT_ARGS_EMPTY_TUPLE
         # Else, this hint is either subscripted *OR* is unsubscripted but not
@@ -105,11 +111,11 @@ if IS_PYTHON_AT_LEAST_3_9:
 else:
     def get_hint_pep_args(hint: object) -> tuple:
 
-        # Under python < 3.9, unparametrized generics have the attribute
+        # Under Python < 3.9, unparametrized generics have the attribute
         # "_special" set to True despite the actual "__args__" typically being a
         # "TypeVar" instance. Because we want to differentiate between
-        # unparametrized and parametrized generics, check whether the hint is
-        # "_special" and if so, we return the empty tuple instead of that
+        # unparametrized and parametrized generics, we check whether this hint
+        # is "_special" and if so, return the empty tuple instead of that
         # "TypeVar" instance.
         if getattr(hint, '_special', False):
             return ()
@@ -121,9 +127,11 @@ else:
 
 # Document this function regardless of implementation details above.
 get_hint_pep_args.__doc__ = '''
-    Tuple of all **typing arguments** (i.e., subscripted objects of the passed
-    PEP-compliant type hint listed by the caller at hint declaration time)
-    if any *or* the empty tuple otherwise.
+    Tuple of the zero or more **child type hints** subscripting (indexing) the
+    passed PEP-compliant type hint if this hint was subscripted *or* the empty
+    tuple otherwise (i.e., if this hint is unsubscripted and is thus either an
+    unsubscriptable type hint *or* a subscriptable type hint factory that is
+    unsubscripted).
 
     This getter is intentionally *not* memoized (e.g., by the
     :func:`callable_cached` decorator), as the implementation trivially reduces
@@ -139,7 +147,20 @@ get_hint_pep_args.__doc__ = '''
     logic attempting to directly access this attribute. Thus this function,
     which "fills in the gaps" by implementing this oversight.
 
-    **This getter never lies, unlike the comparable**
+    **This getter lies rarely due to subscription erasure** (i.e., the malicious
+    destruction of child type hints by parent type hint factories at
+    subscription time). Callers should not assume that the objects originally
+    subscripting this hint are still accessible. Although *most* hints preserve
+    their subscripted objects over their lifetimes, a small subset of edge-case
+    hints erase those objects at subscription time. This includes:
+
+    * :pep:`585`-compliant empty tuple type hints (i.e., ``tuple[()]``), which
+      despite being explicitly subscripted erroneously erase that subscription
+      at subscription time. This does *not* extend to :pep:`484`-compliant
+      empty tuple type hints (i.e., ``typing.Tuple[()]``), which correctly
+      preserve that subscripted empty tuple.
+
+    **This getter lies less than the comparable**
     :func:`get_hint_pep_typevars` **getter.** Whereas
     :func:`get_hint_pep_typevars` synthetically propagates type variables from
     child to parent type hints (rather than preserving the literal type
@@ -168,13 +189,15 @@ get_hint_pep_args.__doc__ = '''
 
     Examples
     --------
-        >>> import typing
-        >>> from beartype._util.hint.pep.utilpepget import (
-        ...     get_hint_pep_args)
-        >>> get_hint_pep_args(typing.Any)
-        ()
-        >>> get_hint_pep_args(typing.List[int, str, typing.Dict[str, str]])
-        (int, str, typing.Dict[str, str])
+    .. code-block:: python
+
+       >>> import typing
+       >>> from beartype._util.hint.pep.utilpepget import (
+       ...     get_hint_pep_args)
+       >>> get_hint_pep_args(typing.Any)
+       ()
+       >>> get_hint_pep_args(typing.List[int, str, typing.Dict[str, str]])
+       (int, str, typing.Dict[str, str])
     '''
 
 # ....................{ GETTERS ~ typevars                 }....................
@@ -230,6 +253,14 @@ get_hint_pep_typevars.__doc__ = '''
     hint declaration time ignoring duplicates) if any *or* the empty tuple
     otherwise.
 
+    This getter correctly handles both:
+
+    * **Direct parametrizations** (i.e., cases in which this object itself is
+      directly parametrized by type variables).
+    * **Superclass parametrizations** (i.e., cases in which this object is
+      indirectly parametrized by one or more superclasses of its class being
+      directly parametrized by type variables).
+
     This getter is intentionally *not* memoized (e.g., by the
     :func:`callable_cached` decorator), as the implementation trivially reduces
     to an efficient one-liner.
@@ -244,6 +275,31 @@ get_hint_pep_typevars.__doc__ = '''
     logic attempting to directly access this attribute. Thus this function,
     which "fills in the gaps" by implementing this oversight.
 
+    **Generics** (i.e., PEP-compliant type hints whose classes subclass one or
+    more public :mod:`typing` pseudo-superclasses) are often but *not* always
+    typevared. For example, consider the untypevared generic:
+
+    .. code-block:: pycon
+
+       >>> from typing import List
+       >>> class UntypevaredGeneric(List[int]): pass
+       >>> UntypevaredGeneric.__mro__
+       (__main__.UntypevaredGeneric, list, typing.Generic, object)
+       >>> UntypevaredGeneric.__parameters__
+       ()
+
+    Likewise, typevared hints are often but *not* always generic. For example,
+    consider the typevared non-generic:
+
+    .. code-block:: pycon
+
+       >>> from typing import List, TypeVar
+       >>> TypevaredNongeneric = List[TypeVar('T')]
+       >>> type(TypevaredNongeneric).__mro__
+       (typing._GenericAlias, typing._Final, object)
+       >>> TypevaredNongeneric.__parameters__
+       (~T,)
+
     Parameters
     ----------
     hint : object
@@ -258,17 +314,39 @@ get_hint_pep_typevars.__doc__ = '''
           value of that attribute.
         * Else, the empty tuple.
 
+    Parameters
+    ----------
+    hint : object
+        Object to be inspected.
+
+    Returns
+    -------
+    bool
+        :data:`True` only if this object is a PEP-compliant type hint
+        parametrized by one or more type variables.
+
     Examples
     --------
-        >>> import typing
-        >>> from beartype._util.hint.pep.utilpepget import (
-        ...     get_hint_pep_typevars)
-        >>> S = typing.TypeVar('S')
-        >>> T = typing.TypeVar('T')
-        >>> get_hint_pep_typevars(typing.Any)
-        ()
-        >>> get_hint_pep_typevars(typing.List[T, int, S, str, T])
-        (T, S)
+    .. code-block:: pycon
+
+       >>> import typing
+       >>> from beartype._util.hint.pep.utilpepget import (
+       ...     get_hint_pep_typevars)
+
+       >>> S = typing.TypeVar('S')
+       >>> T = typing.TypeVar('T')
+       >>> class UserList(typing.List[T]): pass
+
+       >>> get_hint_pep_typevars(typing.Any)
+       ()
+       >>> get_hint_pep_typevars(typing.List[int])
+       ()
+       >>> get_hint_pep_typevars(typing.List[T])
+       (T)
+       >>> get_hint_pep_typevars(UserList)
+       (T)
+       >>> get_hint_pep_typevars(typing.List[T, int, S, str, T])
+       (T, S)
     '''
 
 # ....................{ GETTERS ~ sign                     }....................
@@ -316,7 +394,7 @@ def get_hint_pep_sign(
 
     See Also
     --------
-    :func:`get_hint_pep_sign_or_none`
+    :func:`.get_hint_pep_sign_or_none`
         Further details.
     '''
 
@@ -433,26 +511,28 @@ def get_hint_pep_sign_or_none(hint: Any) -> Optional[HintSign]:
 
     Examples
     --------
-        >>> import typing
-        >>> from beartype._util.hint.pep.utilpepget import (
-        ...     get_hint_pep_sign_or_none)
+    .. code-block:: python
 
-        >>> get_hint_pep_sign_or_none(typing.Any)
-        typing.Any
-        >>> get_hint_pep_sign_or_none(typing.Union[str, typing.Sequence[int]])
-        typing.Union
+       >>> import typing
+       >>> from beartype._util.hint.pep.utilpepget import (
+       ...     get_hint_pep_sign_or_none)
 
-        >>> T = typing.TypeVar('T')
-        >>> get_hint_pep_sign_or_none(T)
-        HintSignTypeVar
+       >>> get_hint_pep_sign_or_none(typing.Any)
+       typing.Any
+       >>> get_hint_pep_sign_or_none(typing.Union[str, typing.Sequence[int]])
+       typing.Union
 
-        >>> class Genericity(typing.Generic[T]): pass
-        >>> get_hint_pep_sign_or_none(Genericity)
-        HintSignGeneric
+       >>> T = typing.TypeVar('T')
+       >>> get_hint_pep_sign_or_none(T)
+       HintSignTypeVar
 
-        >>> class Duplicity(typing.Iterable[T], typing.Container[T]): pass
-        >>> get_hint_pep_sign_or_none(Duplicity)
-        HintSignGeneric
+       >>> class Genericity(typing.Generic[T]): pass
+       >>> get_hint_pep_sign_or_none(Genericity)
+       HintSignGeneric
+
+       >>> class Duplicity(typing.Iterable[T], typing.Container[T]): pass
+       >>> get_hint_pep_sign_or_none(Duplicity)
+       HintSignGeneric
     '''
 
     # ..................{ IMPORTS                            }..................
@@ -503,14 +583,22 @@ def get_hint_pep_sign_or_none(hint: Any) -> Optional[HintSign]:
     hint_type = hint.__class__
 
     #FIXME: Is this actually the case? Do non-physical classes dynamically
-    #defined at runtime actually define these dunder attributes as well?
-    # Fully-qualified name of this class. Note that *ALL* classes are
-    # guaranteed to define the dunder attributes accessed here.
-    hint_type_name = f'{hint_type.__module__}.{hint_type.__qualname__}'
+    #defined at runtime actually define *BOTH* of these dunder attributes:
+    #* "hint_type.__module__"?
+    #* "hint_type.__qualname__"?
+    # Dictionary mapping from the unqualified basenames of the types of all
+    # PEP-compliant hints residing in the package defining this hint that are
+    # uniquely identifiable by those types to their identifying signs if that
+    # package is recognized *OR* the empty dictionary otherwise (i.e., if the
+    # package defining this hint is unrecognized).
+    hint_type_name_to_sign = HINT_MODULE_NAME_TO_TYPE_BASENAME_TO_SIGN.get(
+        hint_type.__module__, DICT_EMPTY)
 
     # Sign identifying this hint if this hint is identifiable by its classname
     # *OR* "None" otherwise.
-    hint_sign = HINT_TYPE_NAME_TO_SIGN.get(hint_type_name)
+    hint_sign = hint_type_name_to_sign.get(hint_type.__qualname__)
+    # print(f'hint_type: {hint_type}')
+    # print(f'hint_sign [by type]: {hint_sign}')
 
     # If this hint is identifiable by its classname, return this sign.
     if hint_sign:
@@ -545,10 +633,15 @@ def get_hint_pep_sign_or_none(hint: Any) -> Optional[HintSign]:
     # identifiable by its possibly unsubscripted representation *OR* "None".
     hint_sign = HINT_REPR_PREFIX_ARGS_0_OR_MORE_TO_SIGN.get(hint_repr_prefix)
 
-    # If this hint is identifiable by its possibly unsubscripted
-    # representation, return this sign.
+    # If this hint is identifiable by its possibly unsubscripted representation,
+    # return this sign.
     if hint_sign:
-        return hint_sign
+        # print(f'hint: {hint}; sign: {hint_sign}')
+        # Return this sign as is if this is any sign other than the ambiguous
+        # "HintSignTuple" sign *OR* reassign this sign to the unambiguous
+        # "HintSignTupleFixed" sign if this is a fixed-length tuple hint.
+        return get_hint_pep484585_sign_tuplefixed_or_same(
+            hint=hint, hint_sign=hint_sign)
     # Else, this hint is *NOT* identifiable by its possibly unsubscripted
     # representation.
     #
@@ -561,26 +654,16 @@ def get_hint_pep_sign_or_none(hint: Any) -> Optional[HintSign]:
             hint_repr_prefix)
 
         # If this hint is identifiable by its necessarily subscripted
-        # representation, return this sign.
+        # representation...
         if hint_sign:
-            return hint_sign
+            # Return this sign as is if this is any sign other than the
+            # ambiguous "HintSignTuple" sign *OR* reassign this sign to the
+            # unambiguous "HintSignTupleFixed" sign if this is a fixed-length
+            # tuple hint.
+            return get_hint_pep484585_sign_tuplefixed_or_same(
+                hint=hint, hint_sign=hint_sign)
         # Else, this hint is *NOT* identifiable by its necessarily subscripted
         # representation.
-
-        # # If this hint is inconsistent with respect to PEP 604-style new unions,
-        # # raise an exception. Although awkward, this is ultimately the ideal
-        # # location for this validation. Why? Because this validation:
-        # # * *ONLY* applies to hints permissible as items of PEP 604-compliant
-        # #   new unions; this means classes and subscripted generics. If this
-        # #   hint is identifiable by its classname, this hint is neither a class
-        # #   *NOR* subscripted generic. Since this hint is *NOT* identifiable by
-        # #   its classname, however, this hint could still be either a class *OR*
-        # #   subscripted generic. It's best not to ask.
-        # # * Does *NOT* apply to well-known type hints detected above (e.g.,
-        # #   those produced by Python itself, the standard library, and
-        # #   well-known third-party type hint factories), which are all
-        # #   guaranteed to be consistent with respect to PEP 604.
-        # die_if_hint_pep604_inconsistent(hint)
     # Else, this representation (and thus this hint) is unsubscripted.
 
     # ..................{ PHASE ~ repr : trie                }..................
