@@ -11,17 +11,27 @@ This private submodule is *not* intended for importation by downstream callers.
 '''
 
 # ....................{ IMPORTS                            }....................
-from beartype.meta import URL_PEP585_DEPRECATIONS
 from beartype.roar import (
     BeartypeDecorHintPepException,
     BeartypeDecorHintPepUnsupportedException,
     BeartypeDecorHintPep484Exception,
-    BeartypeDecorHintPep585DeprecationWarning,
 )
-from beartype.typing import NoReturn
+from beartype.typing import (
+    Dict,
+    NoReturn,
+)
 from beartype._data.hint.datahinttyping import TypeException
-from beartype._data.hint.pep.datapeprepr import (
-    HINTS_PEP484_REPR_PREFIX_DEPRECATED)
+from beartype._data.hint.pep.sign.datapepsigncls import HintSign
+from beartype._data.hint.pep.sign.datapepsigns import (
+    HintSignAnnotated,
+    HintSignGeneric,
+    HintSignOptional,
+    HintSignNewType,
+    HintSignPep695TypeAlias,
+    HintSignProtocol,
+    HintSignTypeVar,
+    HintSignUnion,
+)
 from beartype._data.hint.pep.sign.datapepsignset import (
     HINT_SIGNS_SUPPORTED,
     HINT_SIGNS_TYPE_MIMIC,
@@ -29,14 +39,20 @@ from beartype._data.hint.pep.sign.datapepsignset import (
 from beartype._data.module.datamodtyping import TYPING_MODULE_NAMES
 from beartype._util.cache.utilcachecall import callable_cached
 from beartype._util.hint.pep.proposal.pep484.utilpep484 import (
-    is_hint_pep484_ignorable_or_none)
-from beartype._util.hint.pep.proposal.utilpep544 import (
-    is_hint_pep544_ignorable_or_none)
-from beartype._util.hint.pep.proposal.utilpep593 import (
-    is_hint_pep593_ignorable_or_none)
+    is_hint_pep484_typevar_ignorable,
+)
+from beartype._util.hint.pep.proposal.pep484.utilpep484newtype import (
+    is_hint_pep484_newtype_ignorable)
+from beartype._util.hint.pep.proposal.pep484585.utilpep484585generic import (
+    is_hint_pep484585_generic_ignorable)
+from beartype._util.hint.pep.proposal.utilpep484604 import (
+    is_hint_pep484604_union_ignorable)
+from beartype._util.hint.pep.proposal.utilpep544 import is_hint_pep544_ignorable
+from beartype._util.hint.pep.proposal.utilpep593 import is_hint_pep593_ignorable
+from beartype._util.hint.pep.proposal.utilpep695 import is_hint_pep695_ignorable
 from beartype._util.module.utilmodget import get_object_module_name_or_none
 from beartype._util.utilobject import get_object_type_unless_type
-from warnings import warn
+from collections.abc import Callable
 
 # ....................{ EXCEPTIONS                         }....................
 def die_if_hint_pep(
@@ -221,107 +237,6 @@ def die_if_hint_pep_unsupported(
     )
 
 # ....................{ WARNINGS                           }....................
-#FIXME: Resurrect support for the passed "warning_prefix" parameter. We've
-#currently disabled this parameter as it's typically just a non-human-readable
-#placeholder substring *NOT* intended to be exposed to end users (e.g.,
-#"$%ROOT_PITH_LABEL/~"). For exceptions, we simply catch raised exceptions and
-#replace such substrings with human-readable equivalents. Can we perform a
-#similar replacement for warnings?
-
-def warn_if_hint_pep_deprecated(
-    # Mandatory parameters.
-    hint: object,
-
-    # Optional parameters.
-    warning_prefix: str = '',
-) -> None:
-    '''
-    Emit a non-fatal warning if the passed PEP-compliant type hint is
-    **deprecated** (i.e., obsoleted by an equivalent type hint or set of type
-    hints standardized under one or more recent PEPs).
-
-    This validator is intentionally *not* memoized (e.g., by the
-    :func:`callable_cached` decorator), as the implementation trivially reduces
-    to an efficient one-liner.
-
-    Parameters
-    ----------
-    hint : object
-        PEP-compliant type hint to be inspected.
-    warning_prefix : str, optional
-        Human-readable label prefixing the representation of this object in the
-        warning message. Defaults to the empty string.
-
-    Warns
-    -----
-    BeartypeDecorHintPep585DeprecationWarning
-        If this hint is a :pep:`484`-compliant type hint deprecated by
-        :pep:`585` *and* the active Python interpreter targets Python >= 3.9.
-    '''
-
-    #FIXME: Uncomment *AFTER* resolving the "FIXME:" above.
-    #FIXME: Unit test that this string contains *NO* non-human-readable
-    #placeholder substrings. Note that the existing
-    #"beartype_test.a00_unit.decor.code.test_codemain" submodule contains
-    #relevant logic currently disabled for reasons that hopefully no longer
-    #apply. *Urgh!*
-    # assert isinstance(exception_prefix, str), f'{repr(exception_prefix)} not string.'
-
-    # If this hint is a PEP 484-compliant type hint originating from an origin
-    # type (e.g., "typing.List[int]"), this hint has been deprecated by the
-    # equivalent PEP 585-compliant type hint (e.g., "list[int]"). In this case,
-    # emit a non-fatal PEP 585-specific deprecation warning.
-    if is_hint_pep_deprecated(hint):
-        #FIXME: Resolve issue #73 by additionally passing the "stacklevel"
-        #keyword parameter. Doing so will probably require:
-        #* Refactoring this function to accept an *OPTIONAL*
-        #  "warning_stack_level" parameter. Why optional? Because this
-        #  parameter is only reliably decidable under Python interpreters
-        #  defining the implementation-specific sys._getframe() function, which
-        #  is admittedly all of them everyone cares about. Nonetheless, do this
-        #  right. If non-"None", conditionally pass this level below as:
-        #      stacklevel=(
-        #          warning_stack_level
-        #          if warning_stack_level is not None else
-        #          1  # <-- the official default value for this parameter
-        #      ),
-        #* Refactoring all callers of this function to pass that parameter.
-        #  Here's where things get dicey, however. Passing this parameter
-        #  reliably (so, *NOT* just hard-coding a magic number somewhere and
-        #  praying devoutly for the best) will require computing the distance
-        #  between the current function and the first external third-party
-        #  non-@beartype scope on the call stack. So, maybe we want to actually
-        #  *NOT* refactor this function to accept an *OPTIONAL*
-        #  "warning_stack_level" parameter but instead locally define
-        #  "warning_stack_level" based on an iterative O(n) search up the
-        #  stack? That's obviously non-ideal -- but still absolutely preferable
-        #  to the current untenable situation of emitting unreadable warnings.
-        #
-        #Okay. So, scrap everything above. Let's instead:
-        #* Define a new warn_safe() wrapper function (somewhere in
-        #  "beartype._util", clearly) that automatically decides the
-        #  appropriate "stacklevel" by iterating up the call stack to compute
-        #  the distance between the current function and the first external
-        #  third-party non-@beartype scope. We perform similar iteration when
-        #  resolving PEP 563-based deferred annotations, so that would probably
-        #  be the first place to clean inspiration. That code is rock solid and
-        #  well-tested. Things get non-trivial fast here, sadly. *sigh*
-        #
-        #See also: https://docs.python.org/3/library/warnings.html#warnings.warn
-        warn(
-            (
-                f'PEP 484 type hint {repr(hint)} deprecated by PEP 585. '
-                f'This hint is scheduled for removal in the first Python '
-                f'version released after October 5th, 2025. To resolve this, '
-                f'import this hint from "beartype.typing" rather than "typing". '
-                f'For further commentary and alternatives, see also:\n'
-                f'    {URL_PEP585_DEPRECATIONS}'
-            ),
-            BeartypeDecorHintPep585DeprecationWarning,
-        )
-    # Else, this hint is *NOT* deprecated. In this case, reduce to a noop.
-
-
 #FIXME: Unit test us up.
 #FIXME: Actually use us in place of die_if_hint_pep_unsupported().
 #FIXME: Actually, it's unclear whether we still require or desire this. See
@@ -447,69 +362,71 @@ def is_hint_pep(hint: object) -> bool:
     return hint_sign is not None
 
 
-def is_hint_pep_deprecated(hint: object) -> bool:
-    '''
-    :data:`True` only if the passed object is a **PEP-compliant deprecated type
-    hint** (i.e., obsoleted by an equivalent type hint or set of type hints
-    standardized under one or more recent PEPs).
+#FIXME: Currently unused but preserved for posterity. *shrug*
+# def is_hint_pep_deprecated(hint: object) -> bool:
+#     '''
+#     :data:`True` only if the passed PEP-compliant type hint is **deprecated**
+#     (i.e., obsoleted by an equivalent PEP-compliant type hint standardized by a
+#     more recently released PEP).
+#
+#     This tester is intentionally *not* memoized (e.g., by the
+#     ``callable_cached`` decorator), as this tester is currently *only* called at
+#     test time from our test suite.
+#
+#     Parameters
+#     ----------
+#     hint : object
+#         PEP-compliant type hint to be inspected.
+#
+#     Returns
+#     -------
+#     bool
+#         :data:`True` only if this PEP-compliant type hint is deprecated.
+#     '''
+#
+#     # Avoid circular import dependencies.
+#     from beartype._util.hint.pep.utilpepget import get_hint_pep_sign
+#
+#     # Sign uniquely identifying this hint.
+#     hint_sign = get_hint_pep_sign(hint)
+#
+#     # Return true only if either...
+#     return (
+#         # This sign is that of an unconditionally deprecated type hint *OR*...
+#         hint_sign in HINT_SIGNS_DEPRECATED or
+#         # This is a PEP 484-compliant type hint (e.g., "typing.List[str]")
+#         # conditionally deprecated by an equivalent PEP 585-compliant type hint
+#         # (e.g., "list[str]") under Python >= 3.9.
+#         #
+#         # Note that, in this case, the sign of this hint does *NOT* convey
+#         # enough metadata to ascertain whether this hint is deprecated. Ergo, a
+#         # non-trivial tester dedicated to this discernment is required: e.g.,
+#         # * "list[str]" has the sign "HintSignList" but is *NOT* deprecated.
+#         # * "typing.List[str]" has the sign "HintSignList" but is deprecated.
+#         is_hint_pep484_deprecated(hint)
+#     )
 
-    This tester is intentionally *not* memoized (e.g., by the
-    :func:`callable_cached` decorator), as the implementation trivially reduces
-    to an efficient one-liner.
 
-    Parameters
-    ----------
-    hint : object
-        Object to be inspected.
-
-    Returns
-    -------
-    bool
-        :data:`True` only if this object is a PEP-compliant deprecated type
-        hint.
-    '''
-
-    # Avoid circular import dependencies.
-    from beartype._util.hint.utilhintget import get_hint_repr
-
-    # Machine-readable representation of this hint.
-    hint_repr = get_hint_repr(hint)
-
-    # Substring of the machine-readable representation of this hint preceding
-    # the first "[" delimiter if this representation contains that delimiter
-    # *OR* this representation as is otherwise.
-    #
-    # Note that the str.partition() method has been profiled to be the
-    # optimally efficient means of parsing trivial prefixes.
-    hint_repr_bare, _, _ = hint_repr.partition('[')
-
-    # Return true only if this hint is a PEP 484-compliant type hint originating
-    # from an origin type (e.g., "typing.List[int]").
-    return hint_repr_bare in HINTS_PEP484_REPR_PREFIX_DEPRECATED
-
-# ....................{ TESTERS ~ ignorable                }....................
-#FIXME: *EXTREMELY INEFFICIENT.* See commentary below, please.
 def is_hint_pep_ignorable(hint: object) -> bool:
     '''
-    :data:`True` only if the passed object is a **deeply ignorable PEP-compliant
-    type hint** (i.e., PEP-compliant type hint shown to be ignorable only after
-    recursively inspecting the contents of this hint).
+    :data:`True` only if the passed PEP-compliant type hint is **deeply
+    ignorable** (i.e., shown to be ignorable only after recursively inspecting
+    the contents of this hint).
 
     This tester is intentionally *not* memoized (e.g., by the
-    :func:`callable_cached` decorator), as this tester is only safely callable
-    by the memoized parent
+    :func:`beartype._util.cache.utilcachecall.callable_cached` decorator), as
+    This tester is only safely callable by the memoized parent
     :func:`beartype._util.hint.utilhinttest.is_hint_ignorable` tester.
 
     Parameters
     ----------
     hint : object
-        Object to be inspected.
+        PEP-compliant type hint to be inspected.
 
     Returns
     -------
     bool
-        :data:`True` only if this object is a deeply ignorable PEP-compliant
-        type hint.
+        :data:`True` only if this PEP-compliant type hint is deeply ignorable.
 
     Warns
     -----
@@ -530,57 +447,52 @@ def is_hint_pep_ignorable(hint: object) -> bool:
     # Sign uniquely identifying this hint.
     hint_sign = get_hint_pep_sign(hint)
 
-    #FIXME: *EXTREMELY INEFFICIENT*. What were we thinking? Honestly. This is an
-    #O(N) operation when this should instead be an O(1) operation. Refactor
-    #this immediately to instead resemble the
-    #beartype._check.convert.checkreduce._reduce_hint_cached() function.
-    #Notably:
-    #* Define a new "_HINT_SIGN_TO_IS_HINT_PEP_IGNORABLE_TESTER" private global
-    #  dictionary, refactored from the "_IS_HINT_PEP_IGNORABLE_TESTERS"
-    #  iterable.
-    #* Remove the "_IS_HINT_PEP_IGNORABLE_TESTERS" iterable.
-    #* Refactor this logic to perform a simple lookup into this dictionary.
-    #
-    #We are facepalming ourselves as we speak.
+    # Ignorer (i.e., callable testing whether this hint is ignorable) if an
+    # ignorer for hints of this sign was registered *OR* "None" otherwise (i.e.,
+    # if *NO* ignorer was registered, in which case this hint is unignorable).
+    is_hint_ignorable = _HINT_SIGN_TO_IS_HINT_IGNORABLE.get(hint_sign)
 
-    # For each PEP-specific function testing whether this hint is an ignorable
-    # type hint fully compliant with that PEP...
-    for is_hint_pep_ignorable_tester in _IS_HINT_PEP_IGNORABLE_TESTERS:
-        # True only if this hint is a ignorable under this PEP, False only if
-        # this hint is unignorable under this PEP, and None if this hint is
-        # *NOT* compliant with this PEP.
-        is_hint_pep_ignorable_or_none = is_hint_pep_ignorable_tester(
-            hint, hint_sign)
+    # Return either...
+    return (
+        # If an ignorer for hints of this sign was registered, the boolean
+        # returned when passing this ignorer this hint);
+        is_hint_ignorable(hint)
+        if is_hint_ignorable else
+        # Else, *NO* ignorer for hints of this sign was registered, implying
+        # this hint to be unignorable. Return false.
+        False
+    )
 
-        # If this hint is compliant with this PEP...
-        # print(f'{is_hint_pep_ignorable_or_none} = {is_hint_pep_ignorable_tester}({hint}, {hint_sign})')
-        if is_hint_pep_ignorable_or_none is not None:
-            #FIXME: Uncomment *AFTER* we properly support type variables. Since
-            #we currently ignore type variables, uncommenting this now would
-            #raise spurious warnings for otherwise unignorable and absolutely
-            #unsuspicious generics and protocols parametrized by type
-            #variables, which would be worse than the existing situation.
 
-            # # If this hint is ignorable under this PEP, warn the user this hint
-            # # is deeply ignorable. (See the docstring for justification.)
-            # if is_hint_pep_ignorable_or_none:
-            #     warn(
-            #         (
-            #             f'Ignorable PEP type hint {repr(hint)} '
-            #             f'typically not intended to be ignored.'
-            #         ),
-            #         BeartypeDecorHintPepIgnorableDeepWarning,
-            #     )
+#FIXME: Unit test us up, please.
+def is_hint_pep_subscripted(hint: object) -> bool:
+    '''
+    :data:`True` only if the passed PEP-compliant type hint is **subscripted**
+    (i.e., indexed by one or more child type hints).
 
-            # Return this boolean.
-            return is_hint_pep_ignorable_or_none
-        # Else, this hint is *NOT* compliant with this PEP. In this case,
-        # silently continue to the next such tester.
+    This tester is intentionally *not* memoized (e.g., by the
+    :func:`beartype._util.cache.utilcachecall.callable_cached` decorator), as
+    the implementation trivially reduces to an efficient one-liner.
+
+    Parameters
+    ----------
+    hint : object
+        PEP-compliant type hint to be inspected.
+
+    Returns
+    -------
+    bool
+        :data:`True` only if this PEP-compliant type hint is subscripted.
+    '''
+
+    # Avoid circular import dependencies.
+    from beartype._util.hint.pep.utilpepget import get_hint_pep_args
+
+    # Return true only if the tuple of all child type hints subscripting this
+    # hint contains one or more child type hints.
+    return bool(get_hint_pep_args(hint))
 
-    # Else, this hint is *NOT* deeply ignorable. In this case, return false.
-    return False
 
-# ....................{ TESTERS ~ supported                }....................
 @callable_cached
 def is_hint_pep_supported(hint: object) -> bool:
     '''
@@ -746,159 +658,70 @@ def is_hint_pep_type_typing(hint: object) -> bool:
     # In short, there is no general-purpose clever solution. *sigh*
     return hint_type.__module__ in TYPING_MODULE_NAMES
 
-# ....................{ TESTERS ~ args                     }....................
-#FIXME: Overkill. Replace directly with a simple test, please.
+# ....................{ PRIVATE ~ dicts                    }....................
+# Note that these type hints would ideally be defined with the mypy-specific
+# "callback protocol" pseudostandard, documented here:
+#     https://mypy.readthedocs.io/en/stable/protocols.html#callback-protocols
 #
-#Note that the corresponding unit test should be preserved, as that test is
-#essential to ensuring sanity across type hints and Python versions.
-def is_hint_pep_args(hint: object) -> bool:
-    '''
-    :data:`True` only if the passed object is a **subscripted PEP-compliant type
-    hint** (i.e., PEP-compliant type hint directly indexed by one or more
-    objects).
+# Doing so would enable static type-checkers to type-check that the values of
+# this dictionary are valid ignorer functions. Sadly, that pseudostandard is
+# absurdly strict to the point of practical uselessness. Attempting to conform
+# to that pseudostandard would require refactoring *ALL* ignorer functions to
+# explicitly define the same signature. However, we have intentionally *NOT*
+# done that. Why? Doing so would substantially increase the fragility of this
+# API by preventing us from readily adding and removing infrequently required
+# parameters (e.g., "cls_stack", "pith_name"). Callback protocols suck, frankly.
+_HINT_SIGN_TO_IS_HINT_IGNORABLE: Dict[HintSign, Callable] = {
+    # ..................{ PEP 484                            }..................
+    # Ignore *ALL* PEP 484-compliant "NewType"-style type aliases aliasing
+    # ignorable type hints.
+    HintSignNewType: is_hint_pep484_newtype_ignorable,
 
-    This tester is intentionally *not* memoized (e.g., by the
-    :func:`.callable_cached` decorator), as the implementation trivially reduces
-    to an efficient one-liner.
+    # Ignore *ALL* PEP 484-compliant type variables.
+    HintSignTypeVar: is_hint_pep484_typevar_ignorable,
 
-    Caveats
-    -------
-    **Callers should not assume that the objects originally subscripting this
-    hint are still accessible.** Although *most* hints preserve their
-    subscripted objects over their lifetimes, a small subset of edge-case hints
-    erase those objects at subscription time. This includes:
+    # ..................{ PEP (484|585)                      }..................
+    # Ignore *ALL* PEP 484- and 585-compliant "Generic[...]" subscriptions.
+    HintSignGeneric: is_hint_pep484585_generic_ignorable,
 
-    * :pep:`585`-compliant empty tuple type hints (i.e., ``tuple[()]``), which
-      despite being explicitly subscripted erroneously erase that subscription
-      at subscription time. This does *not* extend to :pep:`484`-compliant
-      empty tuple type hints (i.e., ``typing.Tuple[()]``), which correctly
-      preserve that subscripted empty tuple.
+    # ..................{ PEP (484|604)                      }..................
+    # Ignore *ALL* PEP 484- and 604-compliant unions subscripted by one or more
+    # ignorable type hints.
+    HintSignOptional: is_hint_pep484604_union_ignorable,
+    HintSignUnion:    is_hint_pep484604_union_ignorable,
 
-    Parameters
-    ----------
-    hint : object
-        Object to be inspected.
+    # ..................{ PEP 544                            }..................
+    # Ignore *ALL* PEP 544-compliant "typing.Protocol[...]" subscriptions.
+    HintSignProtocol: is_hint_pep544_ignorable,
 
-    Returns
-    -------
-    bool
-        :data:`True` only if this object is a subscripted PEP-compliant type
-        hint.
-    '''
+    # ..................{ PEP 593                            }..................
+    # Ignore *ALL* PEP 593-compliant "typing.Annotated[...]" type hints except
+    # those indexed by one or more beartype validators.
+    HintSignAnnotated: is_hint_pep593_ignorable,
 
-    # Avoid circular import dependencies.
-    from beartype._util.hint.pep.utilpepget import get_hint_pep_args
-
-    # Return true only if this hint is subscripted by one or more arguments.
-    return bool(get_hint_pep_args(hint))
-
-# ....................{ TESTERS ~ typevars                 }....................
-#FIXME: Overkill. Replace directly with a simple test, please.
-#
-#Note that the corresponding unit test should be preserved, as that test is
-#essential to ensuring sanity across type hints and Python versions.
-def is_hint_pep_typevars(hint: object) -> bool:
-    '''
-    :data:`True` only if the passed object is a PEP-compliant type hint
-    parametrized by one or more **type variables** (i.e., instances of the
-    :class:`TypeVar` class).
-
-    This tester detects both:
-
-    * **Direct parametrizations** (i.e., cases in which this object itself is
-      directly parametrized by type variables).
-    * **Superclass parametrizations** (i.e., cases in which this object is
-      indirectly parametrized by one or more superclasses of its class being
-      directly parametrized by type variables).
-
-    This tester is intentionally *not* memoized (e.g., by the
-    :func:`callable_cached` decorator), as the implementation trivially reduces
-    to an efficient one-liner.
-
-    Semantics
-    ---------
-    **Generics** (i.e., PEP-compliant type hints whose classes subclass one or
-    more public :mod:`typing` pseudo-superclasses) are often but *not* always
-    typevared. For example, consider the untypevared generic:
-
-        >>> from typing import List
-        >>> class UntypevaredGeneric(List[int]): pass
-        >>> UntypevaredGeneric.__mro__
-        (__main__.UntypevaredGeneric, list, typing.Generic, object)
-        >>> UntypevaredGeneric.__parameters__
-        ()
-
-    Likewise, typevared hints are often but *not* always generic. For example,
-    consider the typevared non-generic:
-
-        >>> from typing import List, TypeVar
-        >>> TypevaredNongeneric = List[TypeVar('T')]
-        >>> type(TypevaredNongeneric).__mro__
-        (typing._GenericAlias, typing._Final, object)
-        >>> TypevaredNongeneric.__parameters__
-        (~T,)
-
-    Parameters
-    ----------
-    hint : object
-        Object to be inspected.
-
-    Returns
-    -------
-    bool
-        :data:`True` only if this object is a PEP-compliant type hint
-        parametrized by one or more type variables.
-
-    Examples
-    --------
-        >>> import typing
-        >>> from beartype._util.hint.pep.utilpeptest import (
-        ...     is_hint_pep_typevars)
-        >>> T = typing.TypeVar('T')
-        >>> class UserList(typing.List[T]): pass
-        # Unparametrized type hint.
-        >>> is_hint_pep_typevars(typing.List[int])
-        False
-        # Directly parametrized type hint.
-        >>> is_hint_pep_typevars(typing.List[T])
-        True
-        # Superclass-parametrized type hint.
-        >>> is_hint_pep_typevars(UserList)
-        True
-    '''
-
-    # Avoid circular import dependencies.
-    from beartype._util.hint.pep.utilpepget import get_hint_pep_typevars
-
-    # Return true only if this hint is parametrized by one or more type
-    # variables, trivially detected by testing whether the tuple of all type
-    # variables parametrizing this hint is non-empty.
-    return bool(get_hint_pep_typevars(hint))
-
-# ....................{ PRIVATE ~ tuples                   }....................
-_IS_HINT_PEP_IGNORABLE_TESTERS = (
-    is_hint_pep484_ignorable_or_none,
-    is_hint_pep544_ignorable_or_none,
-    is_hint_pep593_ignorable_or_none,
-)
+    # ..................{ PEP 695                            }..................
+    # Ignore *ALL* PEP 695-compliant type aliases aliasing ignorable type hints.
+    HintSignPep695TypeAlias: is_hint_pep695_ignorable,
+}
 '''
-Tuple of all PEP-specific functions testing whether the passed object is an
-ignorable type hint fully compliant with a specific PEP.
+Dictionary mapping from each sign uniquely identifying PEP-compliant type hints
+to that sign's **ignorer** (i.e., low-level function testing whether the passed
+type hint identified by that sign is deeply ignorable).
 
-Each such function is expected to have a signature resembling:
+Each value of this dictionary is expected to have a signature resembling:
 
 .. code-block:: python
 
-    def is_hint_pep{PEP_NUMBER}_ignorable_or_none(
-        hint: object, hint_sign: HintSign) -> Optional[bool]:
-        ...
+   def is_hint_pep{pep_number}_ignorable(hint: object) -> bool: ...
 
-Each such function is expected to return either:
+Note that:
 
-* If the passed object is fully compliant with that PEP:
-
-    * If this object is ignorable, :data:`True`.
-    * Else, :data:`False`.
-
-* If this object is *not* fully compliant with that PEP, :data:`None`.
+* Ignorers do *not* need to validate the passed type hint as being of the
+  expected sign. By design, an ignorer is only ever passed a type hint of the
+  expected sign.
+* Ignorers should *not* be memoized (e.g., by the
+  `callable_cached`` decorator). Since the higher-level
+  :func:`.is_hint_pep_ignorable` function that is the sole entry point to
+  calling all lower-level ignorers is itself effectively memoized, ignorers
+  themselves neither require nor benefit from memoization.
 '''
