@@ -14,8 +14,15 @@ This private submodule is *not* intended for importation by downstream callers.
 
 # ....................{ IMPORTS                            }....................
 from beartype.claw._importlib.clawimpcache import ModuleNameToBeartypeConf
-from beartype.claw._pkg.clawpkgtrie import PackagesTrie
-from beartype.typing import Optional
+from beartype.claw._package.clawpkgtrie import (
+    PackagesTrieBlacklist,
+    PackagesTrieBlacklisted,
+    PackagesTrieWhitelist,
+)
+from beartype.typing import (
+    TYPE_CHECKING,
+    Optional,
+)
 from beartype._data.hint.datahinttyping import ImportPathHook
 from threading import RLock
 
@@ -50,13 +57,20 @@ class BeartypeClawState(object):
         imported submodule of each package previously registered in our global
         package trie to the beartype configuration configuring type-checking by
         the :func:`beartype.beartype` decorator of that submodule).
-    packages_trie : PackagesTrie
-        **Package configuration trie** (i.e., non-thread-safe recursively nested
+    packages_trie_blacklist : PackagesTrieWhitelist
+        **Package trie blacklist** (i.e., non-thread-safe recursively nested
         dictionary implementing a prefix tree such that each key-value pair maps
-        from the unqualified basename of each subpackage to be type-checked on
-        the first importation of that subpackage to another instance of the
-        :class:`.PackagesTrie` class similarly describing the sub-subpackages of
-        that subpackage).
+        from the unqualified basename of each subpackage to *not* be implicitly
+        type-checked on the first importation of that subpackage to another
+        instance of the :class:`.PackagesTrieWhitelist` class similarly describing the
+        sub-subpackages of that subpackage).
+    packages_trie_whitelist : PackagesTrieWhitelist
+        **Package trie whitelist** (i.e., non-thread-safe recursively nested
+        dictionary implementing a prefix tree such that each key-value pair maps
+        from the unqualified basename of each subpackage to be implicitly
+        type-checked on the first importation of that subpackage to another
+        instance of the :class:`.PackagesTrieWhitelist` class similarly describing the
+        sub-subpackages of that subpackage).
     '''
 
     # ..................{ CLASS VARIABLES                    }..................
@@ -73,9 +87,18 @@ class BeartypeClawState(object):
     __slots__ = (
         'beartype_pathhook',
         'module_name_to_beartype_conf',
-        'packages_trie',
+        'packages_trie_blacklist',
+        'packages_trie_whitelist',
     )
 
+    # Squelch false negatives from mypy. This is absurd. This is mypy. See:
+    #     https://github.com/python/mypy/issues/5941
+    if TYPE_CHECKING:
+        beartype_pathhook: Optional[ImportPathHook]
+        module_name_to_beartype_conf: ModuleNameToBeartypeConf
+        packages_trie_blacklist: PackagesTrieBlacklist
+        packages_trie_whitelist: PackagesTrieWhitelist
+
     # ....................{ INITIALIZERS                   }....................
     def __init__(self) -> None:
 
@@ -100,7 +123,19 @@ class BeartypeClawState(object):
 
         # One one-liner to reinitialize them all.
         self.module_name_to_beartype_conf = ModuleNameToBeartypeConf()
-        self.packages_trie = PackagesTrie(package_basename=None)
+        self.packages_trie_whitelist = PackagesTrieWhitelist()
+
+        # Default the packages trie blacklist to the fully-qualified names of:
+        # * The root "beartype" package. Doing so effectively silently ignores
+        #   dangerous attempts to recursively type-check the "beartype" package
+        #   by the @beartype.beartype decorator. See the
+        #   beartype.claw._importlib._clawimpload.BeartypeSourceFileLoader.get_code()
+        #   method docstring for further commentary.
+        # self.packages_trie_blacklist = PackagesTrieBlacklist()
+
+        #FIXME: Restore this in favour of the above, please. *sigh*
+        self.packages_trie_blacklist = PackagesTrieBlacklist(
+            subpackage_basename_to_trie={'beartype': PackagesTrieBlacklisted})
 
 
     def reinit(self) -> None:
@@ -134,7 +169,8 @@ class BeartypeClawState(object):
             f'{self.__class__.__name__}(\n',
             f'    beartype_pathhook={repr(self.beartype_pathhook)},\n',
             f'    module_name_to_beartype_conf={repr(self.module_name_to_beartype_conf)},\n',
-            f'    packages_trie={repr(self.packages_trie)},\n',
+            f'    packages_trie_blacklist={repr(self.packages_trie_blacklist)},\n',
+            f'    packages_trie_whitelist={repr(self.packages_trie_whitelist)},\n',
             f')',
         ))
 
