@@ -16,28 +16,23 @@ This private submodule is *not* intended for importation by downstream callers.
 #FIXME: Privatize most (...or perhaps all) public instance variables, please.
 
 # ....................{ IMPORTS                            }....................
-from beartype.door._doorcheck import (
+from beartype.door._cls.doormeta import _TypeHintMeta
+from beartype.door._doortest import die_unless_typehint
+from beartype.door._func.doorcheck import (
     die_if_unbearable,
     is_bearable,
 )
-from beartype.door._cls.doormeta import _TypeHintMeta
-from beartype.door._doortest import die_unless_typehint
-from beartype.door._doortyping import T
 from beartype.typing import (
     Any,
     FrozenSet,
     Generic,
     Iterable,
-    # Optional,
     Tuple,
-    Union,
     overload,
 )
-from beartype._conf.confcls import (
-    BEARTYPE_CONF_DEFAULT,
-    BeartypeConf,
-)
-from beartype._data.hint.datahinttyping import CallableMethodGetitemArg
+from beartype._conf.confcls import BeartypeConf
+from beartype._conf.confcommon import BEARTYPE_CONF_DEFAULT
+from beartype._data.hint.datahinttyping import T
 from beartype._util.cache.utilcachecall import (
     method_cached_arg_by_id,
     property_cached,
@@ -74,24 +69,26 @@ class TypeHint(Generic[T], metaclass=_TypeHintMeta):
     **Type hint wrappers are not totally ordered,** however. Like unordered
     sets, type hint wrappers do *not* satisfy **totality** (i.e., either ``a ≤
     b`` or ``b ≤ a``, which is *not* necessarily the case for incommensurable
-    type hint wrappers).
+    type hint wrappers that *cannot* reasonably be compared with one another).
 
     Type hint wrappers are thus usable in algorithms and data structures
     requiring at most a partial ordering over their input.
 
     Examples
     --------
-        >>> from beartype.door import TypeHint
-        >>> hint_a = TypeHint(Callable[[str], list])
-        >>> hint_b = TypeHint(Callable[Union[int, str], Sequence[Any]])
-        >>> hint_a <= hint_b
-        True
-        >>> hint_a > hint_b
-        False
-        >>> hint_a.is_subhint(hint_b)
-        True
-        >>> list(hint_b)
-        [TypeHint(typing.Union[int, str]), TypeHint(typing.Sequence[typing.Any])]
+    .. code-block:: pycon
+
+       >>> from beartype.door import TypeHint
+       >>> hint_a = TypeHint(Callable[[str], list])
+       >>> hint_b = TypeHint(Callable[Union[int, str], Sequence[Any]])
+       >>> hint_a <= hint_b
+       True
+       >>> hint_a > hint_b
+       False
+       >>> hint_a.is_subhint(hint_b)
+       True
+       >>> list(hint_b)
+       [TypeHint(typing.Union[int, str]), TypeHint(typing.Sequence[typing.Any])]
 
     Attributes
     ----------
@@ -147,7 +144,9 @@ class TypeHint(Generic[T], metaclass=_TypeHintMeta):
             object
         )
 
-        # Tuple of all low-level child type hints of this hint.
+        # Tuple of all low-level child type hints of this hint *AFTER* defining
+        # all other instance variables. Deferring this call allows subclass
+        # _make_args() implementations to access these instance variables.
         self._args = self._make_args()
 
     # ..................{ DUNDERS                            }..................
@@ -171,6 +170,7 @@ class TypeHint(Generic[T], metaclass=_TypeHintMeta):
 
         # Unqualified name of the concrete subclass wrapping this hint.
         hint_wrapper_basename = get_object_type_basename(self)
+        # print('hint_wrapper_basename: {hint_wrapper_basename}')
 
         # If this concrete subclass is currently private, deviously hide this
         # implementation detail by defaulting to the unqualified name of this
@@ -308,8 +308,11 @@ class TypeHint(Generic[T], metaclass=_TypeHintMeta):
     @overload
     def __getitem__(self, index: slice) -> Tuple['TypeHint', ...]: ...
 
-    def __getitem__(self, index: CallableMethodGetitemArg) -> (
-        Union['TypeHint', Tuple['TypeHint', ...]]):
+    # Note that the actual implementation of this overload is intentionally:
+    # * *NOT* decorated by the standard @overload decorator.
+    # * *NOT* annotated by type hints. By PEP 484, only the signatures of
+    #   @overload-decorated callables are annotated by type hints.
+    def __getitem__(self, index):
         '''
         Either:
 
@@ -501,11 +504,16 @@ class TypeHint(Generic[T], metaclass=_TypeHintMeta):
         # Optional keyword-only parameters.
         *,
         conf: BeartypeConf = BEARTYPE_CONF_DEFAULT,
+        exception_prefix: str = 'die_if_unbearable() ',
     ) -> None:
         '''
         Raise an exception if the passed arbitrary object violates this type
         hint under the passed beartype configuration.
 
+        To configure the type of violation exception raised by this method, set
+        the :attr:`.BeartypeConf.violation_door_type` option of the passed
+        ``conf`` parameter accordingly.
+
         Parameters
         ----------
         obj : object
@@ -515,37 +523,44 @@ class TypeHint(Generic[T], metaclass=_TypeHintMeta):
             encapsulating all settings configuring type-checking for the passed
             object). Defaults to ``BeartypeConf()``, the default ``O(1)``
             constant-time configuration.
+        exception_prefix : str, optional
+            Human-readable label prefixing the representation of this object in
+            the exception message. Defaults to a reasonably sensible string.
 
         Raises
         ------
-        BeartypeDoorHintViolation
+        ``conf.violation_door_type``
             If this object violates this hint.
+        beartype.roar.BeartypeDecorHintNonpepException
+            If this hint is *not* PEP-compliant (i.e., complies with *no* Python
+            Enhancement Proposals (PEPs) currently supported by
+            :mod:`beartype`).
+        beartype.roar.BeartypeDecorHintPepUnsupportedException
+            If this hint is currently unsupported by :mod:`beartype`.
 
         Examples
         --------
-            >>> from beartype.door import TypeHint
-            >>> TypeHint(list[str]).die_if_unbearable(
-            ...     ['And', 'what', 'rough', 'beast,'], )
-            >>> TypeHint(list[str]).die_if_unbearable(
-            ...     ['its', 'hour', 'come', 'round'], list[int])
-            beartype.roar.BeartypeDoorHintViolation: Object ['its', 'hour',
-            'come', 'round'] violates type hint list[int], as list index 0 item
-            'its' not instance of int.
+        .. code-block:: pycon
+
+           >>> from beartype.door import TypeHint
+           >>> TypeHint(list[str]).die_if_unbearable(
+           ...     ['And', 'what', 'rough', 'beast,'], )
+           >>> TypeHint(list[str]).die_if_unbearable(
+           ...     ['its', 'hour', 'come', 'round'], list[int])
+           beartype.roar.BeartypeDoorHintViolation: Object ['its', 'hour',
+           'come', 'round'] violates type hint list[int], as list index 0 item
+           'its' not instance of int.
         '''
 
         # One-liner, one love, one heart. Let's get together and code alright.
-        die_if_unbearable(obj=obj, hint=self._hint, conf=conf)
+        die_if_unbearable(
+            obj=obj,
+            hint=self._hint,
+            conf=conf,
+            exception_prefix=exception_prefix,
+        )
 
 
-    #FIXME: Submit an upstream mypy issue. Since mypy correctly accepts our
-    #comparable beartype.door.is_bearable() function, mypy should also
-    #accept this equivalent method. mypy currently fails to do so with this
-    #false positive:
-    #    error: Variable "beartype.door._cls.doorsuper.TypeHint.TypeGuard" is not
-    #    valid as a type
-    #
-    #Clearly, mypy fails to percolate the type variable "T" from our
-    #pseudo-superclass "Generic[T]" onto this return annotation. *sigh*
     def is_bearable(
         self,
 
@@ -554,9 +569,6 @@ class TypeHint(Generic[T], metaclass=_TypeHintMeta):
 
         # Optional keyword-only parameters.
         *, conf: BeartypeConf = BEARTYPE_CONF_DEFAULT,
-    #FIXME: Re-enable after static type-checkers support "TypeGuard[T]". See
-    #"_doorcheck" for further details, please.
-    # ) -> TypeGuard[T]:
     ) -> bool:
         '''
         :data:`True` only if the passed arbitrary object satisfies this type
@@ -586,12 +598,14 @@ class TypeHint(Generic[T], metaclass=_TypeHintMeta):
 
         Examples
         --------
-            >>> from beartype.door import TypeHint
-            >>> TypeHint(list[str]).is_bearable(['Things', 'fall', 'apart;'])
-            True
-            >>> TypeHint(list[int]).is_bearable(
-            ...     ['the', 'centre', 'cannot', 'hold;'])
-            False
+        .. code-block:: python
+
+           >>> from beartype.door import TypeHint
+           >>> TypeHint(list[str]).is_bearable(['Things', 'fall', 'apart;'])
+           True
+           >>> TypeHint(list[int]).is_bearable(
+           ...     ['the', 'centre', 'cannot', 'hold;'])
+           False
         '''
 
         # One-liners justify their own existence.
@@ -796,7 +810,7 @@ class TypeHint(Generic[T], metaclass=_TypeHintMeta):
         '''
 
         # If that branch is unsubscripted, assume that branch to have been
-        # subscripted by "Any" and simply check for compatible origin types.
+        # subscripted by "Any" by simply checking for compatible origin types.
         if branch._is_args_ignorable:
             # print(f'is_subhint_branch({self}, {branch} [unsubscripted])')
             return issubclass(self._origin, branch._origin)
