@@ -21,12 +21,10 @@ This private submodule is *not* intended for importation by downstream callers.
 
 # ....................{ IMPORTS                            }....................
 from beartype.roar import BeartypePep563Exception
-from beartype._check.checkcall import make_beartype_call
+from beartype._check.metadata.metadecor import make_beartype_call
 from beartype._check.forward.fwdmain import resolve_hint
-from beartype._conf.confcls import (
-    BEARTYPE_CONF_DEFAULT,
-    BeartypeConf,
-)
+from beartype._conf.confcls import BeartypeConf
+from beartype._conf.confcommon import BEARTYPE_CONF_DEFAULT
 from beartype._data.hint.datahinttyping import TypeStack
 from beartype._util.cache.pool.utilcachepoolobjecttyped import (
     release_object_typed)
@@ -238,7 +236,7 @@ def resolve_pep563(
 
     # ..................{ LOCALS                             }..................
     # Beartype call metadata describing the passed callable.
-    bear_call = make_beartype_call(
+    decor_meta = make_beartype_call(
         func=func,
         conf=conf,
         cls_stack=cls_stack,
@@ -277,7 +275,7 @@ def resolve_pep563(
         if isinstance(hint, str):
             arg_name_to_hint[arg_name] = resolve_hint(
                 hint=hint,
-                bear_call=bear_call,
+                decor_meta=decor_meta,
                 exception_cls=BeartypePep563Exception,
             )
         # Else, this hint is *NOT* stringified. In this case, preserve this hint
@@ -285,7 +283,7 @@ def resolve_pep563(
 
     # ..................{ RETURN                             }..................
     # Release this beartype call metadata back to its object pool.
-    release_object_typed(bear_call)
+    release_object_typed(decor_meta)
 
     # Attempt to...
     try:
@@ -294,12 +292,12 @@ def resolve_pep563(
         #
         # While the @beartype decorator goes to great lengths to preserve the
         # originating "__annotations__" dictionary as is, PEP 563 is
-        # sufficiently expensive, non-trivial, and general-purpose to implement
-        # that generally resolving postponed annotations for downstream
+        # sufficiently expensive, non-trivial, and general-purpose to support
+        # that generically resolving postponed annotations for all downstream
         # third-party callers is justified. Everyone benefits from replacing
         # useless postponed annotations with useful real annotations; so, do so.
         func.__annotations__ = arg_name_to_hint
-    # If doing so fails with an exception resembling the following, then that
+    # If doing so fails with an exception resembling the following, that
     # callable is *NOT* a pure-Python callable but rather a C-based decorator
     # object of some sort (e.g., class, property, or static method descriptor):
     #     AttributeError: 'method' object has no attribute '__annotations__'
@@ -307,7 +305,7 @@ def resolve_pep563(
     # C-based decorator objects define a read-only "__annotations__" dunder
     # attribute that proxies an original writeable "__annotations__" dunder
     # attribute of the pure-Python callables they originally decorated. Ergo,
-    # detecting this edge case is non-trivial and most most easily deferred to
+    # detecting this edge case is non-trivial and most easily deferred to
     # this late time. While non-ideal, simplicity >>>> idealism in this case.
     except AttributeError:
         # For the name of each annotated parameter and return of that callable
