@@ -45,7 +45,7 @@ from beartype.roar._roarexc import (
     BeartypeCaveException as BeartypeCaveException,
     BeartypeCaveNoneTypeOrException as BeartypeCaveNoneTypeOrException,
     BeartypeCaveNoneTypeOrKeyException as BeartypeCaveNoneTypeOrKeyException,
-    BeartypeCaveNoneTypeOrMutabilityException as BeartypeCaveNoneTypeOrMutabilityException,
+    # BeartypeCaveNoneTypeOrMutabilityException as BeartypeCaveNoneTypeOrMutabilityException,
     BeartypeClawException as BeartypeClawException,
     BeartypeClawHookException as BeartypeClawHookException,
     BeartypeClawHookUnpackagedException as BeartypeClawHookUnpackagedException,
@@ -58,6 +58,7 @@ from beartype.roar._roarexc import (
     BeartypeDoorException as BeartypeDoorException,
     BeartypeDoorNonpepException as BeartypeDoorNonpepException,
     BeartypeDoorPepException as BeartypeDoorPepException,
+    BeartypeDoorPepArgsLenException as BeartypeDoorPepArgsLenException,
     BeartypeDoorPepUnsupportedException as BeartypeDoorPepUnsupportedException,
     BeartypeDecorException as BeartypeDecorException,
     BeartypeDecorWrappeeException as BeartypeDecorWrappeeException,
@@ -79,8 +80,11 @@ from beartype.roar._roarexc import (
     BeartypeDecorHintPep591Exception as BeartypeDecorHintPep591Exception,
     BeartypeDecorHintPep593Exception as BeartypeDecorHintPep593Exception,
     BeartypeDecorHintPep604Exception as BeartypeDecorHintPep604Exception,
+    BeartypeDecorHintPep612Exception as BeartypeDecorHintPep612Exception,
+    BeartypeDecorHintPep646Exception as BeartypeDecorHintPep646Exception,
     BeartypeDecorHintPep647Exception as BeartypeDecorHintPep647Exception,
     BeartypeDecorHintPep673Exception as BeartypeDecorHintPep673Exception,
+    BeartypeDecorHintPep692Exception as BeartypeDecorHintPep692Exception,
     BeartypeDecorHintPep695Exception as BeartypeDecorHintPep695Exception,
     BeartypeDecorHintPep3119Exception as BeartypeDecorHintPep3119Exception,
     BeartypeDecorHintTypeException as BeartypeDecorHintTypeException,
@@ -90,9 +94,11 @@ from beartype.roar._roarexc import (
     BeartypeCallUnavailableTypeException as BeartypeCallUnavailableTypeException,
     BeartypeCallHintException as BeartypeCallHintException,
     BeartypeCallHintForwardRefException as BeartypeCallHintForwardRefException,
+    BeartypeHintOverridesException as BeartypeHintOverridesException,
     BeartypeKindException as BeartypeKindException,
     BeartypeKindFrozenDictException as BeartypeKindFrozenDictException,
-    BeartypeHintOverridesException as BeartypeHintOverridesException,
+    BeartypeLibraryException as BeartypeLibraryException,
+    BeartypeLibraryNumpyException as BeartypeLibraryNumpyException,
     BeartypePepException as BeartypePepException,
     BeartypePep563Exception as BeartypePep563Exception,
     BeartypePlugException as BeartypePlugException,
@@ -124,6 +130,9 @@ from beartype.roar._roarwarn import (
     BeartypeDecorHintPep613DeprecationWarning as BeartypeDecorHintPep613DeprecationWarning,
     BeartypeDecorHintNonpepWarning as BeartypeDecorHintNonpepWarning,
     BeartypeDecorHintNonpepNumpyWarning as BeartypeDecorHintNonpepNumpyWarning,
+    BeartypeDoorWarning as BeartypeDoorWarning,
+    BeartypeDoorInferHintWarning as BeartypeDoorInferHintWarning,
+    BeartypeDoorInferHintRecursionWarning as BeartypeDoorInferHintRecursionWarning,
     BeartypeModuleWarning as BeartypeModuleWarning,
     BeartypeModuleNotFoundWarning as BeartypeModuleNotFoundWarning,
     BeartypeModuleAttributeNotFoundWarning as BeartypeModuleAttributeNotFoundWarning,
