@@ -467,6 +467,7 @@ def test_is_func_wrapper_isomorphic() -> None:
     :func:`beartype._util.func.utilfunctest.is_func_wrapper_isomorphic` tester.
     '''
 
+    # ....................{ IMPORTS                        }....................
     # Defer test-specific imports.
     from beartype._util.func.utilfunctest import is_func_wrapper_isomorphic
     from beartype_test.a00_unit.data.data_type import (
@@ -474,16 +475,30 @@ def test_is_func_wrapper_isomorphic() -> None:
         decorator_isomorphic,
         decorator_nonisomorphic,
         function,
+        object_callable_wrapper_isomorphic,
         wrapper_isomorphic,
     )
 
-    # Assert this tester accepts isomorphic closure wrappers.
+    # ....................{ PASS                           }....................
+    # Assert this tester accepts isomorphic wrapper closures.
     assert is_func_wrapper_isomorphic(context_manager_factory) is True
     assert is_func_wrapper_isomorphic(decorator_isomorphic(function)) is True
 
-    # Assert this tester accepts isomorphic non-closure wrappers.
+    # Assert this tester accepts isomorphic wrapper functions.
     assert is_func_wrapper_isomorphic(wrapper_isomorphic) is True
 
+    # Assert this tester accepts isomorphic wrapper bound methods explicitly
+    # decorated as such.
+    assert is_func_wrapper_isomorphic(
+        object_callable_wrapper_isomorphic.method_wrapper_isomorphic) is True
+
+    # Assert this tester accepts isomorphic wrapper bound methods *NOT*
+    # explicitly decorated as such when a sibling wrapper is also passed.
+    assert is_func_wrapper_isomorphic(
+        object_callable_wrapper_isomorphic.method_wrapper_isomorphic_implicit,
+        object_callable_wrapper_isomorphic.method_wrapper_isomorphic,
+    ) is True
+
     # Assert this tester rejects non-isomorphic wrappers.
     assert is_func_wrapper_isomorphic(
         decorator_nonisomorphic(function)) is False
