@@ -58,6 +58,50 @@ def test_unwrap_func_all() -> None:
     assert unwrap_func_all(in_a_station_of_the_metro) is (
         in_a_station_of_the_metro_line_two)
 
+
+def test_unwrap_func_all_isomorphic() -> None:
+    '''
+    Test the
+    :func:`beartype._util.func.utilfuncwrap.unwrap_func_all_isomorphic` function.
+    '''
+
+    # ....................{ IMPORTS                        }....................
+    # Defer test-specific imports.
+    from beartype._util.func.utilfuncwrap import unwrap_func_all_isomorphic
+    from beartype_test.a00_unit.data.data_type import (
+        function_wrappee,
+        function_wrapper_nonisomarphic,
+        function_wrapper_isomarphic,
+        function_wrapper_isomarphic_args,
+        function_wrapper_isomarphic_kwargs,
+        object_callable_wrapper_isomorphic,
+    )
+
+    # ....................{ ASSERTS                        }....................
+    # Assert this function returns unwrapped callables unmodified.
+    assert unwrap_func_all_isomorphic(function_wrappee) is function_wrappee
+    assert unwrap_func_all_isomorphic(iter) is iter
+
+    # Assert this function returns non-isomorphic wrapper callables unmodified.
+    assert unwrap_func_all_isomorphic(function_wrapper_nonisomarphic) is (
+        function_wrapper_nonisomarphic)
+
+    # Assert this function unwraps isomorphic wrapper callables.
+    assert unwrap_func_all_isomorphic(function_wrapper_isomarphic) is (
+        function_wrapper_nonisomarphic)
+    assert unwrap_func_all_isomorphic(function_wrapper_isomarphic_args) is (
+        function_wrapper_nonisomarphic)
+    assert unwrap_func_all_isomorphic(function_wrapper_isomarphic_kwargs) is (
+        function_wrapper_nonisomarphic)
+
+    # Assert this function unwraps wrapper pseudo-callables.
+    object_callable_wrapper_isomorphic_unwrapped = unwrap_func_all_isomorphic(
+        func=object_callable_wrapper_isomorphic.__call__,
+        wrapper=object_callable_wrapper_isomorphic,
+    )
+    assert object_callable_wrapper_isomorphic_unwrapped is (
+        function_wrapper_nonisomarphic)
+
 # ....................{ TESTS ~ descriptor                 }....................
 def test_unwrap_func_classmethod_once() -> None:
     '''
