@@ -20,12 +20,12 @@ This submodule unit tests the public API of the private
 def test_is_hint_pep484585_tuple_empty() -> None:
     '''
     Test the
-    :func:`beartype._util.hint.pep.proposal.pep484585.utilpep484585.is_hint_pep484585_tuple_empty`
+    :func:`beartype._util.hint.pep.proposal.pep484585.utilpep484585tuple.is_hint_pep484585_tuple_empty`
     tester.
     '''
 
     # Defer test-specific imports.
-    from beartype._util.hint.pep.proposal.pep484585.utilpep484585 import (
+    from beartype._util.hint.pep.proposal.pep484585.utilpep484585tuple import (
         is_hint_pep484585_tuple_empty)
     from beartype._util.py.utilpyversion import IS_PYTHON_AT_LEAST_3_9
     from typing import Tuple  # <-- intentionally import the PEP 484 variant
