@@ -4,7 +4,7 @@
 # See "LICENSE" for further details.
 
 '''
-Project-wide **object utility unit tests.**
+Project-wide **object utility** unit tests.
 
 This submodule unit tests the public API of the private
 :mod:`beartype._util.utilobject` submodule.
@@ -35,7 +35,7 @@ def test_is_object_hashable() -> None:
     for object_unhashable in NOT_HINTS_UNHASHABLE:
         assert is_object_hashable(object_unhashable) is False
 
-# ....................{ TESTS ~ getter                     }....................
+# ....................{ TESTS ~ getter : name              }....................
 def test_get_object_basename_scoped() -> None:
     '''
     Test the :func:`beartype._util.utilobject.get_object_basename_scoped`
