@@ -26,6 +26,7 @@ def test_conf_dataclass() -> None:
     # Defer test-specific imports.
     from beartype import (
         BeartypeConf,
+        BeartypeDecorationPosition,
         BeartypeHintOverrides,
         BeartypeStrategy,
         BeartypeViolationVerbosity,
@@ -39,7 +40,7 @@ def test_conf_dataclass() -> None:
     from beartype.typing import Union
     from beartype._conf.confoverrides import (
         BEARTYPE_HINT_OVERRIDES_EMPTY,
-        BEARTYPE_HINT_OVERRIDES_PEP484_TOWER,
+        beartype_hint_overrides_pep484_tower,
     )
     from beartype._util.utilobject import get_object_type_basename
     from pytest import raises
@@ -60,7 +61,10 @@ def test_conf_dataclass() -> None:
     # * The unqualified basenames of and all public fields of this class.
     BEAR_CONF_REPR_SUBSTRS = (
         'BeartypeConf',
+        'claw_decoration_position_funcs',
+        'claw_decoration_position_types',
         'claw_is_pep526',
+        'claw_skip_package_names',
         'hint_overrides',
         'is_color',
         'is_debug',
@@ -79,13 +83,15 @@ def test_conf_dataclass() -> None:
 
     # Non-empty hint overrides mapping one or more arbitrary source type hints
     # to corresponding arbitrary target type hints.
-    BEAR_HINT_OVERRIDES_NONEMPTY = BeartypeHintOverrides(
-        {bool: Union[bool, FakeBool]})
+    BEAR_HINT_OVERRIDES_NONEMPTY = BeartypeHintOverrides({bool: FakeBool})
 
     # All possible keyword arguments initialized to non-default values with
     # which to instantiate a non-default beartype configuration.
     BEAR_CONF_NONDEFAULT_KWARGS = dict(
+        claw_decoration_position_funcs=BeartypeDecorationPosition.FIRST,
+        claw_decoration_position_types=BeartypeDecorationPosition.FIRST,
         claw_is_pep526=False,
+        claw_skip_package_names=('Made_contrast_with', 'the_universe',),
         hint_overrides=BEAR_HINT_OVERRIDES_NONEMPTY,
         is_color=True,
         is_debug=True,
@@ -123,12 +129,15 @@ def test_conf_dataclass() -> None:
     assert BeartypeConf() is BeartypeConf()
     assert (
         BeartypeConf(
-            strategy=BeartypeStrategy.On,
+            claw_decoration_position_funcs=BeartypeDecorationPosition.FIRST,
+            claw_decoration_position_types=BeartypeDecorationPosition.LAST,
             claw_is_pep526=False,
+            claw_skip_package_names=('Made_contrast_with', 'the_universe',),
             hint_overrides=BEAR_HINT_OVERRIDES_NONEMPTY,
             is_debug=True,
             is_color=True,
             is_pep484_tower=True,
+            strategy=BeartypeStrategy.On,
             violation_door_type=RuntimeError,
             violation_param_type=TypeError,
             violation_return_type=ValueError,
@@ -143,18 +152,26 @@ def test_conf_dataclass() -> None:
             violation_return_type=ValueError,
             violation_param_type=TypeError,
             violation_door_type=RuntimeError,
+            strategy=BeartypeStrategy.On,
             is_pep484_tower=True,
             is_color=True,
             is_debug=True,
             hint_overrides=BEAR_HINT_OVERRIDES_NONEMPTY,
             claw_is_pep526=False,
-            strategy=BeartypeStrategy.On,
+            claw_skip_package_names=('Made_contrast_with', 'the_universe',),
+            claw_decoration_position_types=BeartypeDecorationPosition.LAST,
+            claw_decoration_position_funcs=BeartypeDecorationPosition.FIRST,
         )
     )
 
     # ....................{ PASS ~ properties              }....................
     # Assert that the default configuration contains the expected fields.
+    assert BEAR_CONF_DEFAULT.claw_decoration_position_funcs is (
+        BeartypeDecorationPosition.LAST)
+    assert BEAR_CONF_DEFAULT.claw_decoration_position_types is (
+        BeartypeDecorationPosition.LAST)
     assert BEAR_CONF_DEFAULT.claw_is_pep526 is True
+    assert BEAR_CONF_DEFAULT.claw_skip_package_names == ()
     assert BEAR_CONF_DEFAULT.hint_overrides is BEARTYPE_HINT_OVERRIDES_EMPTY
     assert BEAR_CONF_DEFAULT.is_color is None
     assert BEAR_CONF_DEFAULT.is_debug is False
@@ -173,9 +190,15 @@ def test_conf_dataclass() -> None:
     assert BEAR_CONF_DEFAULT._is_warning_cls_on_decorator_exception_set is False
 
     # Assert that the non-default configuration contains the expected fields.
+    assert BEAR_CONF_DEFAULT.claw_decoration_position_funcs is (
+        BeartypeDecorationPosition.LAST)
+    assert BEAR_CONF_DEFAULT.claw_decoration_position_types is (
+        BeartypeDecorationPosition.LAST)
     assert BEAR_CONF_NONDEFAULT.claw_is_pep526 is False
+    assert BEAR_CONF_NONDEFAULT.claw_skip_package_names == (
+        'Made_contrast_with', 'the_universe',)
     assert BEAR_CONF_NONDEFAULT.hint_overrides == (
-        BEAR_HINT_OVERRIDES_NONEMPTY | BEARTYPE_HINT_OVERRIDES_PEP484_TOWER)
+        BEAR_HINT_OVERRIDES_NONEMPTY | beartype_hint_overrides_pep484_tower())
     assert BEAR_CONF_NONDEFAULT.is_color is True
     assert BEAR_CONF_NONDEFAULT.is_debug is True
     assert BEAR_CONF_NONDEFAULT.is_pep484_tower is True
@@ -265,9 +288,29 @@ def test_conf_dataclass() -> None:
     # ....................{ FAIL                           }....................
     # Assert that instantiating a configuration with an invalid parameter raises
     # the expected exception.
+    with raises(BeartypeConfParamException):
+        BeartypeConf(claw_decoration_position_funcs=(
+            "High 'mid the shifting domes of sheeted spray"))
+    with raises(BeartypeConfParamException):
+        BeartypeConf(claw_decoration_position_types=(
+            "That canopied his path o'er the waste deep;"))
     with raises(BeartypeConfParamException):
         BeartypeConf(claw_is_pep526=(
             'The fountains mingle with the river'))
+    with raises(BeartypeConfParamException):
+        BeartypeConf(claw_skip_package_names=('A pine,', 'Rock-rooted,'))
+    with raises(BeartypeConfParamException):
+        BeartypeConf(claw_skip_package_names=(
+            'stretched_athwart', b'the vacancy'))
+    with raises(BeartypeConfParamException):
+        BeartypeConf(claw_skip_package_names=(
+            'Yielding_one.only_response.at.each_pause', ''))
+    with raises(BeartypeConfParamException):
+        BeartypeConf(claw_skip_package_names=(
+            package_name
+            for package_name in (
+                'Its_swinging_boughs', 'to_each_inconstant_blast',)
+        ))
     with raises(BeartypeConfParamException):
         BeartypeConf(hint_overrides=(
             'Wildered, and wan, and panting, she returned.'))
@@ -328,8 +371,16 @@ def test_conf_dataclass() -> None:
 
     # Assert that attempting to modify any public read-only property of this
     # dataclass raises the expected exception.
+    with raises(AttributeError):
+        BEAR_CONF_DEFAULT.claw_decoration_position_funcs = (
+            BeartypeDecorationPosition.FIRST)
+    with raises(AttributeError):
+        BEAR_CONF_DEFAULT.claw_decoration_position_types = (
+            BeartypeDecorationPosition.FIRST)
     with raises(AttributeError):
         BEAR_CONF_DEFAULT.claw_is_pep526 = True
+    with raises(AttributeError):
+        BEAR_CONF_DEFAULT.claw_skip_package_names = ('q','w','e')
     with raises(AttributeError):
         BEAR_CONF_DEFAULT.hint_overrides = {}
     with raises(AttributeError):
