@@ -26,7 +26,9 @@ This submodule unit tests :pep:`563` support implemented in the
 # an "from __future__ import annotations" import.
 #!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
 from beartype_test._util.mark.pytskip import (
+    # skip,
     skip_if_pypy,
+    skip_if_python_version_less_than,
     skip_if_python_version_greater_than_or_equal_to,
 )
 
@@ -59,8 +61,8 @@ def test_pep563_class_self_reference_reloaded() -> None:
     # .....................{ IMPORTS                       }....................
     # Defer test-specific imports.
     #
-    # Note that the "data_pep563_club" submodule is intentionally imported as
-    # an attribute rather than importing the requisite attributes from that
+    # Note that the "data_pep563_club" submodule is intentionally imported as an
+    # attribute rather than importing the requisite attributes from that
     # submodule. Why? Because the entire intention of this test is to exercise
     # reloading of @beartype-decorated callables annotated with circular
     # references under PEP 563.
@@ -125,28 +127,7 @@ def test_pep563_class_self_reference_override() -> None:
     # expected value.
     assert Karma.if_your_colors().dreams == DREAMS
 
-
-def test_pep563_func_return() -> None:
-    '''
-    Test module-scoped :pep:`563` support implemented in the
-    :func:`beartype.beartype` decorator with respect to callables with returns
-    annotated by the :pep:`484`-compliant :obj:`typing.NoReturn` type hint.
-    '''
-
-    # Defer test-specific imports.
-    from beartype_test.a00_unit.data.pep.pep563.data_pep563_club import (
-        HeWouldLingerLong,
-        to_love_and_wonder,
-    )
-    from pytest import raises
-
-    # Assert that a @beartype-decorated function "typing.NoReturn" return
-    # annotation is postponed under PEP 563 to a string raises the expected
-    # exception.
-    with raises(HeWouldLingerLong):
-        to_love_and_wonder()
-
-# ....................{ TESTS ~ poem                       }....................
+# ....................{ TESTS ~ scope                      }....................
 def test_pep563_module() -> None:
     '''
     Test module-scoped :pep:`563` support implemented in the
@@ -346,6 +327,95 @@ def test_pep563_closure_nested() -> None:
     assert minecraft_end_txt_inner[0] == (
         'It is reading our thoughts as though they were words on a screen.')
 
+# .....................{ TESTS ~ pep : 484                 }....................
+def test_pep563_hint_pep484_namedtuple() -> None:
+    '''
+    Test module-scoped :pep:`563` support implemented in the
+    :func:`beartype.beartype` decorator with respect to :pep:`484`-compliant
+    :obj:`typing.NamedTuple` subclasses decorated by this decorator.
+    '''
+
+    # .....................{ IMPORTS                       }....................
+    # Defer test-specific imports.
+    from beartype.roar import BeartypeCallHintParamViolation
+    from beartype_test.a00_unit.data.pep.pep563.pep484.data_pep563_pep484 import (
+        LeadOnlyTo)
+    from pytest import raises
+
+    # .....................{ PASS                          }....................
+    # Assert that instantiating this subclass with valid fields creates and
+    # returns an object of the expected type exposing the same fields.
+    while_deaths_blue_vault = LeadOnlyTo(0xCAFEFACE)
+    assert while_deaths_blue_vault.a_black_and_watery_depth == 0xCAFEFACE
+
+    # .....................{ FAIL                          }....................
+    # Assert that instantiating this subclass with one or more invalid fields
+    # raises the expected exception.
+    with raises(BeartypeCallHintParamViolation):
+        LeadOnlyTo("While death's blue vault, with loathliest vapours hung,")
+
+
+def test_pep563_hint_pep484_noreturn() -> None:
+    '''
+    Test module-scoped :pep:`563` support implemented in the
+    :func:`beartype.beartype` decorator with respect to callables with returns
+    annotated by the :pep:`484`-compliant :obj:`typing.NoReturn` type hint.
+    '''
+
+    # Defer test-specific imports.
+    from beartype_test.a00_unit.data.pep.pep563.data_pep563_club import (
+        HeWouldLingerLong,
+        to_love_and_wonder,
+    )
+    from pytest import raises
+
+    # Assert that a @beartype-decorated function "typing.NoReturn" return
+    # annotation is postponed under PEP 563 to a string raises the expected
+    # exception.
+    with raises(HeWouldLingerLong):
+        to_love_and_wonder()
+
+# .....................{ TESTS ~ pep : 604                 }....................
+@skip_if_python_version_less_than('3.10.0')
+def test_pep563_hint_pep604() -> None:
+    '''
+    Test module-scoped :pep:`563` support implemented in the
+    :func:`beartype.beartype` decorator with respect to :pep:`604`-compliant
+    unions annotating :pep:`557`-compliant
+    :obj:`dataclasses.dataclass`-decorated subclasses also decorated by this
+    decorator if the active Python interpreter targets Python >= 3.10 and thus
+    supports :pep:`604`.
+    '''
+
+    # .....................{ IMPORTS                       }....................
+    # Defer test-specific imports.
+    from beartype.roar import BeartypeCallHintParamViolation
+    from beartype_test.a00_unit.data.pep.pep563.pep604.data_pep563_pep604 import (
+        FrameMoreAttuned,
+        WithVoiceFarSweeter,
+    )
+    from pytest import raises
+
+    # .....................{ LOCALS                        }....................
+    # Arbitrary instance of a problematic dataclass subclass annotated by a
+    # problematic PEP 604-compliant union that had yet to be defined at the time
+    # that subclass was defined.
+    wasting_these_surpassing_powers = WithVoiceFarSweeter(
+        than_thy_dying_notes=FrameMoreAttuned())
+    # wasting_these_surpassing_powers = WithVoiceFarSweeter()
+
+    # .....................{ PASS                          }....................
+    # Assert that this instance exposes the expected fields.
+    isinstance(
+        wasting_these_surpassing_powers.than_thy_dying_notes, FrameMoreAttuned)
+
+    # .....................{ FAIL                          }....................
+    # Assert that instantiating this subclass with one or more invalid fields
+    # raises the expected exception.
+    with raises(BeartypeCallHintParamViolation):
+        WithVoiceFarSweeter(than_thy_dying_notes=(
+            'In the deaf air, to the blind earth, and heaven'))
+
 # ....................{ TESTS ~ limit                      }....................
 #FIXME: Hilariously, we can't even unit test whether the
 #beartype._decor._pep.pep563._die_if_hint_repr_exceeds_child_limit() function
