@@ -16,216 +16,29 @@ from beartype.typing import (
     Callable,
     Coroutine,
     Generator,
+    Iterable,
     Iterator,
+    Tuple,
 )
 from beartype._util.func.utilfuncmake import make_func
 from collections import defaultdict
+from collections.abc import (
+    Hashable as HashableABC,
+    ItemsView as ItemsViewABC,
+    KeysView as KeysViewABC,
+    ValuesView as ValuesViewABC,
+    Sized as SizedABC,
+)
 from contextlib import contextmanager
 from enum import Enum
 from functools import (
     lru_cache,
     partial,
+    update_wrapper,
     wraps,
 )
 from sys import exc_info
 
-# ....................{ CLASSES                            }....................
-class CallableClass(object):
-    '''
-    Arbitrary pure-Python **callable class** (i.e., class defining the
-    :meth:`__call__` dunder method implicitly called by Python when instances
-    of this class are called using the standard calling convention).
-    '''
-
-    def __call__(self, *args, **kwargs) -> int:
-        '''
-        Dunder method implicitly called when this object is called.
-        '''
-
-        return len(args) + len(kwargs)
-
-# ....................{ CLASSES ~ enum                     }....................
-class MasterlessDecreeVenomlessWhich(Enum):
-    '''
-    Arbitrary enumeration whose members are accessed elsewhere as integers,
-    typically when subscripting the :pep:`586`-compliant :attr:`typing.Literal`
-    type hint factory.
-    '''
-
-    NOMENCLATURE_WEATHER_VANES_OF = 0
-    NOMINALLY_UNSWAIN_AUTODIDACTIC_IDIOCRACY_LESS_A = 1
-
-# ....................{ CLASSES ~ hierarchy : 1            }....................
-# Arbitrary class hierarchy.
-
-class Class(object):
-    '''
-    Arbitrary pure-Python class defining arbitrary methods.
-    '''
-
-    # ....................{ NESTED                         }....................
-    class NestedClass(object):
-        '''
-        Arbitrary pure-Python **nested class** whose definition is nested inside
-        the definition of another class.
-        '''
-
-        pass
-
-    # ....................{ METHODS                        }....................
-    def instance_method(self):
-        '''
-        Arbitrary pure-Python instance method.
-        '''
-
-        pass
-
-
-    @property
-    def instance_property(self):
-        '''
-        Arbitrary pure-Python instance property.
-        '''
-
-        pass
-
-
-    @classmethod
-    def class_method(cls):
-        '''
-        Arbitrary pure-Python class method.
-        '''
-
-        pass
-
-
-    @staticmethod
-    def static_method():
-        '''
-        Arbitrary pure-Python static method.
-        '''
-
-        pass
-
-
-class Subclass(Class):
-    '''
-    Arbitrary pure-Python subclass of an arbitrary pure-Python superclass.
-    '''
-
-    pass
-
-
-class SubclassSubclass(Subclass):
-    '''
-    Arbitrary pure-Python subclass of an arbitrary pure-Python subclass of an
-    arbitrary pure-Python superclass.
-    '''
-
-    pass
-
-# ....................{ CLASSES ~ hierarchy : 2            }....................
-# Yet another arbitrary class hierarchy.
-
-class OtherClass(object):
-    '''
-    Arbitrary pure-Python class defining an arbitrary method.
-    '''
-
-    def instance_method(self):
-        '''
-        Arbitrary pure-Python instance method.
-        '''
-
-        pass
-
-
-class OtherSubclass(OtherClass):
-    '''
-    Arbitrary pure-Python subclass of an arbitrary pure-Python superclass.
-    '''
-
-    pass
-
-
-class OtherSubclassSubclass(OtherSubclass):
-    '''
-    Arbitrary pure-Python subclass of an arbitrary pure-Python subclass of an
-    arbitrary pure-Python superclass.
-    '''
-
-    pass
-
-# ....................{ CLASSES ~ isinstance               }....................
-class NonIsinstanceableMetaclass(type):
-    '''
-    Metaclass overriding the ``__instancecheck__()`` dunder method to
-    unconditionally raise an exception, preventing classes with this metaclass
-    from being passed as the second parameter to the :func:`isinstance`
-    builtin.
-    '''
-
-    def __instancecheck__(self, obj: object) -> bool:
-        raise TypeError(
-            f'{self} not passable as second parameter to isinstance().')
-
-
-class NonIsinstanceableClass(object, metaclass=NonIsinstanceableMetaclass):
-    '''
-    Class whose metaclass overrides the ``__instancecheck__()`` dunder method
-    to unconditionally raise an exception, preventing this class from being
-    passed as the second parameter to the :func:`isinstance` builtin.
-    '''
-
-    pass
-
-# ....................{ CLASSES ~ issubclass               }....................
-class NonIssubclassableMetaclass(type):
-    '''
-    Metaclass overriding the ``__subclasscheck__()`` dunder method to
-    unconditionally raise an exception, preventing classes with this metaclass
-    from being passed as the second parameter to the :func:`issubclass`
-    builtin.
-    '''
-
-    def __subclasscheck__(self, obj: object) -> bool:
-        raise TypeError(
-            f'{self} not passable as second parameter to issubclass().')
-
-
-class NonIssubclassableClass(object, metaclass=NonIssubclassableMetaclass):
-    '''
-    Class whose metaclass overrides the ``__subclasscheck__()`` dunder method
-    to unconditionally raise an exception, preventing this class from being
-    passed as the second parameter to the :func:`issubclass` builtin.
-    '''
-
-    pass
-
-# ....................{ CLASSES ~ with : module name       }....................
-class ClassModuleNameFake(object):
-    '''
-    Arbitrary pure-Python class with a **non-existent module name** (i.e., whose
-    ``__module__`` dunder attribute refers to a file that is guaranteed to *not*
-    exist on the local filesystem).
-    '''
-
-    pass
-
-
-class ClassModuleNameNone(object):
-    '''
-    Arbitrary pure-Python class with a **missing module name** (i.e., whose
-    ``__module__`` dunder attribute is :data:`None`).
-    '''
-
-    pass
-
-
-# Monkey-patch the above classes with "bad" module names.
-ClassModuleNameFake.__module__ = 'If_I.were.a_dead_leaf.thou_mightest.bear'
-ClassModuleNameNone.__module__ = None
-
 # ....................{ CALLABLES ~ async : factory        }....................
 # Note that we intentionally avoid declaring a factory function for deprecated
 # generator-based coroutines decorated by either the types.coroutine() or
@@ -359,57 +172,128 @@ def decorator_nonisomorphic(func):
     parameters passed to the passed callable).
     '''
 
-    # Defer decorator-specific imports.
-    from functools import wraps
-
     @wraps(func)
-    def _closure_nonisomorphic(*args):
+    def _closure_nonisomorphic():
         '''
         **Non-isomorphic decorator closure** (i.e., closure destroying the
         positions and/or types of one or more parameters passed to the decorated
         callable).
-
-        This closure fails to accept keyword parameters and thus effectively
-        "destroys" all keyword parameters passed to the decorated callable.
         '''
 
-        return func(*args)
+        return func()
 
     # Return this closure.
     return _closure_nonisomorphic
 
-# ....................{ CALLABLES ~ sync : generator       }....................
-def sync_generator_factory() -> Generator[int, None, None]:
+# ....................{ CALLABLES ~ sync : wrapper         }....................
+def function_wrappee(text_one: str, text_two: str) -> str:
     '''
-    Create and return a pure-Python generator yielding a single integer,
-    accepting nothing, and returning nothing.
+    **Annotated wrappee** (i.e., lower-level function annotated by one or more
+    type hints and subsequently wrapped by a higher-level wrapper function).
     '''
 
-    yield 1
+    return text_one + text_two
 
 
-def sync_generator_factory_yield_int_send_float_return_str() -> (
-    Generator[int, float, str]):
+# Note that the "assigned" parameter is intentionally passed the empty tuple,
+# preserving the original "__name__" and "__qualname__" dunder attributes of
+# wrapper callables for debuggability.
+@wraps(function_wrappee, assigned=())
+def function_wrapper_nonisomarphic(text):
     '''
-    Create and return a pure-Python generator yielding integers, accepting
-    floating-point numbers sent to this generator by the caller, and returning
-    strings.
-
-    See Also
-    ----------
-    https://www.python.org/dev/peps/pep-0484/#id39
-        ``echo_round`` function strongly inspiring this implementation, copied
-        verbatim from this subsection of :pep:`484`.
+    **Non-isomorphic wrapper** (i.e., higher-level function destroying the
+    positions and/or types of one or more parameters passed to the lower-level
+    function wrapped by this wrapper).
     '''
 
-    # Initial value externally sent to this generator.
-    res = yield
+    return function_wrappee(text[0], text[1:])
 
-    while res:
-        res = yield round(res)
 
-    # Return a string constant.
-    return 'Unmarred, scarred revenant remnants'
+@wraps(function_wrapper_nonisomarphic, assigned=())
+def function_wrapper_isomarphic(*args, **kwargs):
+    '''
+    **Isomorphic wrapper** (i.e., higher-level function preserving both the
+    positions and types of all parameters passed to the lower-level
+    non-isomarphic wrapper wrapped by this wrapper).
+    '''
+
+    return function_wrapper_nonisomarphic(*args, **kwargs)
+
+
+@wraps(function_wrapper_nonisomarphic, assigned=())
+def function_wrapper_isomarphic_args(*args):
+    '''
+    **Positionally isomorphic wrapper** (i.e., higher-level function preserving
+    both the positions and types of all parameters excluding keyword parameters
+    passed to the lower-level non-isomarphic wrapper wrapped by this wrapper).
+    '''
+
+    return function_wrapper_nonisomarphic(*args)
+
+
+@wraps(function_wrapper_nonisomarphic, assigned=())
+def function_wrapper_isomarphic_kwargs(**kwargs):
+    '''
+    **Keyword isomorphic wrapper** (i.e., higher-level function preserving both
+    the positions and types of all parameters excluding positional parameters
+    passed to the lower-level non-isomarphic wrapper wrapped by this wrapper).
+    '''
+
+    return function_wrapper_nonisomarphic(**kwargs)
+
+
+class ClassCallableWrapperIsomorphic(object):
+    '''
+    **Callable class** (i.e., pure-Python class defining the :meth:`__call__`
+    dunder method implicitly called by Python when instances of this class are
+    called using the standard calling convention such that that :meth:`__call__`
+    dunder method is defined as an isomorphic wrapper method wrapping an
+    isomorphic wrapper function).
+    '''
+
+    def __call__(self, *args, **kwargs):
+        '''
+        Arbitrary isomorphic wrapper dunder method implicitly wrapping an
+        isomorphic wrapper function.
+        '''
+
+        return function_wrapper_isomarphic(*args, **kwargs)
+
+
+    @wraps(function_wrappee)
+    def method_wrapper_isomorphic(self, *args, **kwargs):
+        '''
+        Arbitrary isomorphic wrapper method explicitly wrapping a wrappee
+        function, decorated by the :func:`.wraps` decorator.
+        '''
+
+        return function_wrappee(*args, **kwargs)
+
+
+    def method_wrapper_isomorphic_implicit(self, *args, **kwargs):
+        '''
+        Arbitrary isomorphic wrapper method implicitly wrapping a wrappee
+        function *without* being decorated by the :func:`.wraps` decorator.
+        '''
+
+        return function_wrappee(*args, **kwargs)
+
+
+object_callable_wrapper_isomorphic = ClassCallableWrapperIsomorphic()
+'''
+**Pseudo-callable object** (i.e., pure-Python object whose class defines the
+:meth:`__call__` dunder method implicitly called by Python when instances of
+this class are called using the standard calling convention such that that
+:meth:`__call__` dunder method is defined as an isomorphic wrapper method
+wrapping an isomorphic wrapper function).
+'''
+
+# Declare that this pseudo-callable object wraps this lower-level function.
+update_wrapper(
+    wrapper=object_callable_wrapper_isomorphic,
+    wrapped=function_wrapper_isomarphic,
+    assigned=(),
+)
 
 # ....................{ CALLABLES ~ sync : closure         }....................
 def closure_factory():
@@ -449,7 +333,40 @@ def closure_cell_factory():
     # Return this closure's first and only cell variable.
     return closure.__closure__[0]
 
-# ....................{ CALLABLES ~ sync : instance        }....................
+# ....................{ CALLABLES ~ sync : generator       }....................
+def sync_generator_factory() -> Generator[int, None, None]:
+    '''
+    Create and return a pure-Python generator yielding a single integer,
+    accepting nothing, and returning nothing.
+    '''
+
+    yield 1
+
+
+def sync_generator_factory_yield_int_send_float_return_str() -> (
+    Generator[int, float, str]):
+    '''
+    Create and return a pure-Python generator yielding integers, accepting
+    floating-point numbers sent to this generator by the caller, and returning
+    strings.
+
+    See Also
+    ----------
+    https://www.python.org/dev/peps/pep-0484/#id39
+        ``echo_round`` function strongly inspiring this implementation, copied
+        verbatim from this subsection of :pep:`484`.
+    '''
+
+    # Initial value externally sent to this generator.
+    res = yield
+
+    while res:
+        res = yield round(res)
+
+    # Return a string constant.
+    return 'Unmarred, scarred revenant remnants'
+
+
 sync_generator = sync_generator_factory()
 '''
 Arbitrary pure-Python synchronous generator.
@@ -566,6 +483,343 @@ def function_module_name_none() -> None:
 function_module_name_fake.__module__ = 'He_had.a_mask.like_Castlereagh'
 function_module_name_none.__module__ = None
 
+# ....................{ CLASSES ~ abc                      }....................
+class ClassSized(object):
+    '''
+    Class manually satisfying *only* the standard :class:`collections.abc.Sized`
+    protocol *without* simply subclassing a builtin immutable sized type (e.g.,
+    :class:`str`).
+    '''
+
+    def __init__(self, sized: SizedABC) -> None: self._sized = sized
+    def __len__(self) -> int: return len(self._sized)
+
+# ....................{ CLASSES ~ abc : mapping            }....................
+class ClassMapping(object):
+    '''
+    Class manually satisfying *only* the standard
+    :class:`collections.abc.Mapping` protocol *without* simply subclassing a
+    builtin mutable dictionary type (e.g., :class:`dict`).
+    '''
+
+    __abc_tpflags__ = 1 << 6 # Py_TPFLAGS_MAPPING
+    def __init__(self, items: dict) -> None: self._items = items
+    def __contains__(self, item: object) -> bool: return item in self._items
+    def __iter__(self) -> Iterator: return iter(self._items)
+    def __len__(self) -> int: return len(self._items)
+    def __eq__(self, other: 'ClassMapping') -> bool:
+        return self._items == other._items
+    def __ne__(self, other: 'ClassMapping') -> bool:
+        return self._items != other._items
+    def __getitem__(self, key: HashableABC) -> object: return self._items[key]
+    def get(self, *args, **kwargs) -> object:
+        return self._items.get(*args, **kwargs)
+    def items(self) -> ItemsViewABC: return self._items.items()
+    def keys(self) -> KeysViewABC: return self._items.keys()
+    def values(self) -> ValuesViewABC: return self._items.values()
+
+
+class ClassMutableMapping(ClassMapping):
+    '''
+    Class manually satisfying *only* the standard
+    :class:`collections.abc.MutableMapping` protocol *without* simply
+    subclassing a builtin mutable dictionary type (e.g., :class:`dict`).
+    '''
+
+    def __delitem__(self, key: HashableABC) -> None: del self._items[key]
+    def __setitem__(self, key: HashableABC, value: object) -> None:
+        self._items[key] = value
+    def clear(self) -> None: self._items.clear()
+    def pop(self, *args, **kwargs) -> object:
+        return self._items.pop(*args, **kwargs)
+    def popitem(self) -> Tuple[object, object]: return self._items.popitem()
+    def setdefault(self, *args, **kwargs) -> object:
+        return self._items.setdefault(*args, **kwargs)
+    def update(self, *args, **kwargs) -> object:
+        return self._items.update(*args, **kwargs)
+
+# ....................{ CLASSES ~ abc : sequence           }....................
+class ClassContainer(object):
+    '''
+    Class manually satisfying *only* the standard
+    :class:`collections.abc.Container` protocol *without* simply subclassing a
+    builtin immutable container type (e.g., :class:`str`).
+    '''
+
+    def __init__(self, items: list) -> None: self._items = items
+    def __contains__(self, item: object) -> bool: return item in self._items
+
+
+class ClassCollection(ClassContainer):
+    '''
+    Class manually satisfying *only* the standard
+    :class:`collections.abc.Collection` protocol *without* simply subclassing a
+    builtin immutable container type (e.g., :class:`bytes`).
+    '''
+
+    def __iter__(self) -> Iterator: return iter(self._items)
+    def __len__(self) -> int: return len(self._items)
+
+
+class ClassSequence(ClassCollection):
+    '''
+    Class manually satisfying *only* the standard
+    :class:`collections.abc.Sequence` protocol *without* simply subclassing a
+    builtin immutable sequence type (e.g., :class:`tuple`).
+    '''
+
+    def __getitem__(self, index: int) -> object: return self._items[index]
+    def __reversed__(self) -> Iterator: return reversed(self._items)
+    def count(self, item: object) -> int: return self._items.count(item)
+    def index(self, *args, **kwargs) -> int:
+        return self._items.index(*args, **kwargs)
+
+
+class ClassMutableSequence(ClassSequence):
+    '''
+    Class manually satisfying *only* the standard
+    :class:`collections.abc.MutableSequence` protocol *without* simply
+    subclassing a builtin mutable sequence type (e.g., :class:`list`).
+    '''
+
+    def __delitem__(self, index: int) -> None: del self._items[index]
+    def __setitem__(self, index: int, item: object) -> None:
+        self._items[index] = item
+    def __iadd__(self, item: object) -> object: self._items += item
+    def append(self, item: object) -> None: self._items.append(item)
+    def clear(self) -> None: self._items.clear()
+    def extend(self, items: Iterable) -> None: self._items.extend(items)
+    def insert(self, index: int, item: object) -> None:
+        self._items.insert(index, item)
+    def pop(self, *args, **kwargs) -> object:
+        return self._items.pop(*args, **kwargs)
+    def remove(self, item: object) -> None: self._items.remove(item)
+    def reverse(self) -> None: self._items.reverse()
+
+
+
+class ClassMappingSequence(ClassMapping, ClassSequence):
+    '''
+    Class manually satisfying both the standard :class:`collections.abc.Mapping`
+    *and* :class:`collections.abc.Sequence` protocols *without* simply
+    subclassing a builtin mapping or sequence type (e.g., :class:`list`).
+    '''
+
+    pass
+
+# ....................{ CLASSES ~ builtin                  }....................
+class ClassDict(dict):
+    '''
+    Class subclassing the builtin C-based :class:`dict` type.
+    '''
+
+    pass
+
+
+class ClassList(list):
+    '''
+    Class subclassing the builtin C-based :class:`list` type.
+    '''
+
+    pass
+
+# ....................{ CLASSES ~ enum                     }....................
+class MasterlessDecreeVenomlessWhich(Enum):
+    '''
+    Arbitrary enumeration whose members are accessed elsewhere as integers,
+    typically when subscripting the :pep:`586`-compliant :attr:`typing.Literal`
+    type hint factory.
+    '''
+
+    NOMENCLATURE_WEATHER_VANES_OF = 0
+    NOMINALLY_UNSWAIN_AUTODIDACTIC_IDIOCRACY_LESS_A = 1
+
+# ....................{ CLASSES ~ dunder : call            }....................
+class ClassCallable(object):
+    '''
+    **Callable class** (i.e., pure-Python class defining the :meth:`__call__`
+    dunder method implicitly called by Python when instances of this class are
+    called using the standard calling convention).
+    '''
+
+    def __call__(self, *args, **kwargs) -> int:
+        '''
+        Dunder method implicitly called when this object is called.
+        '''
+
+        return len(args) + len(kwargs)
+
+# ....................{ CLASSES ~ dunder : instancecheck   }....................
+class NonIsinstanceableMetaclass(type):
+    '''
+    Metaclass overriding the ``__instancecheck__()`` dunder method to
+    unconditionally raise an exception, preventing classes with this metaclass
+    from being passed as the second parameter to the :func:`isinstance`
+    builtin.
+    '''
+
+    def __instancecheck__(self, obj: object) -> bool:
+        raise TypeError(
+            f'{self} not passable as second parameter to isinstance().')
+
+
+class NonIsinstanceableClass(object, metaclass=NonIsinstanceableMetaclass):
+    '''
+    Class whose metaclass overrides the ``__instancecheck__()`` dunder method
+    to unconditionally raise an exception, preventing this class from being
+    passed as the second parameter to the :func:`isinstance` builtin.
+    '''
+
+    pass
+
+# ....................{ CLASSES ~ dunder : subclasscheck   }....................
+class NonIssubclassableMetaclass(type):
+    '''
+    Metaclass overriding the ``__subclasscheck__()`` dunder method to
+    unconditionally raise an exception, preventing classes with this metaclass
+    from being passed as the second parameter to the :func:`issubclass`
+    builtin.
+    '''
+
+    def __subclasscheck__(self, obj: object) -> bool:
+        raise TypeError(
+            f'{self} not passable as second parameter to issubclass().')
+
+
+class NonIssubclassableClass(object, metaclass=NonIssubclassableMetaclass):
+    '''
+    Class whose metaclass overrides the ``__subclasscheck__()`` dunder method
+    to unconditionally raise an exception, preventing this class from being
+    passed as the second parameter to the :func:`issubclass` builtin.
+    '''
+
+    pass
+
+# ....................{ CLASSES ~ dunder : module          }....................
+class ClassModuleNameFake(object):
+    '''
+    Arbitrary pure-Python class with a **non-existent module name** (i.e., whose
+    ``__module__`` dunder attribute refers to a file that is guaranteed to *not*
+    exist on the local filesystem).
+    '''
+
+    pass
+
+
+class ClassModuleNameNone(object):
+    '''
+    Arbitrary pure-Python class with a **missing module name** (i.e., whose
+    ``__module__`` dunder attribute is :data:`None`).
+    '''
+
+    pass
+
+
+# Monkey-patch the above classes with "bad" module names.
+ClassModuleNameFake.__module__ = 'If_I.were.a_dead_leaf.thou_mightest.bear'
+ClassModuleNameNone.__module__ = None
+
+# ....................{ CLASSES ~ hierarchy : 1            }....................
+# Arbitrary class hierarchy.
+
+class Class(object):
+    '''
+    Arbitrary pure-Python class defining arbitrary methods.
+    '''
+
+    # ....................{ NESTED                         }....................
+    class NestedClass(object):
+        '''
+        Arbitrary pure-Python **nested class** whose definition is nested inside
+        the definition of another class.
+        '''
+
+        pass
+
+    # ....................{ METHODS                        }....................
+    def instance_method(self):
+        '''
+        Arbitrary pure-Python instance method.
+        '''
+
+        pass
+
+
+    @property
+    def instance_property(self):
+        '''
+        Arbitrary pure-Python instance property.
+        '''
+
+        pass
+
+
+    @classmethod
+    def class_method(cls):
+        '''
+        Arbitrary pure-Python class method.
+        '''
+
+        pass
+
+
+    @staticmethod
+    def static_method():
+        '''
+        Arbitrary pure-Python static method.
+        '''
+
+        pass
+
+
+class Subclass(Class):
+    '''
+    Arbitrary pure-Python subclass of an arbitrary pure-Python superclass.
+    '''
+
+    pass
+
+
+class SubclassSubclass(Subclass):
+    '''
+    Arbitrary pure-Python subclass of an arbitrary pure-Python subclass of an
+    arbitrary pure-Python superclass.
+    '''
+
+    pass
+
+# ....................{ CLASSES ~ hierarchy : 2            }....................
+# Yet another arbitrary class hierarchy.
+
+class OtherClass(object):
+    '''
+    Arbitrary pure-Python class defining an arbitrary method.
+    '''
+
+    def instance_method(self):
+        '''
+        Arbitrary pure-Python instance method.
+        '''
+
+        pass
+
+
+class OtherSubclass(OtherClass):
+    '''
+    Arbitrary pure-Python subclass of an arbitrary pure-Python superclass.
+    '''
+
+    pass
+
+
+class OtherSubclassSubclass(OtherSubclass):
+    '''
+    Arbitrary pure-Python subclass of an arbitrary pure-Python subclass of an
+    arbitrary pure-Python superclass.
+    '''
+
+    pass
+
 # ....................{ CONSTANTS                          }....................
 CALLABLE_CODE_OBJECT = function.__code__
 '''
@@ -700,7 +954,7 @@ Frozen set of all **fake builtin types** (i.e., types that are *not* builtin
 but which nonetheless erroneously masquerade as being builtin).
 
 See Also
-----------
+--------
 :data:`beartype._data.cls.datacls.TYPES_BUILTIN_FAKE`
     Related runtime set. Whereas that runtime-specific set is efficiently
     defined explicitly by listing all non-builtin builtin mimic types, this
