@@ -30,16 +30,16 @@ def hints_pep544_meta() -> 'List[HintPepMetadata]':
     from beartype.typing import (
         Any,
         AnyStr,
-        TypeVar,
         runtime_checkable,
     )
+    from beartype._data.hint.datahinttyping import T
     from beartype._data.hint.pep.sign.datapepsigns import (
         HintSignBinaryIO,
         HintSignGeneric,
         HintSignIO,
         HintSignTextIO,
     )
-    from beartype._util.module.lib.utiltyping import get_typing_attrs
+    from beartype._util.api.utilapityping import get_typing_attrs
     from beartype_test.a00_unit.data.hint.util.data_hintmetacls import (
         HintPepMetadata,
         HintPithSatisfiedMetadata,
@@ -57,9 +57,6 @@ def hints_pep544_meta() -> 'List[HintPepMetadata]':
     # cross-platform IO testing purposes.
     SUBMODULE_FILENAME = __file__
 
-    # Type variables.
-    T = TypeVar('T')
-
     # ..................{ CALLABLES                          }..................
     def open_file_text():
         '''
@@ -594,7 +591,7 @@ def hints_pep544_ignorable_shallow() -> list:
     '''
 
     # ..................{ IMPORTS                            }..................
-    from beartype._util.module.lib.utiltyping import get_typing_attrs
+    from beartype._util.api.utilapityping import get_typing_attrs
 
     # ..................{ LOCALS                             }..................
     # List of all PEP-specific shallowly ignorable type hints to be returned.
@@ -633,17 +630,13 @@ def hints_pep544_ignorable_deep() -> list:
     '''
 
     # ..................{ IMPORTS                            }..................
-    from beartype._util.module.lib.utiltyping import get_typing_attrs
-    from beartype.typing import TypeVar
+    from beartype._util.api.utilapityping import get_typing_attrs
+    from beartype._data.hint.datahinttyping import S, T
 
     # ..................{ LOCALS                             }..................
     # List of all PEP-specific deeply ignorable type hints to be returned.
     hints_pep_ignorable_deep = []
 
-    # Type variables.
-    S = TypeVar('S')
-    T = TypeVar('T')
-
     # ..................{ LISTS                              }..................
     # For the PEP 544-specific "Protocol" superclass importable from any typing
     # module...
