@@ -19,7 +19,12 @@ def hints_pep593_meta() -> 'List[HintPepMetadata]':
 
     # ..................{ IMPORTS                            }..................
     # Defer fixture-specific imports.
-    from beartype.typing import List
+    from beartype.typing import (
+        List,
+        Sequence,
+        TypeVar,
+        Union,
+    )
     from beartype.vale import (
         Is,
         IsAttr,
@@ -30,8 +35,10 @@ def hints_pep593_meta() -> 'List[HintPepMetadata]':
     from beartype._data.hint.pep.sign.datapepsigns import (
         HintSignAnnotated,
         HintSignList,
+        HintSignUnion,
     )
-    from beartype._util.module.lib.utiltyping import get_typing_attrs
+    from beartype._util.api.utilapityping import get_typing_attrs
+    from beartype._util.py.utilpyversion import IS_PYTHON_AT_LEAST_3_10
     from beartype_test.a00_unit.data.data_type import (
         Class,
         Subclass,
@@ -42,13 +49,51 @@ def hints_pep593_meta() -> 'List[HintPepMetadata]':
         HintPithSatisfiedMetadata,
         HintPithUnsatisfiedMetadata,
     )
+    from functools import partial
+
+    # ..................{ CLASSES                            }..................
+    class TruthSeeker(object):
+        def __call__(self, obj: object) -> bool:
+            '''
+            Tester method returning :data:`True` only if the passed object
+            evaluates to :data:`True` when coerced into a boolean and whose
+            first parameter is ignorable.
+            '''
+
+            return bool(obj)
+
+    # ..................{ CALLABLES                          }..................
+    def is_true(ignorable_arg, obj):
+        '''
+        Tester function returning :data:`True` only if the passed object
+        evaluates to :data:`True` when coerced into a boolean and whose first
+        parameter is ignorable.
+        '''
+
+        return bool(obj)
+
+
+    # Partial of the is_true() tester defined above, effectively ignoring the
+    # "ignorable_arg" parameter accepted by that tester.
+    is_true_partial = partial(
+        is_true, 'Drank its inspiring radiance, and the wind')
 
     # ..................{ VALIDATORS ~ is                    }..................
-    # Beartype-specific validators defined as lambda functions.
+    # PEP 484-compliant union of all builtin scalar types.
+    Number = Union[int, float, complex]
+
+    # Generic beartype validators defined as lambda functions.
+    IsNonEmpty = Is[lambda obj: bool(obj)]
+
+    # Numeric beartype validators defined as lambda functions.
+    IsNonNegative = Is[lambda number: number >= 0]
+    IsIntNonZero = Is[lambda number: isinstance(number, int) and number != 0]
+
+    # Textual beartype validators defined as lambda functions.
     IsLengthy = Is[lambda text: len(text) > 30]
     IsSentence = Is[lambda text: text and text[-1] == '.']
 
-    # Beartype-specific validators defined as non-lambda functions.
+    # Textual beartype validators defined as non-lambda functions.
     def _is_quoted(text):
         return '"' in text or "'" in text
     def _is_exceptional(obj):
@@ -56,8 +101,8 @@ def hints_pep593_meta() -> 'List[HintPepMetadata]':
     IsQuoted = Is[_is_quoted]
     IsExceptional = Is[_is_exceptional]
 
-    # Beartype-specific validator synthesized from the above validators
-    # via the domain-specific language (DSL) implemented by those validators.
+    # Textual beartype validator synthesized from the above validators via the
+    # domain-specific language (DSL) implemented by those validators.
     IsLengthyOrUnquotedSentence = IsLengthy | (IsSentence & ~IsQuoted)
 
     # ..................{ VALIDATORS ~ isattr                }..................
@@ -108,6 +153,13 @@ def hints_pep593_meta() -> 'List[HintPepMetadata]':
         # validator defined as a lambda function.
         AnnotatedStrIsLength = Annotated[str, IsLengthy]
 
+        # Validator matching any sequence of strings that is itself *NOT* a
+        # string. Technically, a string is itself a sequence of characters,
+        # which are themselves strings of length 1 in Python. Pragmatically, a
+        # string is rarely considered to be a "sequence of strings" in the
+        # common sense of that term. Validators, save us from the sins of Guido!
+        SequenceNonstrOfStr = Annotated[Sequence[str], ~IsInstance[str]]
+
         # ................{ TUPLES                             }................
         # Add PEP 593-specific test type hints to this tuple global.
         hints_pep_meta.extend((
@@ -158,8 +210,8 @@ def hints_pep593_meta() -> 'List[HintPepMetadata]':
             ),
 
             # ..............{ ANNOTATED ~ beartype : is          }..............
-            # Annotated of the root "object" superclass annotated by one
-            # beartype-specific validator defined as a lambda function.
+            # Annotated of the root "object" superclass annotated by a beartype
+            # validator defined as a lambda function.
             HintPepMetadata(
                 hint=Annotated[object, Is[
                     lambda obj: hasattr(obj, 'this_mobbed_triste_of')]],
@@ -174,8 +226,38 @@ def hints_pep593_meta() -> 'List[HintPepMetadata]':
                 ),
             ),
 
-            # Annotated of an isinstanceable type annotated by one
-            # beartype-specific validator defined as a lambda function.
+            # Annotated of the root "object" superclass annotated by a beartype
+            # validator defined as a callable object.
+            HintPepMetadata(
+                hint=Annotated[object, Is[TruthSeeker()]],
+                pep_sign=HintSignAnnotated,
+                piths_meta=(
+                    # Objects evaluating to "True" when coerced into booleans.
+                    HintPithSatisfiedMetadata(True),
+                    HintPithSatisfiedMetadata(
+                        'Leaped in the boat, he spread his cloak aloft'),
+                    # Empty string.
+                    HintPithUnsatisfiedMetadata(''),
+                ),
+            ),
+
+            # Annotated of the root "object" superclass annotated by a beartype
+            # validator defined as a partial function.
+            HintPepMetadata(
+                hint=Annotated[object, Is[is_true_partial]],
+                pep_sign=HintSignAnnotated,
+                piths_meta=(
+                    # Objects evaluating to "True" when coerced into booleans.
+                    HintPithSatisfiedMetadata(True),
+                    HintPithSatisfiedMetadata(
+                        'Swept strongly from the shore, blackening the waves.'),
+                    # Empty string.
+                    HintPithUnsatisfiedMetadata(''),
+                ),
+            ),
+
+            # Annotated of an isinstanceable type annotated by a beartype
+            # validator defined as a lambda function.
             HintPepMetadata(
                 hint=AnnotatedStrIsLength,
                 pep_sign=HintSignAnnotated,
@@ -199,8 +281,8 @@ def hints_pep593_meta() -> 'List[HintPepMetadata]':
             ),
 
             # Annotated of an isinstanceable type annotated by two or more
-            # beartype-specific validators all defined as functions, specified
-            # with comma-delimited list syntax.
+            # beartype validators all defined as functions, specified with
+            # comma-delimited list syntax.
             HintPepMetadata(
                 hint=Annotated[str, IsLengthy, IsSentence, IsQuoted],
                 pep_sign=HintSignAnnotated,
@@ -234,9 +316,8 @@ def hints_pep593_meta() -> 'List[HintPepMetadata]':
                 ),
             ),
 
-            # Annotated of an isinstanceable type annotated by one
-            # beartype-specific validator synthesized from all possible
-            # operators.
+            # Annotated of an isinstanceable type annotated by one beartype
+            # validator synthesized from all possible operators.
             HintPepMetadata(
                 hint=Annotated[str, IsLengthyOrUnquotedSentence],
                 pep_sign=HintSignAnnotated,
@@ -271,8 +352,8 @@ def hints_pep593_meta() -> 'List[HintPepMetadata]':
 
             # ..............{ ANNOTATED ~ beartype : is : &      }..............
             # Annotated of an isinstanceable type annotated by two or more
-            # validators all defined as functions, specified with "&"-delimited
-            # operator syntax.
+            # beartype validators all defined as functions, specified with
+            # "&"-delimited operator syntax.
             HintPepMetadata(
                 hint=Annotated[str, IsLengthy & IsSentence & IsQuoted],
                 pep_sign=HintSignAnnotated,
@@ -307,10 +388,10 @@ def hints_pep593_meta() -> 'List[HintPepMetadata]':
             ),
 
             # Annotated of an isinstanceable type annotated by two or more
-            # validators all defined as functions, specified with "&"-delimited
-            # operator syntax such that the first such validator short-circuits
-            # all subsequent such validators, which all intentionally raise
-            # exceptions to prove they are silently ignored.
+            # beartype validators all defined as functions, specified with
+            # "&"-delimited operator syntax such that the first such validator
+            # short-circuits all subsequent such validators, which all
+            # intentionally raise exceptions to prove they are silently ignored.
             #
             # Note this hint is *NOT* safely satisfiable. Ergo, we
             # intentionally do *NOT* validate this hint to be satisfied.
@@ -329,10 +410,10 @@ def hints_pep593_meta() -> 'List[HintPepMetadata]':
 
             # ..............{ ANNOTATED ~ beartype : is : |      }..............
             # Annotated of an isinstanceable type annotated by two or more
-            # validators all defined as functions, specified with "|"-delimited
-            # operator syntax such that the first such validator short-circuits
-            # all subsequent such validators, which all intentionally raise
-            # exceptions to prove they are silently ignored.
+            # beartype validators all defined as functions, specified with
+            # "|"-delimited operator syntax such that the first such validator
+            # short-circuits all subsequent such validators, which all
+            # intentionally raise exceptions to prove they are silently ignored.
             #
             # Note this hint is *NOT* safely unsatisfiable. Ergo, we
             # intentionally do *NOT* validate this hint to be unsatisfied.
@@ -353,7 +434,7 @@ def hints_pep593_meta() -> 'List[HintPepMetadata]':
 
             # ..............{ ANNOTATED ~ beartype : is : nest   }..............
             # Annotated of an annotated of an isinstanceable type, each
-            # annotated by a beartype-specific validator defined as a function.
+            # annotated by a beartype validator defined as a function.
             HintPepMetadata(
                 hint=Annotated[Annotated[str, IsLengthy], IsSentence],
                 pep_sign=HintSignAnnotated,
@@ -373,7 +454,7 @@ def hints_pep593_meta() -> 'List[HintPepMetadata]':
             ),
 
             # List of annotateds of isinstanceable types annotated by one
-            # beartype-specific validator defined as a lambda function.
+            # beartype validator defined as a lambda function.
             HintPepMetadata(
                 hint=List[AnnotatedStrIsLength],
                 pep_sign=HintSignList,
@@ -403,9 +484,63 @@ def hints_pep593_meta() -> 'List[HintPepMetadata]':
                 ),
             ),
 
+            # List of lists of annotateds of an ignorable type hint annotated by
+            # a type variable bounded by a beartype validator defined as a
+            # lambda function.
+            HintPepMetadata(
+                hint=List[List[TypeVar('AWhirlwindSweptItOn', bound=(
+                    Annotated[object, IsIntNonZero]))]],
+                pep_sign=HintSignList,
+                isinstanceable_type=list,
+                is_pep585_builtin_subscripted=List is list,
+                is_typevars=True,
+                piths_meta=(
+                    # List of lists of non-zero integer constants.
+                    HintPithSatisfiedMetadata([[16, 17, 20], [21, 64, 65, 68]]),
+                    # String constant *NOT* an instance of the expected type.
+                    HintPithUnsatisfiedMetadata(
+                        'The waves arose. Higher and higher still'),
+                    # List of lists of non-integers and zeroes.
+                    HintPithUnsatisfiedMetadata([
+                        [
+                            'Their fierce necks writhed',
+                            "beneath the tempest's scourge",
+                        ],
+                        [0, 0, 0, 0],
+                    ]),
+                ),
+            ),
+
+            # List of lists of annotateds of an ignorable type hint annotated by
+            # a type variable bounded by two beartype validators, one defined as
+            # a lambda function and one not.
+            HintPepMetadata(
+                hint=List[List[TypeVar('WithFierceGusts', bound=(
+                    Annotated[object, IsInstance[int], IsNonEmpty]))]],
+                pep_sign=HintSignList,
+                isinstanceable_type=list,
+                is_pep585_builtin_subscripted=List is list,
+                is_typevars=True,
+                piths_meta=(
+                    # List of lists of non-zero integer constants.
+                    HintPithSatisfiedMetadata([[16, 17, 20], [21, 64, 65, 68]]),
+                    # String constant *NOT* an instance of the expected type.
+                    HintPithUnsatisfiedMetadata(
+                        'The waves arose. Higher and higher still'),
+                    # List of lists of non-integers and zeroes.
+                    HintPithUnsatisfiedMetadata([
+                        [
+                            'Their fierce necks writhed',
+                            "beneath the tempest's scourge",
+                        ],
+                        [0, 0, 0, 0],
+                    ]),
+                ),
+            ),
+
             # ..............{ ANNOTATED ~ beartype : isattr      }..............
-            # Annotated of an isinstanceable type annotated by one
-            # beartype-specific attribute validator.
+            # Annotated of an isinstanceable type annotated by one beartype
+            # attribute validator.
             HintPepMetadata(
                 hint=Annotated[
                     CathecticallyEnsconceYouIn, IsAttrThisMobbedTristeOf],
@@ -427,8 +562,8 @@ def hints_pep593_meta() -> 'List[HintPepMetadata]':
             ),
 
             # ..............{ ANNOTATED ~ beartype : isequal     }..............
-            # Annotated of an isinstanceable type annotated by one
-            # beartype-specific equality validator.
+            # Annotated of an isinstanceable type annotated by one beartype
+            # equality validator.
             HintPepMetadata(
                 hint=Annotated[List[str], IsEqual[AMPLY_IMPISH]],
                 pep_sign=HintSignAnnotated,
@@ -455,8 +590,8 @@ def hints_pep593_meta() -> 'List[HintPepMetadata]':
             ),
 
             # ..............{ ANNOTATED ~ beartype : isinstance  }..............
-            # Annotated of an isinstanceable type annotated by one
-            # beartype-specific type instance validator.
+            # Annotated of an isinstanceable type annotated by one beartype type
+            # instance validator.
             HintPepMetadata(
                 hint=Annotated[Class, ~IsInstance[SubclassSubclass]],
                 pep_sign=HintSignAnnotated,
@@ -484,9 +619,45 @@ def hints_pep593_meta() -> 'List[HintPepMetadata]':
                 ),
             ),
 
+            # Type hint matching *ANY* sequence of strings, defined as the union
+            # of a beartype validator matching any sequence of strings that is
+            # *NOT* itself a string with a string. Although odd, this exercises
+            # an obscure edge case in code generation.
+            HintPepMetadata(
+                hint=Union[SequenceNonstrOfStr, str],
+                pep_sign=HintSignUnion,
+                piths_meta=(
+                    # String constant.
+                    HintPithSatisfiedMetadata(
+                        'Caught the impatient wandering of his gaze.'),
+                    # Tuple of string constants.
+                    HintPithSatisfiedMetadata((
+                        'Swayed with the undulations of the tide.',
+                        'A restless impulse urged him to embark',
+                    )),
+                    # Byte string constant.
+                    HintPithUnsatisfiedMetadata(
+                        pith=b'It had been long abandoned, for its sides',
+                        # Match that the exception message raised for this
+                        # object embeds a classname in the expected list.
+                        exception_str_match_regexes=(r'\bbytes\b',),
+                    ),
+                    # Tuple of byte string constants.
+                    HintPithUnsatisfiedMetadata(
+                        pith=(
+                            b'Gaped wide with many a rift,',
+                            b'and its frail joints',
+                        ),
+                        # Match that the exception message raised for this
+                        # object embeds a classname in the expected list.
+                        exception_str_match_regexes=(r'\btuple\b',),
+                    ),
+                ),
+            ),
+
             # ..............{ ANNOTATED ~ beartype : issubclass  }..............
-            # Annotated of an isinstanceable type annotated by one
-            # beartype-specific type inheritance validator.
+            # Annotated of an isinstanceable type annotated by one beartype type
+            # inheritance validator.
             HintPepMetadata(
                 hint=Annotated[type, IsSubclass[Class]],
                 pep_sign=HintSignAnnotated,
@@ -509,6 +680,46 @@ def hints_pep593_meta() -> 'List[HintPepMetadata]':
             ),
         ))
 
+        # ..................{ VERSION                        }..................
+        # If the active Python interpreter targets Python >= 3.10, the
+        # "typing.Annotated" type factory supports the "|" operator. In this
+        # case, defined unions of annotateds with this operator.
+        if IS_PYTHON_AT_LEAST_3_10:
+            # Add PEP 593-specific test type hints to this tuple global.
+            hints_pep_meta.extend((
+                # ..............{ ANNOTATED ~ beartype : is : nes}..............
+                # List of lists of annotateds of a union of isinstanceable types
+                # annotated by a type variable bounded by a union of beartype
+                # validators defined as lambda functions.
+                HintPepMetadata(
+                    hint=List[List[TypeVar('TheStrainingBoat', bound=(
+                        Annotated[Number, IsNonNegative] |
+                        Annotated[str, IsNonEmpty]
+                    ))]],
+                    pep_sign=HintSignList,
+                    isinstanceable_type=list,
+                    is_pep585_builtin_subscripted=List is list,
+                    is_typevars=True,
+                    piths_meta=(
+                        # List of lists of positive number constants.
+                        HintPithSatisfiedMetadata([[11, 0.11], [1, 110, 1101100]]),
+                        # List of lists of non-empty string constants.
+                        HintPithSatisfiedMetadata([
+                            ['The straining boat.', '—A whirlwind swept it on,'],
+                            ['With fierce gusts and', 'precipitating force,'],
+                        ]),
+                        # String constant *NOT* an instance of the expected type.
+                        HintPithUnsatisfiedMetadata(
+                            'Through the white ridges of the chafèd sea.'),
+                        # List of lists of negative numbers and empty strings.
+                        HintPithUnsatisfiedMetadata([[-1, '', -0.4], ['', -5, '']]),
+                    ),
+                ),
+            ))
+        # Else, the active Python interpreter targets Python < 3.10. In this
+        # case, the "typing.Annotated" type factory fails to support the "|"
+        # operator.
+
     # ..................{ RETURN                             }..................
     # Return this list of all PEP-specific type hint metadata.
     return hints_pep_meta
@@ -528,7 +739,7 @@ def hints_pep593_ignorable_deep() -> list:
         Optional,
         Union,
     )
-    from beartype._util.module.lib.utiltyping import get_typing_attrs
+    from beartype._util.api.utilapityping import get_typing_attrs
 
     # ..................{ LOCALS                             }..................
     # List of all PEP-specific deeply ignorable type hints to be returned.
